@@ -2,7 +2,7 @@
 /*                                                                            */
 /*     Copyright (C) 2007 Dominique Parisot                                   */
 /*          zionly@free.org                                                   */
-/*          2008-2010 Pierre Biava (grisbi@pierre.biava.name)                 */
+/*          2008-2012 Pierre Biava (grisbi@pierre.biava.name)                 */
 /*          http://www.grisbi.org                                             */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
@@ -26,6 +26,8 @@
 #endif
 
 #include "include.h"
+#include <gdk/gdkkeysyms.h>
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "bet_config.h"
@@ -38,9 +40,11 @@
 #include "gsb_account.h"
 #include "gsb_automem.h"
 #include "gsb_calendar_entry.h"
+#include "gsb_color.h"
 #include "gsb_currency.h"
 #include "gsb_data_account.h"
 #include "gsb_data_currency.h"
+#include "gsb_file.h"
 #include "gsb_form_widget.h"
 #include "gsb_fyear.h"
 #include "navigation.h"
@@ -48,6 +52,7 @@
 #include "traitement_variables.h"
 #include "utils.h"
 #include "utils_dates.h"
+#include "utils_real.h"
 #include "utils_str.h"
 #include "erreur.h"
 /*END_INCLUDE*/
@@ -63,6 +68,7 @@ static GtkWidget *bet_config_account_get_finance_data ( gchar *title );
 static GtkWidget *bet_config_get_finance_widget ( GtkWidget *parent );
 static GtkWidget *bet_config_account_get_forecast_data ( gchar *title );
 static GtkWidget *bet_config_account_get_select_account ( gchar *title );
+static GtkWidget *bet_config_account_get_select_bank_card ( void );
 static GtkWidget *bet_config_account_get_select_historical_data ( gchar *title );
 static void bet_config_finance_apply_clicked ( GtkButton *button, GtkWidget *parent );
 static GtkWidget *bet_config_get_select_labels_widget ( GtkWidget *container );
@@ -78,6 +84,7 @@ static void bet_config_initialise_duration_widget ( gint account_number,
                         GtkWidget *notebook );
 static void bet_config_initialise_finance_widget ( gint account_number,
                         GtkWidget *notebook );
+static void bet_config_initialise_select_bank_card ( gint account_number );
 static void bet_config_initialise_select_historical_data ( gint account_number,
                         GtkWidget *notebook );
 /*END_STATIC*/
@@ -86,10 +93,9 @@ static void bet_config_initialise_select_historical_data ( gint account_number,
 extern GtkWidget *account_page;
 extern GtkTreeModel *bet_fyear_model;
 extern GtkTreeModel *bet_fyear_model_filter;
-extern GtkWidget *notebook_general;
 /*END_EXTERN*/
 
-gchar* bet_duration_array[] = {
+static gchar* bet_duration_array[] = {
     N_("Month"),
     N_("Year"),
     NULL
@@ -113,11 +119,10 @@ GtkWidget *bet_config_general_create_general_page ( void )
 
     vbox = new_vbox_with_title_and_icon ( _("General Options"), "balance_estimate.png" );
     gtk_container_set_border_width ( GTK_CONTAINER ( vbox ), 12 );
-    
+
     /* Calculation of period */
     paddingbox = new_paddingbox_with_title ( vbox, FALSE, _("Common data") );
-
-    widget = bet_config_general_get_period_widget ( paddingbox );
+    bet_config_general_get_period_widget ( paddingbox );
 
     /* add a separator */
     gtk_box_pack_start ( GTK_BOX ( vbox ), gtk_hseparator_new (), FALSE, FALSE, 5 );
@@ -174,7 +179,7 @@ GtkWidget *bet_config_general_get_period_widget ( GtkWidget *container )
                         _("1st day of month") );
     gtk_widget_set_name ( button_1, "bet_period_button_1" );
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), button_1 );
-    
+
     button_2 = gtk_radio_button_new_with_label_from_widget (
                         GTK_RADIO_BUTTON ( button_1 ),
                         _("date today") );
@@ -221,20 +226,20 @@ gboolean bet_config_general_cash_account_option_clicked ( GtkWidget *checkbutton
                         gpointer null )
 {
     GtkWidget *combo;
-    
+
     combo = g_object_get_data ( G_OBJECT ( account_page ), "account_combo" );
     if ( combo )
     {
         gint account_number;
 
         account_number = gsb_account_get_combo_account_number ( combo );
+        gsb_data_account_set_bet_show_onglets_all_accounts ();
         bet_config_sensitive_account_parameters ( account_number, TRUE );
     }
 
     bet_data_select_bet_pages ( gsb_gui_navigation_get_current_account ( ) );
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     return FALSE;
 }
@@ -258,10 +263,15 @@ GtkWidget *bet_config_account_create_account_page ( void )
     gtk_container_set_border_width ( GTK_CONTAINER ( vbox_pref ), 12 );
 
     /* set the choice of account */
-    widget = bet_config_account_get_select_account ( "Select an account" );
+    widget = bet_config_account_get_select_account ( _("Select an account") );
     gtk_box_pack_start ( GTK_BOX ( vbox_pref ), widget, FALSE, FALSE, 0 );
     gtk_widget_show_all ( vbox_pref );
 
+    /* sélectionne un compte carte bancaire à débit différé */
+    widget = bet_config_account_get_select_bank_card ();
+    gtk_box_pack_start ( GTK_BOX ( vbox_pref ), widget, FALSE, FALSE, 0 );
+    g_object_set_data ( G_OBJECT ( account_page ), "bet_credit_card_hbox", widget );
+
     notebook = gtk_notebook_new ( );
     gtk_notebook_set_show_border ( GTK_NOTEBOOK ( notebook ), FALSE );
     gtk_notebook_set_show_tabs  ( GTK_NOTEBOOK ( notebook ), FALSE );
@@ -322,21 +332,21 @@ GtkWidget *bet_config_account_get_select_account ( gchar *title )
     vbox = gtk_vbox_new ( FALSE, 0 );
 
     /* set the choice of account */
-    paddingbox = new_paddingbox_with_title ( vbox, FALSE, _(title) );
+    paddingbox = new_paddingbox_with_title ( vbox, FALSE, title );
 
     hbox = gtk_hbox_new ( FALSE, 5 );
     gtk_box_pack_start ( GTK_BOX ( paddingbox ), hbox, FALSE, FALSE, 5 );
 
-	label = gtk_label_new ( _("Account: ") );
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
-	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
+    label = gtk_label_new ( _("Account: ") );
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
+    gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
     gtk_box_pack_start ( GTK_BOX (hbox ), label, FALSE, FALSE, 0 );
 
-	combo = gsb_account_create_combo_list ( (GtkSignalFunc) bet_config_change_account,
+    combo = gsb_account_create_combo_list ( G_CALLBACK ( bet_config_change_account ),
                         NULL, FALSE );
     g_object_set_data ( G_OBJECT ( account_page ), "account_combo", combo );
     if ( ( account_number = gsb_gui_navigation_get_current_account ( ) ) == -1 )
-	    gtk_combo_box_set_active ( GTK_COMBO_BOX ( combo ), 0 );
+        gtk_combo_box_set_active ( GTK_COMBO_BOX ( combo ), 0 );
     else
         gsb_account_set_combo_account_number ( combo, account_number );
     gtk_box_pack_start ( GTK_BOX ( hbox ), combo, FALSE, FALSE, 0 );
@@ -346,9 +356,9 @@ GtkWidget *bet_config_account_get_select_account ( gchar *title )
     g_object_set_data ( G_OBJECT ( combo ), "bet_use_budget", button );
     gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 5 );
     g_signal_connect ( G_OBJECT ( button ),
-			            "toggled",
-			            G_CALLBACK ( bet_config_use_budget_toggle ),
-			            combo );
+                        "toggled",
+                        G_CALLBACK ( bet_config_use_budget_toggle ),
+                        combo );
 
     return vbox;
 }
@@ -410,7 +420,7 @@ GtkWidget *bet_config_get_duration_widget ( gint origin )
     }
 
     /* partie mensuelle */
-    label = gtk_label_new ( _("Duration estimation") );
+    label = gtk_label_new ( _("Duration estimation:") );
     gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 0.5);
     gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_LEFT );
     gtk_box_pack_start ( GTK_BOX ( box ), label, FALSE, FALSE, 5 ) ;
@@ -429,8 +439,8 @@ GtkWidget *bet_config_get_duration_widget ( gint origin )
             widget = gtk_radio_button_new_with_label ( NULL,
                         _(bet_duration_array[iduration]) );
             previous = widget;
-        }  
-        else 
+        }
+        else
         {
             widget = gtk_radio_button_new_with_label_from_widget (
                         GTK_RADIO_BUTTON ( previous ),
@@ -573,7 +583,7 @@ GtkWidget *bet_config_get_select_labels_widget ( GtkWidget *container )
     origine = SPP_ORIGIN_TRANSACTION;
     select = gsb_data_account_get_bet_select_label ( bet_config_get_account_from_combo ( ),
                         origine );
-    label = gtk_label_new ( _("Labels for transactions") );
+    label = gtk_label_new ( _("Labels for transactions:") );
     gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 0.5);
     gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_LEFT );
     gtk_box_pack_start ( GTK_BOX ( vbox ), label, FALSE, FALSE, 5 );
@@ -592,7 +602,7 @@ GtkWidget *bet_config_get_select_labels_widget ( GtkWidget *container )
     origine = SPP_ORIGIN_SCHEDULED;
     select = gsb_data_account_get_bet_select_label ( bet_config_get_account_from_combo ( ),
                         origine );
-    label = gtk_label_new ( _("Labels for scheduled transactions") );
+    label = gtk_label_new ( _("Labels for scheduled transactions:") );
     gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 0.5);
     gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_LEFT );
     gtk_box_pack_start ( GTK_BOX ( vbox ), label, FALSE, FALSE, 5 );
@@ -610,7 +620,7 @@ GtkWidget *bet_config_get_select_labels_widget ( GtkWidget *container )
     origine = SPP_ORIGIN_FUTURE;
     select = gsb_data_account_get_bet_select_label ( bet_config_get_account_from_combo ( ),
                         origine );
-    label = gtk_label_new ( _("Labels for futur data") );
+    label = gtk_label_new ( _("Labels for futur data:") );
     gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 0.5);
     gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_LEFT );
     gtk_box_pack_start ( GTK_BOX ( vbox ), label, FALSE, FALSE, 5 );
@@ -624,8 +634,8 @@ GtkWidget *bet_config_get_select_labels_widget ( GtkWidget *container )
                         GTK_ORIENTATION_HORIZONTAL );
     gtk_box_pack_start ( GTK_BOX ( vbox ), button, FALSE, FALSE, 0 );
 
-    text = make_blue ( _("Order by default if the data are not zero: notes, payee, "
-                        "category and budgetary line.") );
+    text = make_blue ( _("Order by default if the data are not zero:\n"
+                        "\tnotes, payee, category and budgetary line.") );
     label = gtk_label_new ( text );
     gtk_label_set_use_markup ( GTK_LABEL(label), TRUE );
     gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 0.5);
@@ -649,12 +659,11 @@ GtkWidget *bet_config_account_get_select_historical_data ( gchar *title )
 {
     GtkWidget *vbox;
     GtkWidget *paddingbox;
-    GtkWidget *hbox;
 
     vbox = gtk_vbox_new ( FALSE, 0 );
 
     paddingbox = new_paddingbox_with_title ( vbox, FALSE, _(title) );
-    hbox = bet_config_get_select_historical_data ( paddingbox, account_page );
+    bet_config_get_select_historical_data ( paddingbox, account_page );
 
     return vbox;
 }
@@ -672,6 +681,7 @@ GtkWidget *bet_config_get_select_historical_data ( GtkWidget *container,
     GtkWidget *widget;
     GtkWidget *hbox;
     GtkWidget *button_1, *button_2;
+    GDate *date_jour;
     gchar *str_year;
     gint year;
 
@@ -709,7 +719,10 @@ GtkWidget *bet_config_get_select_historical_data ( GtkWidget *container,
     g_object_set_data ( G_OBJECT ( notebook ), "bet_config_hist_fyear_combo", widget );
 
     /* hide the present financial year */
-    year = g_date_get_year ( gdate_today ( ) );
+    date_jour = gdate_today ( );
+    year = g_date_get_year ( date_jour );
+    g_date_free ( date_jour );
+
     str_year = utils_str_itoa ( year );
     gsb_fyear_hide_iter_by_name ( bet_fyear_model, str_year );
     g_free ( str_year );
@@ -720,6 +733,7 @@ GtkWidget *bet_config_get_select_historical_data ( GtkWidget *container,
                     G_CALLBACK ( bet_config_fyear_clicked ),
                     GINT_TO_POINTER ( 0 ) );
 
+    /* return */
     return hbox;
 }
 
@@ -768,6 +782,7 @@ void bet_config_period_clicked ( GtkWidget *togglebutton, GdkEventButton *event,
                         G_CALLBACK ( bet_config_period_clicked ),
                         button );
 
+    gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( togglebutton ), TRUE );
     name = gtk_widget_get_name ( GTK_WIDGET ( togglebutton ) );
 
     if ( g_strcmp0 ( name, "bet_period_button_1" ) == 0 )
@@ -783,8 +798,7 @@ void bet_config_period_clicked ( GtkWidget *togglebutton, GdkEventButton *event,
                         G_CALLBACK ( bet_config_period_clicked ),
                         button );
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 }
 
 
@@ -851,8 +865,7 @@ void bet_config_duration_button_clicked ( GtkWidget *togglebutton,
                         G_CALLBACK ( bet_config_duration_number_changed ),
                         data );
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     gsb_data_account_set_bet_maj ( account_number, BET_MAJ_ESTIMATE );
     bet_data_update_bet_module ( account_number, -1 );
@@ -879,11 +892,10 @@ gboolean bet_config_duration_number_changed ( GtkWidget *spin_button,
     months = gtk_spin_button_get_value_as_int ( GTK_SPIN_BUTTON ( spin_button ) );
     if ( gsb_data_account_get_bet_spin_range ( account_number ) == 1 )
         months *= 12;
-                                               
+
     gsb_data_account_set_bet_months ( account_number, months );
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     gsb_data_account_set_bet_maj ( account_number, BET_MAJ_ESTIMATE );
     bet_data_update_bet_module ( account_number, -1 );
@@ -947,8 +959,7 @@ void bet_config_origin_data_clicked ( GtkWidget *togglebutton, GdkEventButton *e
     gtk_tree_view_column_set_title ( GTK_TREE_VIEW_COLUMN ( column ), title );
     g_free ( title );
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     gsb_data_account_set_bet_maj ( account_number, BET_MAJ_ALL );
     bet_data_update_bet_module ( account_number, -1 );
@@ -973,8 +984,7 @@ void bet_config_fyear_clicked ( GtkWidget *combo, gpointer data )
     gsb_data_account_set_bet_hist_fyear ( account_number,
                         bet_historical_get_fyear_from_combobox ( combo ) );
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     gsb_data_account_set_bet_maj ( account_number, BET_MAJ_ALL );
     bet_data_update_bet_module ( account_number, -1 );
@@ -994,9 +1004,10 @@ gboolean bet_config_change_account ( GtkWidget *combo )
 {
     GtkWidget *notebook;
     GtkWidget *widget = NULL;
+    GtkWidget *fyear_combo;
     gint account_number;
     gint bet_use_budget;
-    kind_account kind;
+    bet_type_onglets bet_show_onglets;
 
     devel_debug (NULL);
     widget = g_object_get_data ( G_OBJECT ( combo ), "bet_use_budget" );
@@ -1007,6 +1018,12 @@ gboolean bet_config_change_account ( GtkWidget *combo )
     account_number = gsb_account_get_combo_account_number ( combo );
     bet_use_budget = gsb_data_account_get_bet_use_budget ( account_number );
 
+    /* on bloque l'appel à la fonction bet_config_fyear_clicked */
+    fyear_combo = g_object_get_data ( G_OBJECT ( account_page ), "bet_config_hist_fyear_combo" );
+    g_signal_handlers_block_by_func ( G_OBJECT ( fyear_combo ),
+                        G_CALLBACK ( bet_config_fyear_clicked ),
+                        GINT_TO_POINTER ( 0 ) );
+
     switch ( bet_use_budget )
     {
         case -1:
@@ -1028,31 +1045,37 @@ gboolean bet_config_change_account ( GtkWidget *combo )
             break;
     }
 
-    kind = gsb_data_account_get_kind ( account_number );
-    if ( etat.bet_deb_cash_account_option == 1 &&  kind == GSB_TYPE_CASH )
-        kind = GSB_TYPE_BANK;
-
+    bet_show_onglets = gsb_data_account_get_bet_show_onglets ( account_number );
     notebook = g_object_get_data ( G_OBJECT ( account_page ), "config_notebook" );
-    switch ( kind )
+    switch ( bet_show_onglets )
     {
-        case GSB_TYPE_BANK:
+        case BET_ONGLETS_PREV:
             gtk_notebook_set_current_page ( GTK_NOTEBOOK ( notebook ), 0 );
+            bet_config_initialise_select_bank_card ( account_number );
             bet_config_initialise_duration_widget ( account_number, account_page );
             bet_config_initialise_select_historical_data ( account_number, account_page );
             break;
-        case GSB_TYPE_CASH:
+        case BET_ONGLETS_HIST:
             gtk_notebook_set_current_page ( GTK_NOTEBOOK ( notebook ), 0 );
+            bet_config_initialise_select_bank_card ( account_number );
             bet_config_initialise_select_historical_data ( account_number, account_page );
             break;
-        case GSB_TYPE_LIABILITIES:
+        case BET_ONGLETS_CAP:
             gtk_notebook_set_current_page ( GTK_NOTEBOOK ( notebook ), 1 );
+            bet_config_initialise_select_bank_card ( account_number );
             bet_config_initialise_finance_widget ( account_number, account_page );
             break;
-        case GSB_TYPE_ASSET:
+        default:
             gtk_notebook_set_current_page ( GTK_NOTEBOOK ( notebook ), 0 );
             break;
     }
 
+    /* on débloque l'appel à la fonction bet_config_fyear_clicked */
+    g_signal_handlers_unblock_by_func ( G_OBJECT ( fyear_combo ),
+                        G_CALLBACK ( bet_config_fyear_clicked ),
+                        GINT_TO_POINTER ( 0 ) );
+
+    /* return */
     return FALSE;
 }
 
@@ -1100,9 +1123,8 @@ gboolean bet_config_select_label_changed ( GtkWidget *checkbutton,
 
     gsb_data_account_set_bet_select_label ( account_number, origine, value );
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
-    
+    gsb_file_set_modified ( TRUE );
+
     gsb_data_account_set_bet_maj ( account_number, BET_MAJ_ESTIMATE );
     bet_data_update_bet_module ( account_number, -1 );
 
@@ -1122,15 +1144,15 @@ void bet_config_sensitive_account_parameters ( gint account_number, gboolean sen
 
     if ( sensitive )
     {
-        kind_account kind;
+        bet_type_onglets bet_show_onglets;
 
-        kind = gsb_data_account_get_kind ( account_number );
-        if ( etat.bet_deb_cash_account_option == 1 &&  kind == GSB_TYPE_CASH )
-            kind = GSB_TYPE_BANK;
+        bet_show_onglets = gsb_data_account_get_bet_show_onglets ( account_number );
 
-        switch ( kind )
+        switch ( bet_show_onglets )
         {
-        case GSB_TYPE_BANK:
+        case BET_ONGLETS_PREV:
+            widget = g_object_get_data ( G_OBJECT ( account_page ), "bet_credit_card_hbox" );
+            gtk_widget_show_all ( widget );
             widget = g_object_get_data ( G_OBJECT ( account_page ), "Data_for_forecast" );
             gtk_widget_show_all ( widget );
             widget = g_object_get_data ( G_OBJECT ( account_page ), "Data_for_historical" );
@@ -1138,7 +1160,9 @@ void bet_config_sensitive_account_parameters ( gint account_number, gboolean sen
             widget = g_object_get_data ( G_OBJECT ( account_page ), "Data_for_credit" );
             gtk_widget_hide_all ( widget );
             break;
-        case GSB_TYPE_CASH:
+        case BET_ONGLETS_HIST:
+            widget = g_object_get_data ( G_OBJECT ( account_page ), "bet_credit_card_hbox" );
+            gtk_widget_show_all ( widget );
             widget = g_object_get_data ( G_OBJECT ( account_page ), "Data_for_forecast" );
             gtk_widget_hide_all ( widget );
             widget = g_object_get_data ( G_OBJECT ( account_page ), "Data_for_historical" );
@@ -1146,7 +1170,9 @@ void bet_config_sensitive_account_parameters ( gint account_number, gboolean sen
             widget = g_object_get_data ( G_OBJECT ( account_page ), "Data_for_credit" );
             gtk_widget_hide_all ( widget );
             break;
-        case GSB_TYPE_LIABILITIES:
+        case BET_ONGLETS_CAP:
+            widget = g_object_get_data ( G_OBJECT ( account_page ), "bet_credit_card_hbox" );
+            gtk_widget_show_all ( widget );
             widget = g_object_get_data ( G_OBJECT ( account_page ), "Data_for_forecast" );
             gtk_widget_hide_all ( widget );
             widget = g_object_get_data ( G_OBJECT ( account_page ), "Data_for_historical" );
@@ -1154,7 +1180,9 @@ void bet_config_sensitive_account_parameters ( gint account_number, gboolean sen
             widget = g_object_get_data ( G_OBJECT ( account_page ), "Data_for_credit" );
             gtk_widget_show_all ( widget );
             break;
-        case GSB_TYPE_ASSET:
+        default:
+            widget = g_object_get_data ( G_OBJECT ( account_page ), "bet_credit_card_hbox" );
+            gtk_widget_hide ( widget );
             widget = g_object_get_data ( G_OBJECT ( account_page ), "Data_for_forecast" );
             gtk_widget_hide_all ( widget );
             widget = g_object_get_data ( G_OBJECT ( account_page ), "Data_for_historical" );
@@ -1166,10 +1194,14 @@ void bet_config_sensitive_account_parameters ( gint account_number, gboolean sen
     }
     else
     {
+        widget = g_object_get_data ( G_OBJECT ( account_page ), "bet_credit_card_hbox" );
+        gtk_widget_hide ( widget );
         widget = g_object_get_data ( G_OBJECT ( account_page ), "Data_for_forecast" );
         gtk_widget_hide_all ( widget );
         widget = g_object_get_data ( G_OBJECT ( account_page ), "Data_for_historical" );
         gtk_widget_hide_all ( widget );
+        widget = g_object_get_data ( G_OBJECT ( account_page ), "Data_for_credit" );
+        gtk_widget_hide_all ( widget );
     }
 }
 
@@ -1182,7 +1214,6 @@ void bet_config_sensitive_account_parameters ( gint account_number, gboolean sen
  * */
 void bet_config_use_budget_toggle ( GtkToggleButton *button, GtkWidget *combo )
 {
-    GtkWidget *widget;
     gint account_number;
 
     account_number = gsb_account_get_combo_account_number ( combo );
@@ -1190,6 +1221,7 @@ void bet_config_use_budget_toggle ( GtkToggleButton *button, GtkWidget *combo )
     if ( gtk_toggle_button_get_active ( button ) )
     {
         gsb_data_account_set_bet_use_budget ( account_number, 1 );
+        gsb_data_account_set_bet_show_onglets ( account_number );
         bet_config_change_account ( combo );
 
         gsb_data_account_set_bet_maj ( account_number, BET_MAJ_ALL );
@@ -1198,12 +1230,7 @@ void bet_config_use_budget_toggle ( GtkToggleButton *button, GtkWidget *combo )
     {
         bet_data_remove_all_bet_data ( account_number );
         gsb_data_account_set_bet_use_budget ( account_number, 0 );
-        widget = g_object_get_data ( G_OBJECT ( account_page ), "Data_for_forecast" );
-        gtk_widget_hide_all ( widget );
-        widget = g_object_get_data ( G_OBJECT ( account_page ), "Data_for_historical" );
-        gtk_widget_hide_all ( widget );
-        widget = g_object_get_data ( G_OBJECT ( account_page ), "Data_for_credit" );
-        gtk_widget_hide_all ( widget );
+        bet_config_sensitive_account_parameters ( account_number, FALSE );
     }
 
     if ( gsb_gui_navigation_get_current_account ( ) == account_number )
@@ -1235,11 +1262,145 @@ GtkWidget *bet_config_account_get_finance_data ( gchar *title )
 
 
 /**
+ * called when entry changed
+ * check the entry and set the entry red/invalid if not a good number
  *
+ * \param entry
+ * \param parent
  *
- *
- *
+ * \return
  * */
+void bet_config_account_amount_entry_changed ( GtkWidget *entry,
+                        GtkWidget *parent )
+{
+    gboolean valide = FALSE;
+    const gchar *text;
+
+    text = gtk_entry_get_text ( GTK_ENTRY ( entry ) );
+    /* if nothing in the entry, keep the normal style */
+    if ( strlen ( text ) == 0 )
+    {
+        gtk_widget_modify_base ( entry, GTK_STATE_NORMAL, NULL );
+        return;
+    }
+
+    valide = gsb_form_widget_get_valide_amout_entry ( text );
+    if ( valide )
+    {
+        /* the entry is valid, make it normal */
+        gtk_widget_modify_base ( entry, GTK_STATE_NORMAL, NULL );
+    }
+    else
+    {
+        /* the entry is not valid, make it red */
+        gtk_widget_modify_base ( entry, GTK_STATE_NORMAL,
+                        gsb_color_get_couleur ( "entry_error_color" ) );
+    }
+}
+
+
+/**
+ * fonction appellée lorsqu'on change le type de taux
+ *
+ * \param togglebutton
+ * \param event
+ * \param parent        parent widget for callback
+ *
+ * \return
+ **/
+static void bet_config_account_type_taux_changed ( GtkWidget *togglebutton,
+                        GdkEventButton *event,
+                        GtkWidget *parent )
+{
+    gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( togglebutton ), TRUE );
+    bet_config_finance_apply_clicked ( NULL, parent );
+}
+
+
+/**
+ * function called when changing the start date
+ *
+ * \param entry         date entry
+ * \param event
+ * \param parent        parent widget for callback
+ *
+ * \return              TRUE to stop other handlers from being invoked for the event.
+ **/
+static gboolean bet_config_account_date_entry_lose_focus ( GtkWidget *entry,
+                        GdkEventFocus *event,
+                        GtkWidget *parent )
+{
+    if ( strlen ( gtk_entry_get_text ( GTK_ENTRY ( entry ) ) ) )
+    {
+        GDate *date = NULL;
+
+        date = gsb_calendar_entry_get_date ( entry );
+        if ( date && g_date_valid ( date ) )
+            bet_config_finance_apply_clicked ( NULL, parent );
+    }
+
+    return TRUE;
+}
+
+
+/**
+ * function called when changing the capital or fees
+ *
+ * \param entry         entry for capital
+ * \param event
+ * \param parent        parent widget for callback
+ *
+ * \return              TRUE to stop other handlers from being invoked for the event.
+ **/
+static gboolean bet_config_account_entry_lose_focus ( GtkWidget *entry,
+                        GdkEventFocus *event,
+                        GtkWidget *parent )
+{
+    const gchar *text;
+
+    text = gtk_entry_get_text ( GTK_ENTRY ( entry ) );
+    if ( strlen ( text ) )
+    {
+        if ( gsb_form_widget_get_valide_amout_entry ( text ) )
+            bet_config_finance_apply_clicked ( NULL, parent );
+    }
+
+    return TRUE;
+}
+
+
+/**
+ * called when we press the button in an entry field in the entry
+ *
+ * \param entry     wich receive the signal
+ * \param event     can be NULL
+ * \param parent    parent widget for callback
+ *
+ * \return TRUE or FALSE
+ * */
+static gboolean bet_config_account_date_key_press_event ( GtkWidget *entry,
+                        GdkEventKey *event,
+                        GtkWidget *parent )
+{
+    if (  event->keyval == GDK_Return || event->keyval == GDK_KP_Enter )
+    {
+        GtkWidget *widget;
+
+        widget = g_object_get_data ( G_OBJECT ( parent ), "bet_config_taux" );
+        gtk_widget_grab_focus ( widget );
+    }
+
+    return FALSE;
+}
+
+
+/**
+ * Create the amortization array
+ *
+ * \param parent    widget parent
+ *
+ * \return          Widget for options of amortization array
+ **/
 GtkWidget *bet_config_get_finance_widget ( GtkWidget *parent )
 {
     GtkWidget *vbox;
@@ -1248,9 +1409,6 @@ GtkWidget *bet_config_get_finance_widget ( GtkWidget *parent )
     GtkWidget *widget;
     GtkWidget *spin_button = NULL;
     GtkWidget *button_1, *button_2;
-    GtkWidget *align;
-    GtkWidget *image;
-    GtkWidget *button;
 
     vbox = gtk_vbox_new ( FALSE, 5 );
 
@@ -1267,10 +1425,6 @@ GtkWidget *bet_config_get_finance_widget ( GtkWidget *parent )
     gtk_widget_set_size_request ( widget, 90, -1 );
     g_object_set_data ( G_OBJECT ( parent ), "bet_config_capital", widget );
     gtk_box_pack_start ( GTK_BOX ( hbox ), widget, FALSE, FALSE, 5 );
-    g_signal_connect ( G_OBJECT ( widget ),
-                        "changed",
-                        G_CALLBACK ( gsb_form_widget_amount_entry_changed ),
-                        NULL );
 
     label = gtk_label_new ( NULL );
     g_object_set_data ( G_OBJECT ( parent ), "bet_config_capital_devise", label );
@@ -1296,7 +1450,7 @@ GtkWidget *bet_config_get_finance_widget ( GtkWidget *parent )
     hbox = gtk_hbox_new ( FALSE, 5 );
     gtk_box_pack_start ( GTK_BOX ( vbox ), hbox, FALSE, FALSE, 5);
 
-    label = gtk_label_new ( _("Date of first Repayment: ") );
+    label = gtk_label_new ( _("Date of first repayment: ") );
     gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 0.5);
     gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_LEFT );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, FALSE, FALSE, 5 );
@@ -1336,10 +1490,6 @@ GtkWidget *bet_config_get_finance_widget ( GtkWidget *parent )
     gtk_widget_set_size_request ( widget, 50, -1 );
     g_object_set_data ( G_OBJECT ( parent ), "bet_config_montant_frais", widget );
     gtk_box_pack_start ( GTK_BOX ( hbox ), widget, FALSE, FALSE, 5 );
-    g_signal_connect ( G_OBJECT ( widget ),
-                        "changed",
-                        G_CALLBACK ( gsb_form_widget_amount_entry_changed ),
-                        NULL );
 
     label = gtk_label_new ( NULL );
     g_object_set_data ( G_OBJECT ( parent ), "bet_config_frais_devise", label );
@@ -1355,6 +1505,7 @@ GtkWidget *bet_config_get_finance_widget ( GtkWidget *parent )
     gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_LEFT );
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, FALSE, FALSE, 5 );
     button_1 = gtk_radio_button_new_with_label ( NULL, _("CAGR") );
+    g_object_set_data ( G_OBJECT ( parent ), "bet_config_type_taux_1", button_1 );
     gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( button_1 ), TRUE );
 
     button_2 = gtk_radio_button_new_with_label_from_widget ( GTK_RADIO_BUTTON ( button_1 ),
@@ -1364,22 +1515,10 @@ GtkWidget *bet_config_get_finance_widget ( GtkWidget *parent )
     gtk_box_pack_start ( GTK_BOX ( hbox ), button_1, FALSE, FALSE, 5) ;
     gtk_box_pack_start ( GTK_BOX ( hbox ), button_2, FALSE, FALSE, 5) ;
 
-    /* Apply */
-    align = gtk_alignment_new (0.5, 0.0, 0.0, 0.0);
-    gtk_box_pack_start ( GTK_BOX ( vbox ), align, FALSE, FALSE, 5);
-
-    image = gtk_image_new_from_stock ( GTK_STOCK_APPLY, GTK_ICON_SIZE_BUTTON );
-    button = gtk_button_new_with_label ( _("Apply") );
-    gtk_button_set_image ( GTK_BUTTON ( button ), image );
-    gtk_button_set_relief ( GTK_BUTTON ( button ), GTK_RELIEF_NONE );
-    g_signal_connect ( G_OBJECT ( button ),
-                        "clicked",
-                        G_CALLBACK ( bet_config_finance_apply_clicked ),
-                        parent );
-
-    gtk_container_add ( GTK_CONTAINER ( align ), button );
     return vbox;
 }
+
+
 /**
  *
  *
@@ -1413,10 +1552,18 @@ void bet_config_initialise_finance_widget ( gint account_number,
     /* set capital */
     widget = g_object_get_data ( G_OBJECT ( parent ), "bet_config_capital" );
     gtk_entry_set_text ( GTK_ENTRY ( widget ),
-                        gsb_real_get_string_with_currency (
+                        utils_real_get_string_with_currency (
                         gsb_real_double_to_real (
                         gsb_data_account_get_bet_finance_capital ( account_number ) ),
                         devise, FALSE ) );
+    g_signal_connect ( G_OBJECT ( widget ),
+                        "changed",
+                        G_CALLBACK ( bet_config_account_amount_entry_changed ),
+                        parent );
+    g_signal_connect_after ( G_OBJECT (widget),
+                        "focus-out-event",
+                        G_CALLBACK ( bet_config_account_entry_lose_focus ),
+                        parent );
 
     /* set duration */
     nbre_ans = gsb_data_account_get_bet_months ( account_number ) / 12;
@@ -1427,29 +1574,63 @@ void bet_config_initialise_finance_widget ( gint account_number,
         gtk_label_set_label ( GTK_LABEL ( widget ), _(" year ") );
     else
         gtk_label_set_label ( GTK_LABEL ( widget ), _(" years ") );
+    g_signal_connect ( button,
+                        "value-changed",
+                        G_CALLBACK ( bet_config_finance_apply_clicked ),
+                        parent );
 
     /* set start_date */
     widget = g_object_get_data ( G_OBJECT ( parent ), "bet_config_start_date" );
     gsb_calendar_entry_set_date ( widget,
                         gsb_data_account_get_bet_start_date ( account_number ) );
+    g_signal_connect_after ( G_OBJECT (widget),
+                        "focus-out-event",
+                        G_CALLBACK ( bet_config_account_date_entry_lose_focus ),
+                        parent );
+    g_signal_connect ( G_OBJECT ( widget ),
+                       "key-press-event",
+                       G_CALLBACK ( bet_config_account_date_key_press_event ),
+                       parent );
 
     /* set taux */
     button = g_object_get_data ( G_OBJECT ( parent ), "bet_config_taux" );
     taux = gsb_data_account_get_bet_finance_taux_annuel ( account_number );
     gtk_spin_button_set_value ( GTK_SPIN_BUTTON ( button ), taux );
+    g_signal_connect ( button,
+                        "value-changed",
+                        G_CALLBACK ( bet_config_finance_apply_clicked ),
+                        parent );
 
     /* set frais */
     widget = g_object_get_data ( G_OBJECT ( parent ), "bet_config_montant_frais" );
     gtk_entry_set_text ( GTK_ENTRY ( widget ),
-                        gsb_real_get_string_with_currency (
+                        utils_real_get_string_with_currency (
                         gsb_real_double_to_real (
                         gsb_data_account_get_bet_finance_frais ( account_number ) ),
                         devise, FALSE ) );
+    g_signal_connect ( G_OBJECT ( widget ),
+                        "changed",
+                        G_CALLBACK ( bet_config_account_amount_entry_changed ),
+                        parent );
+    g_signal_connect_after ( G_OBJECT (widget),
+                        "focus-out-event",
+                        G_CALLBACK ( bet_config_account_entry_lose_focus ),
+                        parent );
 
     /* set type taux */
     button = g_object_get_data ( G_OBJECT ( parent ), "bet_config_type_taux" );
     gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( button ),
                         gsb_data_account_get_bet_finance_type_taux ( account_number ) );
+    g_signal_connect ( G_OBJECT ( button ),
+                        "button-release-event",
+                        G_CALLBACK ( bet_config_account_type_taux_changed ),
+                        parent );
+
+    button = g_object_get_data ( G_OBJECT ( parent ), "bet_config_type_taux_1" );
+    g_signal_connect ( G_OBJECT ( button ),
+                        "button-release-event",
+                        G_CALLBACK ( bet_config_account_type_taux_changed ),
+                        parent );
 }
 
 
@@ -1461,13 +1642,19 @@ void bet_config_initialise_finance_widget ( gint account_number,
  * */
 void bet_config_finance_apply_clicked ( GtkButton *button, GtkWidget *parent )
 {
-    GtkWidget *bouton;
+    GtkWidget *bouton, *widget;
     gdouble number;
     gint type_taux;
     gint account_number;
+    GDate *start_date;
 
     account_number = bet_config_get_account_from_combo ( );
 
+    /* start date */
+    widget = g_object_get_data ( G_OBJECT ( parent ), "bet_config_start_date" );
+    start_date = gsb_calendar_entry_get_date( widget );
+    gsb_data_account_set_bet_start_date( account_number, start_date );
+
     /* capital */
     number = bet_finance_get_number_from_string ( parent, "bet_config_capital" );
     gsb_data_account_set_bet_finance_capital ( account_number, number );
@@ -1499,8 +1686,7 @@ void bet_config_finance_apply_clicked ( GtkButton *button, GtkWidget *parent )
     type_taux = gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON ( bouton ) );
     gsb_data_account_set_bet_finance_type_taux ( account_number, type_taux );
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     bet_finance_ui_update_amortization_tab ( account_number );
 }
@@ -1512,6 +1698,85 @@ void bet_config_finance_apply_clicked ( GtkButton *button, GtkWidget *parent )
  *
  *
  * */
+static void bet_config_select_bank_card_toggle ( GtkToggleButton *button,
+                        GtkWidget *combo )
+{
+    gint account_number;
+
+    account_number = gsb_account_get_combo_account_number ( combo );
+
+    if ( gtk_toggle_button_get_active ( button ) )
+        gsb_data_account_set_bet_credit_card ( account_number, 1 );
+    else
+        gsb_data_account_set_bet_credit_card ( account_number, 0 );
+
+    gsb_data_account_set_bet_show_onglets (  account_number );
+    bet_config_change_account ( combo );
+
+    if ( gsb_gui_navigation_get_current_account ( ) == account_number )
+        bet_data_select_bet_pages ( account_number );
+}
+
+/**
+ * widget qui permet de dire que le compte concerné sert à gérer une carte
+ * bancaire à débit différé.
+ *
+ * \param
+ *
+ * \return hbox
+ * */
+static GtkWidget *bet_config_account_get_select_bank_card ( void )
+{
+    GtkWidget *hbox;
+    GtkWidget *button;
+    GtkWidget *combo;
+
+    /* partie de gestion des comptes cartes avec débit différé */
+    hbox = gtk_hbox_new ( FALSE, 0 );
+
+    button = gtk_check_button_new_with_label ( _("Account with deferred debit card") );
+    gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( button ), FALSE );
+    g_object_set_data ( G_OBJECT ( account_page ), "bet_credit_card_button", button );
+    gtk_box_pack_start ( GTK_BOX ( hbox ), button, FALSE, FALSE, 0 );
+
+    /* set the signal */
+    combo = g_object_get_data ( G_OBJECT ( account_page ), "account_combo" );
+    g_signal_connect ( G_OBJECT ( button ),
+                        "toggled",
+                        G_CALLBACK ( bet_config_select_bank_card_toggle ),
+                        combo );
+
+    /* return */
+    return hbox;
+}
+
+
+/**
+ * initialise l'option credit_card
+ *
+ * \param account_number
+ *
+ * \return
+ * */
+static void bet_config_initialise_select_bank_card ( gint account_number )
+{
+    GtkWidget *button;
+    gint active;
+
+    button = g_object_get_data ( G_OBJECT ( account_page ), "bet_credit_card_button" );
+    active = gsb_data_account_get_bet_credit_card ( account_number );
+
+    gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON ( button ), active );
+}
+
+
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ **/
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
