@@ -79,8 +79,9 @@ struct _transfert_data
     gint replace_account;           /* Account number or partial balance number */
     gint replace_transaction;       /* remplace la transaction plannifiée dans le compte principal */
     gint direct_debit;              /* si = 1 création de la transaction dans le compte principal */
-    GDate *date;                    /* dare de l'opération du compte principal */
+    GDate *date;                    /* date de l'opération du compte principal */
     GDate *date_bascule;            /* date de début de nouveau de mois dans le compte à débit différé */
+    gint main_last_banking_date;    /* force la date au dernier jour bancaire ouvrable du mois */
     gint main_payee_number;         /* tiers de l'opération du compte principal */
     gint main_payment_number;       /* moyen de payement de l'opération du compte principal */
     gint main_category_number;      /* catégorie de l'opération du compte principal */
