@@ -1,5 +1,8 @@
 #ifndef _DIALOG_H
 #define _DIALOG_H (1)
+
+#include <gtk/gtk.h>
+
 /* START_INCLUDE_H */
 /* END_INCLUDE_H */
 
@@ -15,27 +18,26 @@ struct conditional_message
 
 
 /* START_DECLARATION */
-G_MODULE_EXPORT void dialog_message ( gchar *label, ... );
+void dialog_message ( gchar *label, ... );
 void dialogue ( gchar *texte_dialogue );
 void dialogue_conditional_hint ( gchar *hint, gchar *text, gchar *var );
-G_MODULE_EXPORT void dialogue_error ( gchar *text );
+void dialogue_error ( gchar *text );
 void dialogue_error_brain_damage ();
-G_MODULE_EXPORT void dialogue_error_hint ( const gchar *text, gchar *hint );
+void dialogue_error_hint ( const gchar *text, gchar *hint );
 void dialogue_error_memory ();
 void dialogue_hint ( gchar *text, gchar *hint );
 const gchar *dialogue_hint_with_entry ( gchar *text, gchar *hint, gchar *entry_description );
-void dialogue_special ( GtkMessageType param, gchar *text );
 GtkWidget *dialogue_special_no_run ( GtkMessageType param,
                         GtkButtonsType buttons,
                         gchar *text );
 gboolean dialogue_update_struct_message ( GtkWidget *checkbox,
                         struct conditional_message *message );
-G_MODULE_EXPORT void dialogue_warning ( gchar *text );
+void dialogue_warning ( gchar *text );
 void dialogue_warning_hint ( gchar *text, gchar *hint );
-gchar *make_blue ( gchar *text );
+gchar *make_blue ( const gchar *text );
 gchar *make_hint ( const gchar *hint, const gchar *text );
-gchar *make_pango_attribut ( gchar *attribut, gchar *text );
-gchar *make_red ( gchar *text );
+gchar *make_pango_attribut ( gchar *attribut, const gchar *text );
+gchar *make_red ( const gchar *text );
 gboolean question_conditional_yes_no ( gchar *var );
 gint question_conditional_yes_no_get_no_struct ( struct conditional_message *msg,
                         gchar *name );
