@@ -26,7 +26,7 @@
 #endif
 
 #include "include.h"
-
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "export.h"
@@ -149,7 +149,9 @@ void export_accounts ( void )
 
     g_free ( extension );
     g_slist_free ( selected_accounts );
-    g_slist_free_full ( exported_accounts, ( GDestroyNotify ) expert_account_free_account_structure );
+    g_slist_foreach ( exported_accounts, ( GFunc ) expert_account_free_account_structure, NULL );
+    g_slist_free ( exported_accounts );
+/*     g_slist_free_full ( exported_accounts, ( GDestroyNotify ) expert_account_free_account_structure );  */
     gtk_widget_destroy ( dialog );
 }
 
@@ -161,7 +163,6 @@ void export_accounts ( void )
 GtkWidget * export_create_selection_page ( GtkWidget * assistant )
 {
     GtkWidget * view, * vbox, * padding_box, * sw;
-    GtkWidget *combo;
     GtkWidget *button;
     GtkWidget *button_select;
     GtkTreeViewColumn *column;
@@ -236,7 +237,7 @@ GtkWidget * export_create_selection_page ( GtkWidget * assistant )
                         G_CALLBACK ( export_account_all_toggled ),
                         view );
 
-    combo = gsb_automem_radiobutton3_new_with_title ( vbox,
+    gsb_automem_radiobutton3_new_with_title ( vbox,
 					    _("Select options to export" ),
 					    _("QIF format" ), _("CSV format" ), NULL,
 					    &etat.export_file_format,
@@ -321,11 +322,11 @@ GtkWidget * export_create_final_page ( GtkWidget * assistant )
 
     gtk_text_buffer_insert (buffer, &iter, "\n", -1 );
     gtk_text_buffer_insert_with_tags_by_name (buffer, &iter,
-					      _("Export setup terminated"), -1,
+					      _("Export settings completed successfully"), -1,
 					      "x-large", NULL);
     gtk_text_buffer_insert (buffer, &iter, "\n\n", -1 );
     gtk_text_buffer_insert (buffer, &iter,
-			    _("You have successfully set up data export into Grisbi.  Press the 'Close' button to actually export data."),
+			    _("Press the 'Close' button to finish the export."),
 			    -1 );
     gtk_text_buffer_insert (buffer, &iter, "\n\n", -1 );
 
@@ -442,7 +443,7 @@ GtkWidget * create_export_account_resume_page ( struct exported_account * accoun
     tmpstr = make_pango_attribut ( "size=\"x-large\"",
                         g_strdup_printf ( "Export of : %s",
                         gsb_data_account_get_name ( account -> account_nb ) ) );
-                        
+
     label = gtk_label_new ( NULL );
     gtk_misc_set_alignment ( GTK_MISC ( label ), 0, 0.5);
     gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_LEFT );
@@ -661,8 +662,7 @@ gboolean export_account_radiobutton_format_changed ( GtkWidget *checkbutton,
         value = GPOINTER_TO_INT ( g_object_get_data ( G_OBJECT ( checkbutton ), "pointer" ) );
         *pointeur = value;
 
-        if ( etat.modification_fichier == 0 )
-            modification_fichier ( TRUE );
+        gsb_file_set_modified ( TRUE );
     }
 
     return FALSE;
