@@ -34,8 +34,8 @@
 #endif
 
 #include "include.h"
-
-
+#include <gdk/gdkkeysyms.h>
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_account_property.h"
@@ -108,7 +108,14 @@ static void gsb_account_property_iban_set_iban ( const gchar *iban );
 static void gsb_account_property_iban_switch_bank_data ( gboolean sensitive );
 /*END_STATIC*/
 
-struct iso_13616_iban iso_13616_ibans [] = {
+struct iso_13616_iban
+{
+    gchar *locale;
+    gchar *iban;
+    gint nbre_char;
+};
+
+static struct iso_13616_iban iso_13616_ibans [] = {
     { "XX", "XXkk XXXX XXXX XXXX XXXX XXXX XXXX XXXX XX", 34 },
     { "AD", "ADkk BBBB SSSS CCCC CCCC CCCC", 24 },
     { "AT", "ATkk BBBB BCCC CCCC CCCC", 20 },
@@ -138,7 +145,7 @@ struct iso_13616_iban iso_13616_ibans [] = {
 };
 
 static GtkWidget *edit_bank_button = NULL;
-GtkWidget *detail_nom_compte = NULL;
+static GtkWidget *detail_nom_compte = NULL;
 static GtkWidget *detail_type_compte = NULL;
 static GtkWidget *detail_titulaire_compte = NULL;
 static GtkWidget *detail_adresse_titulaire = NULL;
@@ -174,11 +181,6 @@ enum origin
 };
 
 /*START_EXTERN*/
-extern gint mise_a_jour_fin_comptes_passifs;
-extern gint mise_a_jour_liste_comptes_accueil;
-extern gint mise_a_jour_liste_echeances_manuelles_accueil;
-extern gint mise_a_jour_soldes_minimaux;
-extern gsb_real null_real;
 /*END_EXTERN*/
 
 
@@ -228,7 +230,7 @@ GtkWidget *gsb_account_property_create_page ( void )
 
     /* création de la ligne des détails du compte */
     paddingbox = new_paddingbox_with_title (vbox, FALSE, _("Account details"));
-    
+
    /* création de la ligne du nom du compte */
     hbox = gtk_hbox_new ( FALSE, 6 );
     gtk_box_pack_start ( GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0 );
@@ -277,7 +279,7 @@ GtkWidget *gsb_account_property_create_page ( void )
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
-    detail_devise_compte = gsb_autofunc_currency_new (TRUE, 
+    detail_devise_compte = gsb_autofunc_currency_new (TRUE,
                         0,
                         G_CALLBACK (gsb_account_property_changed),
                         GINT_TO_POINTER (PROPERTY_CURRENCY),
@@ -336,6 +338,7 @@ GtkWidget *gsb_account_property_create_page ( void )
                         NULL,
                         G_CALLBACK (gsb_data_account_set_holder_address),
                         0 );
+    gtk_widget_set_size_request ( detail_adresse_titulaire, -1, 70 );
 
     /* now the checkbutton for different address */
     button_holder_address = gsb_autofunc_checkbutton_new (
@@ -378,14 +381,10 @@ GtkWidget *gsb_account_property_create_page ( void )
     gtk_size_group_add_widget ( GTK_SIZE_GROUP ( size_group ), label );
     gtk_box_pack_start ( GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
-    bank_list_combobox = gsb_bank_create_combobox ( 0,
-                        NULL,
-                        NULL,
-                        G_CALLBACK (gsb_data_account_set_bank),
-                        0 );
-    g_signal_connect ( G_OBJECT (bank_list_combobox),
+    bank_list_combobox = gsb_bank_create_combobox ( 0 );
+    g_signal_connect ( G_OBJECT ( bank_list_combobox ),
                         "changed",
-                        G_CALLBACK (gsb_account_property_changed_bank_label),
+                        G_CALLBACK ( gsb_account_property_changed_bank_label ),
                         NULL );
     gtk_box_pack_start ( GTK_BOX(hbox), bank_list_combobox, TRUE, TRUE, 0);
 
@@ -522,7 +521,7 @@ GtkWidget *gsb_account_property_create_page ( void )
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, FALSE, FALSE, 0 );
 
     detail_solde_init = gsb_autofunc_real_new ( null_real,
-                        G_CALLBACK (gsb_account_property_changed), 
+                        G_CALLBACK (gsb_account_property_changed),
                         GINT_TO_POINTER (PROPERTY_INIT_BALANCE),
                         G_CALLBACK (gsb_data_account_set_init_balance), 0);
     gtk_box_pack_start ( GTK_BOX ( hbox ), detail_solde_init, TRUE, TRUE, 0 );
@@ -538,7 +537,7 @@ GtkWidget *gsb_account_property_create_page ( void )
     gtk_box_pack_start ( GTK_BOX ( hbox ), label, FALSE, FALSE, 0 );
 
     detail_solde_mini_autorise = gsb_autofunc_real_new ( null_real,
-                        G_CALLBACK (gsb_account_property_changed), 
+                        G_CALLBACK (gsb_account_property_changed),
                         GINT_TO_POINTER (PROPERTY_WANTED_BALANCE),
                         G_CALLBACK (gsb_data_account_set_mini_balance_authorized),
                         0);
@@ -574,6 +573,8 @@ GtkWidget *gsb_account_property_create_page ( void )
                         NULL,
                         G_CALLBACK (gsb_data_account_set_comment),
                         0);
+
+    gtk_widget_set_size_request ( detail_commentaire, -1, 70 );
     gtk_container_add ( GTK_CONTAINER ( scrolled_window_text ), detail_commentaire );
 
     gtk_widget_show_all ( onglet );
@@ -725,6 +726,7 @@ gboolean gsb_account_property_changed ( GtkWidget *widget,
     switch (origin)
     {
     case PROPERTY_NAME:
+        gsb_navigation_update_account_label (account_number);
         gsb_gui_navigation_update_account ( account_number );
         break;
     case PROPERTY_CLOSED_ACCOUNT:
@@ -736,9 +738,9 @@ gboolean gsb_account_property_changed ( GtkWidget *widget,
                         SCHEDULED_FORM_ACCOUNT), FALSE );
 
         /* Replace trees contents. */
-        remplit_arbre_categ ();
-        remplit_arbre_imputation ();
-        payee_fill_tree ();
+        categories_fill_list ();
+        budgetary_lines_fill_list ();
+        payees_fill_list ();
         break;
 
     case PROPERTY_KIND:
@@ -764,10 +766,10 @@ gboolean gsb_account_property_changed ( GtkWidget *widget,
     }
 
     /* update main page */
-    mise_a_jour_liste_comptes_accueil = 1;
-    mise_a_jour_liste_echeances_manuelles_accueil = 1;
-    mise_a_jour_soldes_minimaux = 1;
-    mise_a_jour_fin_comptes_passifs = 1;
+    run.mise_a_jour_liste_comptes_accueil = TRUE;
+    run.mise_a_jour_liste_echeances_manuelles_accueil = TRUE;
+    run.mise_a_jour_soldes_minimaux = TRUE;
+    run.mise_a_jour_fin_comptes_passifs = TRUE;
 
     return FALSE;
 }
@@ -807,7 +809,7 @@ gboolean gsb_account_property_change_currency ( GtkWidget *combobox,
 				    new_currency_number );
 
     /* ask for the currency of the transactions */
-    tmpstr = g_strdup_printf ( _("You are changing the currency of the account, do you want to change the currency of the transactions too ?\n(yes will change all the transactions currency from %s to %s, all the transactions with another currency will stay the same).\n\nArchived and reconcilied transactions will be left unmodified."),
+    tmpstr = g_strdup_printf ( _("You are changing the currency of the account, do you want to change the currency of the transactions too?\n(yes will change all the transactions currency from %s to %s, all the transactions with another currency will stay the same).\n\nArchived and reconcilied transactions will be left unmodified."),
 				      gsb_data_currency_get_name (account_currency_number),
 				      gsb_data_currency_get_name (new_currency_number));
     result = question_yes_no_hint ( _("Change the transactions currency"),
@@ -1037,8 +1039,7 @@ gboolean gsb_account_property_iban_key_press_event ( GtkWidget *entry,
             current_account = gsb_gui_navigation_get_current_account ();
             gsb_data_account_set_bank_account_iban ( current_account, iban );
             gsb_account_property_iban_set_bank_from_iban ( iban );
-            if ( etat.modification_fichier == 0 )
-                modification_fichier ( TRUE );
+            gsb_file_set_modified ( TRUE );
         }
 
         if ( iban && strlen (iban) > 0 )
@@ -1095,8 +1096,7 @@ gboolean gsb_account_property_iban_focus_out_event ( GtkWidget *entry,
     {
         gsb_data_account_set_bank_account_iban ( current_account, iban );
         gsb_account_property_iban_set_bank_from_iban ( iban );
-        if ( etat.modification_fichier == 0 )
-            modification_fichier ( TRUE );
+        gsb_file_set_modified ( TRUE );
     }
 
     if ( iban && strlen (iban) > 0 )
@@ -1136,9 +1136,7 @@ gboolean gsb_account_property_iban_set_bank_from_iban ( gchar *iban )
     g_signal_handlers_block_by_func ( G_OBJECT ( bank_list_combobox ),
                         G_CALLBACK ( gsb_account_property_changed_bank_label ),
                         NULL );
-    gsb_bank_list_set_bank ( bank_list_combobox,
-                        bank_number,
-                        current_account );
+    gsb_bank_list_set_bank ( bank_list_combobox, bank_number );
     g_signal_handlers_unblock_by_func ( G_OBJECT ( bank_list_combobox ),
                         G_CALLBACK ( gsb_account_property_changed_bank_label ),
                         NULL );
@@ -1462,7 +1460,7 @@ gint gsb_account_property_iban_control_iban ( gchar *iban )
 
     tmp_str = g_strndup ( iban + 2, 2 );
     code_controle =  utils_str_atoi ( tmp_str );
-    
+
     if ( code_controle - reste == 0 )
         result = 1;
     else
@@ -1525,7 +1523,6 @@ gboolean gsb_account_property_focus_out ( GtkWidget *widget,
         gsb_scheduler_list_fill_list (gsb_scheduler_list_get_tree_view ());
 
         /*update the the view menu */
-        gsb_navigation_update_account_label (account_number);
         gsb_menu_update_accounts_in_menus ();
 
         /* update the name of accounts in form */
@@ -1533,9 +1530,9 @@ gboolean gsb_account_property_focus_out ( GtkWidget *widget,
                         SCHEDULED_FORM_ACCOUNT), FALSE );
 
         /* Replace trees contents. */
-        remplit_arbre_categ ();
-        remplit_arbre_imputation ();
-        payee_fill_tree ();
+        categories_fill_list ();
+        budgetary_lines_fill_list ();
+        payees_fill_list ();
         break;
     case PROPERTY_HOLDER_NAME:
         gsb_main_set_grisbi_title ( account_number );
@@ -1543,10 +1540,10 @@ gboolean gsb_account_property_focus_out ( GtkWidget *widget,
     }
 
     /* update main page */
-    mise_a_jour_liste_comptes_accueil = 1;
-    mise_a_jour_liste_echeances_manuelles_accueil = 1;
-    mise_a_jour_soldes_minimaux = 1;
-    mise_a_jour_fin_comptes_passifs = 1;
+    run.mise_a_jour_liste_comptes_accueil = TRUE;
+    run.mise_a_jour_liste_echeances_manuelles_accueil = TRUE;
+    run.mise_a_jour_soldes_minimaux = TRUE;
+    run.mise_a_jour_fin_comptes_passifs = TRUE;
 
     return FALSE;
 }
