@@ -31,25 +31,25 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_assistant_file.h"
+#include "affichage.h"
 #include "gsb_assistant.h"
 #include "gsb_automem.h"
 #include "gsb_bank.h"
 #include "gsb_category.h"
 #include "gsb_currency_config.h"
 #include "gsb_currency.h"
+#include "gsb_dirs.h"
 #include "gsb_file.h"
-#include "parametres.h"
 #include "gsb_select_icon.h"
 #include "import.h"
+#include "parametres.h"
 #include "traitement_variables.h"
-#include "utils_files.h"
-#include "utils_str.h"
 #include "utils.h"
-#include "affichage.h"
-#include "structures.h"
+#include "utils_str.h"
 #include "erreur.h"
 /*END_INCLUDE*/
 
@@ -70,7 +70,6 @@ static GtkWidget *gsb_assistant_file_page_finish ( GtkWidget *assistant,
 extern gchar *adresse_commune;
 extern gchar *nom_fichier_comptes;
 extern gchar *titre_fichier;
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 enum file_assistant_page
@@ -223,12 +222,12 @@ GtkResponseType gsb_assistant_file_run ( gboolean first_opening,
     gsb_category_assistant_create_categories (assistant);
 
     /* get the next assistant to launch */
-    launch_account_assistant = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON 
+    launch_account_assistant = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
                         (button_create_account_next));
     gtk_widget_destroy (assistant);
 
     /* initialise le logo accueil */
-    gsb_select_icon_set_logo_pixbuf ( 
+    gsb_select_icon_set_logo_pixbuf (
                         gsb_select_icon_get_default_logo_pixbuf ( ) );
 
     /* and now, launch the next assistant */
@@ -283,7 +282,7 @@ static GtkWidget *gsb_assistant_file_page_2 ( GtkWidget *assistant )
 	gtk_box_pack_start ( GTK_BOX ( paddingbox ), table, FALSE, FALSE, 0);
 
 	/* label account name */
-	label = gtk_label_new ( _("Accounts file title: ") );
+	label = gtk_label_new ( _("Name of accounting entity: ") );
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 1);
 	gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
 	gtk_table_attach ( GTK_TABLE ( table ), label, 0, 1, 0, 1,
@@ -292,7 +291,7 @@ static GtkWidget *gsb_assistant_file_page_2 ( GtkWidget *assistant )
 	/* need to declare filename_entry first for the next callback,
 	 * if no filename, set the title.gsb as default name */
 	if (!nom_fichier_comptes)
-	nom_fichier_comptes = g_strconcat ( my_get_gsb_file_default_dir (),
+	nom_fichier_comptes = g_strconcat ( gsb_dirs_get_default_dir (),
 			G_DIR_SEPARATOR_S, titre_fichier, ".gsb", NULL );
 	filename_entry = gsb_automem_entry_new (&nom_fichier_comptes,
 			NULL, NULL);
@@ -323,13 +322,21 @@ static GtkWidget *gsb_assistant_file_page_2 ( GtkWidget *assistant )
 			GTK_SHRINK | GTK_FILL, 0, 0, 0 );
 
     /* will we crypt the file ? */
-    button = gsb_automem_checkbutton_new ( _("Encrypt Grisbi file"),
-					   &(etat.crypt_file), G_CALLBACK (gsb_gui_encryption_toggled), NULL);
-    gtk_box_pack_start ( GTK_BOX ( paddingbox ), button,
-			 FALSE, FALSE, 0 );
+#ifdef HAVE_SSL
+    {
+        button = gsb_automem_checkbutton_new ( _("Encrypt Grisbi file"),
+                                               &(etat.crypt_file), G_CALLBACK (gsb_gui_encryption_toggled), NULL);
+        gtk_box_pack_start ( GTK_BOX ( paddingbox ), button,
+                             FALSE, FALSE, 0 );
 
-    if ( etat.crypt_file )
-        run.new_crypted_file = TRUE;
+        if ( etat.crypt_file )
+            run.new_crypted_file = TRUE;
+    }
+#else
+    {
+        run.new_crypted_file = FALSE;
+    }
+#endif
 
     /* date format */
     paddingbox = gsb_config_date_format_chosen ( vbox, GTK_ORIENTATION_HORIZONTAL );
@@ -476,7 +483,7 @@ static GtkWidget *gsb_assistant_file_page_finish ( GtkWidget *assistant,
     gtk_container_set_border_width ( GTK_CONTAINER (page),
 				     10 );
 
-    vbox = new_vbox_with_title_and_icon ( _("Configuration finished !"),
+    vbox = new_vbox_with_title_and_icon ( _("Configuration finished!"),
 					  "reconciliationlg.png" );
     gtk_box_pack_start ( GTK_BOX (page),
 			 vbox,
@@ -537,7 +544,7 @@ static gboolean gsb_assistant_file_change_title ( GtkWidget *title_entry,
      * else we don't touch the filename entry */
     last_title = g_object_get_data ( G_OBJECT (title_entry),
 				     "last_title");
-    last_filename = g_strconcat ( my_get_gsb_file_default_dir (),
+    last_filename = g_strconcat ( gsb_dirs_get_default_dir (),
 				  G_DIR_SEPARATOR_S,
 				  last_title,
 				  ".gsb",
@@ -562,7 +569,7 @@ static gboolean gsb_assistant_file_change_title ( GtkWidget *title_entry,
 
     if ( strlen ( gtk_entry_get_text (GTK_ENTRY (title_entry) ) ) )
     {
-	new_filename = g_strconcat ( my_get_gsb_file_default_dir (),
+	new_filename = g_strconcat ( gsb_dirs_get_default_dir (),
 				     G_DIR_SEPARATOR_S,
 				     gtk_entry_get_text (GTK_ENTRY (title_entry)),
 				     ".gsb",
@@ -570,7 +577,7 @@ static gboolean gsb_assistant_file_change_title ( GtkWidget *title_entry,
     }
     else
     {
-	new_filename = g_strconcat ( my_get_gsb_file_default_dir (),
+	new_filename = g_strconcat ( gsb_dirs_get_default_dir (),
 				     G_DIR_SEPARATOR_S,
 				     _("My accounts"),
 				     ".gsb",
@@ -600,7 +607,7 @@ static gboolean gsb_assistant_file_choose_filename ( GtkWidget *button,
     gchar *tmpstr;
 
     dialog = gtk_file_chooser_dialog_new ( _("Create filename"),
-					   GTK_WINDOW ( window ),
+					   GTK_WINDOW ( run.window ),
 					   GTK_FILE_CHOOSER_ACTION_SAVE,
 					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					   GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
