@@ -22,10 +22,10 @@
 
 /**
  * \file gsb_autofunc.c
- * this file groups some widget functions wich update value automatickly
+ * this file groups some widget functions which update value automatically
  * when the widget change
  * a change in the widget call a given function of kind gsb_data_..._set_... ( number, value )
- * use to set automatickly the content in the grisbi structures
+ * use to set automatically the content in the grisbi structures
  * (for changes only on variables, see gsb_automem.c)
  */
 
@@ -46,9 +46,11 @@
 #include "gsb_data_category.h"
 #include "gsb_data_fyear.h"
 #include "gsb_data_reconcile.h"
+#include "gsb_file.h"
 #include "utils_editables.h"
 #include "gsb_real.h"
 #include "traitement_variables.h"
+#include "utils_real.h"
 #include "utils_str.h"
 #include "structures.h"
 /*END_INCLUDE*/
@@ -76,7 +78,6 @@ static gboolean gsb_autofunc_textview_changed ( GtkTextBuffer *buffer,
 
 
 /*START_EXTERN*/
-extern gsb_real null_real;
 /*END_EXTERN*/
 
 
@@ -124,18 +125,18 @@ GtkWidget *gsb_autofunc_entry_new ( const gchar *value,
     g_object_set_data ( G_OBJECT (entry),
 			"number_for_func", GINT_TO_POINTER (number_for_func));
     if (default_func)
-	g_object_set_data ( G_OBJECT ( entry ), "changed", 
+	g_object_set_data ( G_OBJECT ( entry ), "changed",
 			    (gpointer) g_signal_connect_after (G_OBJECT(entry), "changed",
 							       G_CALLBACK (gsb_autofunc_entry_changed), default_func ));
     if ( hook )
-	g_object_set_data ( G_OBJECT ( entry ), "changed-hook", 
+	g_object_set_data ( G_OBJECT ( entry ), "changed-hook",
 			    (gpointer) g_signal_connect_after (G_OBJECT(entry), "changed",
 							       G_CALLBACK (hook), data ));
     return entry;
 }
 
 
-/** 
+/**
  * set the value in a gsb_editable_entry
  * a value is in 2 parts :
  * 	a string, wich be showed in the entry
@@ -154,11 +155,11 @@ void gsb_autofunc_entry_set_value ( GtkWidget *entry,
     /* Block everything */
     if ( g_object_get_data (G_OBJECT (entry), "changed") > 0 )
 	g_signal_handler_block ( G_OBJECT(entry),
-				 (gulong) g_object_get_data (G_OBJECT (entry), 
+				 (gulong) g_object_get_data (G_OBJECT (entry),
 							     "changed"));
     if ( g_object_get_data (G_OBJECT (entry), "changed-hook") > 0 )
 	g_signal_handler_block ( G_OBJECT(entry),
-				 (gulong) g_object_get_data (G_OBJECT (entry), 
+				 (gulong) g_object_get_data (G_OBJECT (entry),
 							     "changed-hook"));
 
     /* Fill in value */
@@ -173,11 +174,11 @@ void gsb_autofunc_entry_set_value ( GtkWidget *entry,
     /* Unblock everything */
     if ( g_object_get_data (G_OBJECT (entry), "changed") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(entry),
-				   (gulong) g_object_get_data (G_OBJECT (entry), 
+				   (gulong) g_object_get_data (G_OBJECT (entry),
 							       "changed"));
     if ( g_object_get_data (G_OBJECT (entry), "changed-hook") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(entry),
-				   (gulong) g_object_get_data (G_OBJECT (entry), 
+				   (gulong) g_object_get_data (G_OBJECT (entry),
 							       "changed-hook"));
 }
 
@@ -206,8 +207,7 @@ static gboolean gsb_autofunc_entry_changed ( GtkWidget *entry,
 		   gtk_entry_get_text ( GTK_ENTRY (entry)));
 
     /* Mark file as modified */
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     return FALSE;
 }
@@ -264,7 +264,7 @@ GtkWidget *gsb_autofunc_textview_new ( const gchar *value,
 }
 
 
-/** 
+/**
  * set the value in a gsb_editable_text_area
  * a value is in 2 parts :
  * 	a string, wich be showed in the text_view
@@ -288,7 +288,7 @@ void gsb_autofunc_textview_set_value ( GtkWidget *text_view,
 				 (gulong) g_object_get_data ( G_OBJECT(buffer), "changed" ));
     if ( g_object_get_data (G_OBJECT(buffer), "changed-hook") > 0 )
 	g_signal_handler_block ( G_OBJECT(buffer),
-				 (gulong) g_object_get_data ( G_OBJECT(buffer), 
+				 (gulong) g_object_get_data ( G_OBJECT(buffer),
 							      "changed-hook" ));
 
     /* Fill in value */
@@ -303,11 +303,11 @@ void gsb_autofunc_textview_set_value ( GtkWidget *text_view,
     /* Unblock everything */
     if ( g_object_get_data (G_OBJECT(buffer), "changed") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(buffer),
-				   (gulong) g_object_get_data ( G_OBJECT(buffer), 
+				   (gulong) g_object_get_data ( G_OBJECT(buffer),
 								"changed" ));
     if ( g_object_get_data (G_OBJECT(buffer), "change-hook") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(buffer),
-				   (gulong) g_object_get_data ( G_OBJECT(buffer), 
+				   (gulong) g_object_get_data ( G_OBJECT(buffer),
 								"change-hook" ));
 }
 
@@ -337,8 +337,7 @@ static gboolean gsb_autofunc_textview_changed ( GtkTextBuffer *buffer,
 		   gtk_text_buffer_get_text (buffer, &start, &end, 0));
 
     /* Mark file as modified */
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     return FALSE;
 }
@@ -389,18 +388,18 @@ GtkWidget *gsb_autofunc_int_new ( gint value,
     g_object_set_data ( G_OBJECT (entry),
 			"number_for_func", GINT_TO_POINTER (number_for_func));
     if (default_func)
-	g_object_set_data ( G_OBJECT ( entry ), "changed", 
+	g_object_set_data ( G_OBJECT ( entry ), "changed",
 			    (gpointer) g_signal_connect_after (G_OBJECT(entry), "changed",
 							       ((GCallback) gsb_autofunc_int_changed), default_func ));
     if ( hook )
-	g_object_set_data ( G_OBJECT ( entry ), "changed-hook", 
+	g_object_set_data ( G_OBJECT ( entry ), "changed-hook",
 			    (gpointer) g_signal_connect_after (G_OBJECT(entry), "changed",
 							       ((GCallback) hook), data ));
     return entry;
 }
 
 
-/** 
+/**
  * set the value in a gsb_editable_int_entry
  * a value is in 2 parts :
  * 	a string, wich be showed in the entry
@@ -421,11 +420,11 @@ void gsb_autofunc_int_set_value ( GtkWidget *entry,
     /* Block everything */
     if ( g_object_get_data (G_OBJECT (entry), "changed") > 0 )
 	g_signal_handler_block ( G_OBJECT(entry),
-				 (gulong) g_object_get_data (G_OBJECT (entry), 
+				 (gulong) g_object_get_data (G_OBJECT (entry),
 							     "changed"));
     if ( g_object_get_data (G_OBJECT (entry), "changed-hook") > 0 )
 	g_signal_handler_block ( G_OBJECT(entry),
-				 (gulong) g_object_get_data (G_OBJECT (entry), 
+				 (gulong) g_object_get_data (G_OBJECT (entry),
 							     "changed-hook"));
 
     /* Fill in value */
@@ -439,11 +438,11 @@ void gsb_autofunc_int_set_value ( GtkWidget *entry,
     /* Unblock everything */
     if ( g_object_get_data (G_OBJECT (entry), "changed") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(entry),
-				   (gulong) g_object_get_data (G_OBJECT (entry), 
+				   (gulong) g_object_get_data (G_OBJECT (entry),
 							       "changed"));
     if ( g_object_get_data (G_OBJECT (entry), "changed-hook") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(entry),
-				   (gulong) g_object_get_data (G_OBJECT (entry), 
+				   (gulong) g_object_get_data (G_OBJECT (entry),
 							       "changed-hook"));
 }
 
@@ -463,11 +462,11 @@ void gsb_autofunc_int_erase_entry ( GtkWidget *entry )
     /* Block everything */
     if ( g_object_get_data (G_OBJECT (entry), "changed") > 0 )
 	g_signal_handler_block ( G_OBJECT(entry),
-				 (gulong) g_object_get_data (G_OBJECT (entry), 
+				 (gulong) g_object_get_data (G_OBJECT (entry),
 							     "changed"));
     if ( g_object_get_data (G_OBJECT (entry), "changed-hook") > 0 )
 	g_signal_handler_block ( G_OBJECT(entry),
-				 (gulong) g_object_get_data (G_OBJECT (entry), 
+				 (gulong) g_object_get_data (G_OBJECT (entry),
 							     "changed-hook"));
 
     /* Fill in value */
@@ -480,11 +479,11 @@ void gsb_autofunc_int_erase_entry ( GtkWidget *entry )
     /* Unblock everything */
     if ( g_object_get_data (G_OBJECT (entry), "changed") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(entry),
-				   (gulong) g_object_get_data (G_OBJECT (entry), 
+				   (gulong) g_object_get_data (G_OBJECT (entry),
 							       "changed"));
     if ( g_object_get_data (G_OBJECT (entry), "changed-hook") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(entry),
-				   (gulong) g_object_get_data (G_OBJECT (entry), 
+				   (gulong) g_object_get_data (G_OBJECT (entry),
 							       "changed-hook"));
 }
 
@@ -512,8 +511,7 @@ static gboolean gsb_autofunc_int_changed ( GtkWidget *entry,
 		   utils_str_atoi (gtk_entry_get_text ( GTK_ENTRY (entry))));
 
     /* Mark file as modified */
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     return FALSE;
 }
@@ -565,18 +563,18 @@ GtkWidget *gsb_autofunc_spin_new ( gint value,
     g_object_set_data ( G_OBJECT (spin_button),
 			"number_for_func", GINT_TO_POINTER (number_for_func));
     if (default_func)
-	g_object_set_data ( G_OBJECT (spin_button), "changed", 
+	g_object_set_data ( G_OBJECT (spin_button), "changed",
 			    (gpointer) g_signal_connect_after (G_OBJECT(spin_button), "value-changed",
 							       G_CALLBACK (gsb_autofunc_spin_changed), default_func ));
     if ( hook )
-	g_object_set_data ( G_OBJECT (spin_button), "changed-hook", 
+	g_object_set_data ( G_OBJECT (spin_button), "changed-hook",
 			    (gpointer) g_signal_connect_after (G_OBJECT(spin_button), "value-changed",
 							       G_CALLBACK ( hook), data ));
     return spin_button;
 }
 
 
-/** 
+/**
  * set the value in a autofunc_spin entry
  * a value is in 2 parts :
  * 	a gint, wich be showed in the spint button
@@ -595,11 +593,11 @@ void gsb_autofunc_spin_set_value ( GtkWidget *spin_button,
     /* Block everything */
     if ( g_object_get_data (G_OBJECT (spin_button), "changed") > 0 )
 	g_signal_handler_block ( G_OBJECT(spin_button),
-				 (gulong) g_object_get_data (G_OBJECT (spin_button), 
+				 (gulong) g_object_get_data (G_OBJECT (spin_button),
 							     "changed"));
     if ( g_object_get_data (G_OBJECT (spin_button), "changed-hook") > 0 )
 	g_signal_handler_block ( G_OBJECT(spin_button),
-				 (gulong) g_object_get_data (G_OBJECT (spin_button), 
+				 (gulong) g_object_get_data (G_OBJECT (spin_button),
 							     "changed-hook"));
 
     /* Fill in value */
@@ -612,11 +610,11 @@ void gsb_autofunc_spin_set_value ( GtkWidget *spin_button,
     /* Unblock everything */
     if ( g_object_get_data (G_OBJECT (spin_button), "changed") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(spin_button),
-				   (gulong) g_object_get_data (G_OBJECT (spin_button), 
+				   (gulong) g_object_get_data (G_OBJECT (spin_button),
 							       "changed"));
     if ( g_object_get_data (G_OBJECT (spin_button), "changed-hook") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(spin_button),
-				   (gulong) g_object_get_data (G_OBJECT (spin_button), 
+				   (gulong) g_object_get_data (G_OBJECT (spin_button),
 							       "changed-hook"));
 }
 
@@ -645,8 +643,7 @@ static gboolean gsb_autofunc_spin_changed ( GtkWidget *spin_button,
 		   gtk_spin_button_get_value_as_int ( GTK_SPIN_BUTTON (spin_button)));
 
     /* Mark file as modified */
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
     return FALSE;
 }
 
@@ -693,18 +690,18 @@ GtkWidget *gsb_autofunc_checkbutton_new ( const gchar *label,
     g_object_set_data ( G_OBJECT (button),
 			"number_for_func", GINT_TO_POINTER (number_for_func));
     if (default_func)
-	g_object_set_data ( G_OBJECT (button), "changed", 
+	g_object_set_data ( G_OBJECT (button), "changed",
 			    (gpointer) g_signal_connect_after (G_OBJECT(button), "toggled",
 							       ((GCallback) gsb_autofunc_checkbutton_changed), default_func ));
     if ( hook )
-	g_object_set_data ( G_OBJECT (button), "changed-hook", 
+	g_object_set_data ( G_OBJECT (button), "changed-hook",
 			    (gpointer) g_signal_connect_after (G_OBJECT(button), "toggled",
 							       ((GCallback) hook), data ));
     return button;
 }
 
 
-/** 
+/**
  * set the value in a gsb_editable_checkbutton
  * a value is in 2 parts :
  * 	a boolean, so value TRUE or FALSE
@@ -723,11 +720,11 @@ void gsb_autofunc_checkbutton_set_value ( GtkWidget *button,
     /* Block everything */
     if ( g_object_get_data (G_OBJECT (button), "changed") > 0 )
 	g_signal_handler_block ( G_OBJECT(button),
-				 (gulong) g_object_get_data (G_OBJECT (button), 
+				 (gulong) g_object_get_data (G_OBJECT (button),
 							     "changed"));
     if ( g_object_get_data (G_OBJECT (button), "changed-hook") > 0 )
 	g_signal_handler_block ( G_OBJECT(button),
-				 (gulong) g_object_get_data (G_OBJECT (button), 
+				 (gulong) g_object_get_data (G_OBJECT (button),
 							     "changed-hook"));
 
     /* Fill in value */
@@ -739,11 +736,11 @@ void gsb_autofunc_checkbutton_set_value ( GtkWidget *button,
     /* Unblock everything */
     if ( g_object_get_data (G_OBJECT (button), "changed") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(button),
-				   (gulong) g_object_get_data (G_OBJECT (button), 
+				   (gulong) g_object_get_data (G_OBJECT (button),
 							       "changed"));
     if ( g_object_get_data (G_OBJECT (button), "changed-hook") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(button),
-				   (gulong) g_object_get_data (G_OBJECT (button), 
+				   (gulong) g_object_get_data (G_OBJECT (button),
 							       "changed-hook"));
 }
 
@@ -772,8 +769,7 @@ static gboolean gsb_autofunc_checkbutton_changed ( GtkWidget *button,
 		   gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)));
 
     /* Mark file as modified */
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     return FALSE;
 }
@@ -798,7 +794,7 @@ static gboolean gsb_autofunc_checkbutton_changed ( GtkWidget *button,
  * \param data optional data to send to hook
  * \param default_func The function to call to change the value in memory (function must be func ( number, gboolean ) ) or NULL
  * \param number_for_func a gint wich we be used to call default_func (will be saved as g_object_set_data with "number_for_func")
- * 
+ *
  * \return a vbox with the 2 radiobuttons
  *
  */
@@ -816,7 +812,7 @@ GtkWidget *gsb_autofunc_radiobutton_new ( const gchar *choice1,
 
     button1 = gtk_radio_button_new_with_mnemonic ( NULL, choice1 );
     gtk_box_pack_start (GTK_BOX(vbox), button1, FALSE, FALSE, 0 );
-    button2 = gtk_radio_button_new_with_mnemonic ( gtk_radio_button_get_group (GTK_RADIO_BUTTON(button1)), 
+    button2 = gtk_radio_button_new_with_mnemonic ( gtk_radio_button_get_group (GTK_RADIO_BUTTON(button1)),
 						   choice2 );
     gtk_box_pack_start (GTK_BOX(vbox), button2, FALSE, FALSE, 0 );
 
@@ -844,7 +840,7 @@ GtkWidget *gsb_autofunc_radiobutton_new ( const gchar *choice1,
 
 
 
-/** 
+/**
  * set the value in a gsb_editable_checkbutton
  * a value is in 2 parts :
  * 	a boolean, 0 to active the first button, 1 for the second
@@ -868,11 +864,11 @@ GtkWidget *gsb_autofunc_radiobutton_new ( const gchar *choice1,
     // Block everything, the signals were on button2
     if ( g_object_get_data (G_OBJECT (button2), "changed") > 0 )
 	g_signal_handler_block ( G_OBJECT(button2),
-				 (gulong) g_object_get_data (G_OBJECT (button2), 
+				 (gulong) g_object_get_data (G_OBJECT (button2),
 							     "changed"));
     if ( g_object_get_data (G_OBJECT (button2), "changed-hook") > 0 )
 	g_signal_handler_block ( G_OBJECT(button2),
-				 (gulong) g_object_get_data (G_OBJECT (button2), 
+				 (gulong) g_object_get_data (G_OBJECT (button2),
 							     "changed-hook"));
 
     // Fill in value
@@ -887,11 +883,11 @@ GtkWidget *gsb_autofunc_radiobutton_new ( const gchar *choice1,
     // Unblock everything
     if ( g_object_get_data (G_OBJECT (button2), "changed") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(button2),
-				   (gulong) g_object_get_data (G_OBJECT (button2), 
+				   (gulong) g_object_get_data (G_OBJECT (button2),
 							       "changed"));
     if ( g_object_get_data (G_OBJECT (button2), "changed-hook") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(button2),
-				   (gulong) g_object_get_data (G_OBJECT (button2), 
+				   (gulong) g_object_get_data (G_OBJECT (button2),
 							       "changed-hook"));
 }*/
 
@@ -942,18 +938,18 @@ GtkWidget *gsb_autofunc_date_new ( const GDate *date,
     g_object_set_data ( G_OBJECT (entry),
 			"number_for_func", GINT_TO_POINTER (number_for_func));
     if (default_func)
-	g_object_set_data ( G_OBJECT ( entry ), "changed", 
+	g_object_set_data ( G_OBJECT ( entry ), "changed",
 			    (gpointer) g_signal_connect_after (G_OBJECT(entry), "changed",
 							       G_CALLBACK (gsb_autofunc_date_changed), default_func ));
     if ( hook )
-	g_object_set_data ( G_OBJECT ( entry ), "changed-hook", 
+	g_object_set_data ( G_OBJECT ( entry ), "changed-hook",
 			    (gpointer) g_signal_connect_after (G_OBJECT(entry), "changed",
 							       G_CALLBACK (hook), data ));
     return entry;
 }
 
 
-/** 
+/**
  * set the date in a gsb_editable_date
  * a value is in 2 parts :
  * 	a date, wich be showed in the entry
@@ -972,11 +968,11 @@ void gsb_autofunc_date_set ( GtkWidget *entry,
     /* Block everything */
     if ( g_object_get_data (G_OBJECT (entry), "changed") > 0 )
 	g_signal_handler_block ( G_OBJECT(entry),
-				 (gulong) g_object_get_data (G_OBJECT (entry), 
+				 (gulong) g_object_get_data (G_OBJECT (entry),
 							     "changed"));
     if ( g_object_get_data (G_OBJECT (entry), "changed-hook") > 0 )
 	g_signal_handler_block ( G_OBJECT(entry),
-				 (gulong) g_object_get_data (G_OBJECT (entry), 
+				 (gulong) g_object_get_data (G_OBJECT (entry),
 							     "changed-hook"));
 
     /* Fill in value */
@@ -989,11 +985,11 @@ void gsb_autofunc_date_set ( GtkWidget *entry,
     /* Unblock everything */
     if ( g_object_get_data (G_OBJECT (entry), "changed") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(entry),
-				   (gulong) g_object_get_data (G_OBJECT (entry), 
+				   (gulong) g_object_get_data (G_OBJECT (entry),
 							       "changed"));
     if ( g_object_get_data (G_OBJECT (entry), "changed-hook") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(entry),
-				   (gulong) g_object_get_data (G_OBJECT (entry), 
+				   (gulong) g_object_get_data (G_OBJECT (entry),
 							       "changed-hook"));
 }
 
@@ -1028,8 +1024,7 @@ static gboolean gsb_autofunc_date_changed ( GtkWidget *entry,
 	g_date_free (date);
 
     /* Mark file as modified */
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     return FALSE;
 }
@@ -1070,7 +1065,7 @@ GtkWidget *gsb_autofunc_real_new ( gsb_real real,
     /* first, create and fill the entry */
     entry = gtk_entry_new ();
 
-    string = gsb_real_get_string (real);
+    string = utils_real_get_string (real);
     gtk_entry_set_text ( GTK_ENTRY (entry), string );
     g_free (string);
 
@@ -1080,18 +1075,18 @@ GtkWidget *gsb_autofunc_real_new ( gsb_real real,
     g_object_set_data ( G_OBJECT (entry),
 			"number_for_func", GINT_TO_POINTER (number_for_func));
     if (default_func)
-	g_object_set_data ( G_OBJECT ( entry ), "changed", 
+	g_object_set_data ( G_OBJECT ( entry ), "changed",
 			    (gpointer) g_signal_connect_after (G_OBJECT(entry), "changed",
 							       G_CALLBACK (gsb_autofunc_real_changed), default_func ));
     if ( hook )
-	g_object_set_data ( G_OBJECT ( entry ), "changed-hook", 
+	g_object_set_data ( G_OBJECT ( entry ), "changed-hook",
 			    (gpointer) g_signal_connect_after (G_OBJECT(entry), "changed",
 							       G_CALLBACK (hook), data ));
     return entry;
 }
 
 
-/** 
+/**
  * set the gsb_real in a gsb_editable_date
  * a value is in 2 parts :
  * 	a date, wich be showed in the entry
@@ -1112,15 +1107,15 @@ void gsb_autofunc_real_set ( GtkWidget *entry,
     /* Block everything */
     if ( g_object_get_data (G_OBJECT (entry), "changed") > 0 )
 	g_signal_handler_block ( G_OBJECT(entry),
-				 (gulong) g_object_get_data (G_OBJECT (entry), 
+				 (gulong) g_object_get_data (G_OBJECT (entry),
 							     "changed"));
     if ( g_object_get_data (G_OBJECT (entry), "changed-hook") > 0 )
 	g_signal_handler_block ( G_OBJECT(entry),
-				 (gulong) g_object_get_data (G_OBJECT (entry), 
+				 (gulong) g_object_get_data (G_OBJECT (entry),
 							     "changed-hook"));
 
     /* Fill in value */
-    string = gsb_real_get_string (real);
+    string = utils_real_get_string (real);
     gtk_entry_set_text ( GTK_ENTRY (entry), string );
     g_free (string);
 
@@ -1130,11 +1125,11 @@ void gsb_autofunc_real_set ( GtkWidget *entry,
     /* Unblock everything */
     if ( g_object_get_data (G_OBJECT (entry), "changed") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(entry),
-				   (gulong) g_object_get_data (G_OBJECT (entry), 
+				   (gulong) g_object_get_data (G_OBJECT (entry),
 							       "changed"));
     if ( g_object_get_data (G_OBJECT (entry), "changed-hook") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(entry),
-				   (gulong) g_object_get_data (G_OBJECT (entry), 
+				   (gulong) g_object_get_data (G_OBJECT (entry),
 							       "changed-hook"));
 }
 
@@ -1160,11 +1155,10 @@ static gboolean gsb_autofunc_real_changed ( GtkWidget *entry,
 
     number_for_func = GPOINTER_TO_INT ( g_object_get_data (G_OBJECT (entry), "number_for_func"));
     default_func ( number_for_func,
-		   gsb_real_get_from_string (gtk_entry_get_text (GTK_ENTRY (entry))));
+		   utils_real_get_from_string (gtk_entry_get_text (GTK_ENTRY (entry))));
 
     /* Mark file as modified */
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
     return FALSE;
 }
 
@@ -1216,18 +1210,18 @@ GtkWidget *gsb_autofunc_combobox_new ( GSList *list,
     g_object_set_data ( G_OBJECT (combobox),
 			"number_for_func", GINT_TO_POINTER (number_for_func));
     if (default_func)
-	g_object_set_data ( G_OBJECT (combobox), "changed", 
+	g_object_set_data ( G_OBJECT (combobox), "changed",
 			    (gpointer) g_signal_connect_after (G_OBJECT(combobox), "changed",
 							       G_CALLBACK (gsb_autofunc_combobox_changed), default_func ));
     if ( hook )
-	g_object_set_data ( G_OBJECT (combobox), "changed-hook", 
+	g_object_set_data ( G_OBJECT (combobox), "changed-hook",
 			    (gpointer) g_signal_connect_after (G_OBJECT(combobox), "changed",
 							       G_CALLBACK (hook), data ));
     return combobox;
 }
 
 
-/** 
+/**
  * set the value in a gsb_autofunc_combobox
  * a value is in 2 parts :
  * 	an index, wich place the combobox on the good place
@@ -1246,11 +1240,11 @@ void gsb_autofunc_combobox_set_index ( GtkWidget *combobox,
     /* Block everything */
     if ( g_object_get_data (G_OBJECT (combobox), "changed") > 0 )
 	g_signal_handler_block ( G_OBJECT(combobox),
-				 (gulong) g_object_get_data (G_OBJECT (combobox), 
+				 (gulong) g_object_get_data (G_OBJECT (combobox),
 							     "changed"));
     if ( g_object_get_data (G_OBJECT (combobox), "changed-hook") > 0 )
 	g_signal_handler_block ( G_OBJECT(combobox),
-				 (gulong) g_object_get_data (G_OBJECT (combobox), 
+				 (gulong) g_object_get_data (G_OBJECT (combobox),
 							     "changed-hook"));
 
     /* place the combobox */
@@ -1262,11 +1256,11 @@ void gsb_autofunc_combobox_set_index ( GtkWidget *combobox,
     /* Unblock everything */
     if ( g_object_get_data (G_OBJECT (combobox), "changed") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(combobox),
-				   (gulong) g_object_get_data (G_OBJECT (combobox), 
+				   (gulong) g_object_get_data (G_OBJECT (combobox),
 							       "changed"));
     if ( g_object_get_data (G_OBJECT (combobox), "changed-hook") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(combobox),
-				   (gulong) g_object_get_data (G_OBJECT (combobox), 
+				   (gulong) g_object_get_data (G_OBJECT (combobox),
 							       "changed-hook"));
 }
 
@@ -1294,8 +1288,7 @@ static gboolean gsb_autofunc_combobox_changed ( GtkWidget *combobox,
 		   gsb_combo_box_get_index (combobox));
 
     /* Mark file as modified */
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
     return FALSE;
 }
 
@@ -1326,7 +1319,7 @@ static gboolean gsb_autofunc_combobox_changed ( GtkWidget *combobox,
  * \param number_for_func a gint wich we be used to call default_func (will be saved as g_object_set_data with "number_for_func")
  * 				that number can be changed with gsb_autofunc_currency_set_currency_number
  *
- * \return a new GtkComboBox 
+ * \return a new GtkComboBox
  * */
 GtkWidget *gsb_autofunc_currency_new ( gboolean set_name,
 				       gint currency_number,
@@ -1350,18 +1343,18 @@ GtkWidget *gsb_autofunc_currency_new ( gboolean set_name,
             "number_for_func", GINT_TO_POINTER (number_for_func));
 
     if (default_func)
-    g_object_set_data ( G_OBJECT (combobox), "changed", 
+    g_object_set_data ( G_OBJECT (combobox), "changed",
                     (gpointer) g_signal_connect_after (G_OBJECT(combobox), "changed",
                     G_CALLBACK (gsb_autofunc_currency_changed), default_func ));
     if ( hook )
-    g_object_set_data ( G_OBJECT (combobox), "changed-hook", 
+    g_object_set_data ( G_OBJECT (combobox), "changed-hook",
                     (gpointer) g_signal_connect_after (G_OBJECT(combobox), "changed",
                     G_CALLBACK (hook), data ));
      return combobox;
 }
 
 
-/** 
+/**
  * show the currency in a gsb_autofunc_currency
  * a value is in 2 parts :
  * 	an currency number, wich place the combobox on the good place
@@ -1380,11 +1373,11 @@ void gsb_autofunc_currency_set_currency_number ( GtkWidget *combobox,
     /* Block everything */
     if ( g_object_get_data (G_OBJECT (combobox), "changed") > 0 )
 	g_signal_handler_block ( G_OBJECT(combobox),
-				 (gulong) g_object_get_data (G_OBJECT (combobox), 
+				 (gulong) g_object_get_data (G_OBJECT (combobox),
 							     "changed"));
     if ( g_object_get_data (G_OBJECT (combobox), "changed-hook") > 0 )
 	g_signal_handler_block ( G_OBJECT(combobox),
-				 (gulong) g_object_get_data (G_OBJECT (combobox), 
+				 (gulong) g_object_get_data (G_OBJECT (combobox),
 							     "changed-hook"));
 
     /* place the combobox */
@@ -1396,11 +1389,11 @@ void gsb_autofunc_currency_set_currency_number ( GtkWidget *combobox,
     /* Unblock everything */
     if ( g_object_get_data (G_OBJECT (combobox), "changed") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(combobox),
-				   (gulong) g_object_get_data (G_OBJECT (combobox), 
+				   (gulong) g_object_get_data (G_OBJECT (combobox),
 							       "changed"));
     if ( g_object_get_data (G_OBJECT (combobox), "changed-hook") > 0 )
 	g_signal_handler_unblock ( G_OBJECT(combobox),
-				   (gulong) g_object_get_data (G_OBJECT (combobox), 
+				   (gulong) g_object_get_data (G_OBJECT (combobox),
 							       "changed-hook"));
 }
 
@@ -1428,8 +1421,7 @@ gboolean gsb_autofunc_currency_changed ( GtkWidget *combobox,
 		   gsb_currency_get_currency_from_combobox (combobox));
 
     /* Mark file as modified */
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     return FALSE;
 }
