@@ -31,6 +31,7 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_category.h"
@@ -38,6 +39,7 @@
 #include "dialog.h"
 #include "gsb_data_category.h"
 #include "gsb_data_form.h"
+#include "gsb_dirs.h"
 #include "gsb_file_others.h"
 #include "gsb_form_widget.h"
 #include "gtk_combofix.h"
@@ -77,9 +79,9 @@ gint compare_basename ( gchar * file1, gchar * file2 )
     gchar * base1 = g_path_get_basename ( file1 );
     gchar * base2 = g_path_get_basename ( file2 );
     gint result;
-    
+
     result = strcmp ( base1, base2 );
-    
+
     g_free ( base1 );
     g_free ( base2 );
 
@@ -108,14 +110,14 @@ void gsb_category_fill_sets ( GtkTreeView * view, GtkTreeModel * model, gboolean
     {
 	GSList * list;
 
-	if ( show_foreign || 
+	if ( show_foreign ||
 	     ( strlen ( (gchar *) *languages ) && strcmp ( (gchar *) *languages, "C" ) ) )
 	{
-	    list = gsb_category_assistant_scan_directory ( (gchar *) * languages, 
+	    list = gsb_category_assistant_scan_directory ( (gchar *) * languages,
 							   model );
 	    while ( list )
 	    {
-		if ( ! g_slist_find_custom ( category_files, list -> data, 
+		if ( ! g_slist_find_custom ( category_files, list -> data,
 					     (GCompareFunc) cherche_string_equivalente_dans_slist ) )
 		{
 		    category_files = g_slist_append ( category_files, list -> data );
@@ -130,12 +132,12 @@ void gsb_category_fill_sets ( GtkTreeView * view, GtkTreeModel * model, gboolean
     {
 	category_files = gsb_category_assistant_scan_directory ( "C", model );
     }
-    
+
     category_files = g_slist_sort ( category_files, (GCompareFunc) compare_basename );
 
     while ( category_files )
     {
-	gsb_category_assistant_parse_file ( (gchar * ) category_files -> data, 
+	gsb_category_assistant_parse_file ( (gchar * ) category_files -> data,
 					    model );
 
 	category_files = category_files -> next;
@@ -150,7 +152,7 @@ void gsb_category_fill_sets ( GtkTreeView * view, GtkTreeModel * model, gboolean
 
 
 /**
- * Handler that is responsible of toggling what is displayed in the 
+ * Handler that is responsible of toggling what is displayed in the
  *
  * \param button		GtkButton that triggered this handler.
  *
@@ -209,7 +211,7 @@ GtkWidget *gsb_category_assistant_create_choice_page ( GtkWidget *assistant )
     gtk_container_add ( GTK_CONTAINER ( sw ), (GtkWidget *) builtin_category_view );
 
     cell = gtk_cell_renderer_text_new ();
-    col_offset = 
+    col_offset =
 	gtk_tree_view_insert_column_with_attributes ( GTK_TREE_VIEW ( builtin_category_view ),
 						      -1, _("Category list"),
 						      cell, "markup",
@@ -260,7 +262,7 @@ gboolean gsb_category_assistant_create_categories ( GtkWidget *assistant )
 			     &iter,
 			     BUILTIN_CATEGORY_MODEL_FILENAME, &filename,
 			     -1);
-	
+
 	gsb_file_others_load_category ( filename );
 
     }
@@ -284,7 +286,7 @@ gboolean gsb_category_update_combofix ( gboolean force )
                         TRANSACTION_FORM_CATEGORY ) ),
                         gsb_data_category_get_name_list ( TRUE, TRUE, TRUE, TRUE ) );
     }
- 
+
     return FALSE;
 }
 
@@ -293,7 +295,7 @@ gboolean gsb_category_update_combofix ( gboolean force )
  * Scan a directory for Grisbi category files in order to put their
  * titles in a GtkTreeModel.
  *
- * \param basename	Basename of the directory to scan.  The 
+ * \param basename	Basename of the directory to scan.  The
  *			data directory will be prepended.
  * \param model		A GtkTreeModel to fill with information found.
  *
@@ -305,20 +307,22 @@ GSList * gsb_category_assistant_scan_directory ( gchar * basename, GtkTreeModel
     GDir * dir;
     GSList * list = NULL;
 
-    dirname = g_strconcat ( DATA_PATH, C_DIRECTORY_SEPARATOR, "categories", C_DIRECTORY_SEPARATOR, basename, NULL );
+    dirname = g_build_filename ( gsb_dirs_get_categories_dir ( ), basename, NULL );
     if ( ! g_file_test ( dirname, G_FILE_TEST_IS_DIR ) )
     {
 	gchar * pos = strchr ( basename, '.' );
-	if ( pos ) 
+	if ( pos )
 	    *pos = '\0';
-	dirname = g_strconcat ( DATA_PATH, C_DIRECTORY_SEPARATOR, "categories", C_DIRECTORY_SEPARATOR, basename, NULL );
+	g_free ( dirname );
+	dirname = g_build_filename ( gsb_dirs_get_categories_dir ( ), basename, NULL );
     }
     if ( ! g_file_test ( dirname, G_FILE_TEST_IS_DIR ) )
     {
 	gchar * pos = strchr ( basename, '_' );
-	if ( pos ) 
+	if ( pos )
 	    *pos = '\0';
-	dirname = g_strconcat ( DATA_PATH, C_DIRECTORY_SEPARATOR, "categories", C_DIRECTORY_SEPARATOR, basename, NULL );
+	g_free ( dirname );
+	dirname = g_build_filename ( gsb_dirs_get_categories_dir ( ), basename, NULL );
     }
 
     dir = g_dir_open ( dirname, 0, NULL );
@@ -327,7 +331,7 @@ GSList * gsb_category_assistant_scan_directory ( gchar * basename, GtkTreeModel
 	gchar * filename;
 	while ( ( filename = (gchar *) g_dir_read_name ( dir ) ) )
 	{
-	    filename = g_strconcat ( dirname, "/", filename, NULL );
+	    filename = g_build_filename ( dirname, filename, NULL );
 	    if ( g_file_test ( filename, G_FILE_TEST_IS_REGULAR ) &&
 		 g_str_has_suffix ( filename, ".cgsb" ) )
 	    {
@@ -336,6 +340,8 @@ GSList * gsb_category_assistant_scan_directory ( gchar * basename, GtkTreeModel
 	}
     }
 
+    g_free ( dirname );
+
     return g_slist_sort ( list, (GCompareFunc) strcmp );
 }
 
@@ -348,8 +354,8 @@ GSList * gsb_category_assistant_scan_directory ( gchar * basename, GtkTreeModel
  * \param model		A GtkTreeModel to fill with information found.
  */
 void gsb_category_assistant_parse_file ( gchar * filename, GtkTreeModel * model )
-{    
-    GMarkupParser *markup_parser = g_malloc0 (sizeof (GMarkupParser));
+{
+    GMarkupParser *markup_parser;
     GMarkupParseContext * context;
     gchar * file_content, * description = NULL;
     GtkTreeIter iter;
@@ -363,6 +369,7 @@ void gsb_category_assistant_parse_file ( gchar * filename, GtkTreeModel * model
 	return;
     }
 
+    markup_parser = g_malloc0 ( sizeof ( GMarkupParser ) );
     markup_parser -> start_element = (void *) gsb_category_assistant_start_element;
 
     context = g_markup_parse_context_new ( markup_parser,
@@ -376,7 +383,7 @@ void gsb_category_assistant_parse_file ( gchar * filename, GtkTreeModel * model
 
     if ( ! description )
     {
-	description = g_strconcat ( "<span size=\"larger\" weight=\"bold\">", _("Unnamed category list"), 
+	description = g_strconcat ( "<span size=\"larger\" weight=\"bold\">", _("Unnamed category list"),
 				    "</span>", NULL );
     }
 
@@ -400,7 +407,7 @@ void gsb_category_assistant_start_element ( GMarkupParseContext *context, const
 
     if ( ! my_strcasecmp ( element_name, "general" ) )
     {
-	
+
 	while ( *attribute_names )
 	{
 	    if ( ! my_strcasecmp ( *attribute_names, "title" ) )
