@@ -46,31 +46,10 @@
 #include "gsb_data_transaction.h"
 #include "gsb_real.h"
 #include "transaction_list.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 
-/**
- * \struct 
- * Describe an archive store
- */
-typedef struct
-{
-    gint archive_store_number;
-
-    /* the corresponding archive (1 archive contains several archive store) */
-    gint archive_number;
-
-    /* account we are working on */
-    gint account_number;
-
-    /* balance of all the transactions of the archive for that account */
-    gsb_real balance;
-
-    /* number of transactions in the archive for that account */
-    gint nb_transactions;
-} struct_store_archive;
-
-
 /*START_STATIC*/
 static void _gsb_data_archive_store_free ( struct_store_archive *archive );
 static struct_store_archive *gsb_data_archive_store_find_struct ( gint archive_number,
@@ -80,7 +59,6 @@ static gint gsb_data_archive_store_new ( void );
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern gsb_real null_real;
 /*END_EXTERN*/
 
 /** contains the g_slist of struct_store_archive */
@@ -102,16 +80,15 @@ gboolean gsb_data_archive_store_init_variables ( void )
 {
     if ( archive_store_list )
     {
-        GSList* tmp_list = archive_store_list;
+        GSList *tmp_list;
+
+        tmp_list = archive_store_list;
         while ( tmp_list )
         {
             struct_store_archive *archive;
-            gint archive_number;
 
             archive = tmp_list -> data;
-            archive_number = gsb_data_archive_store_get_archive_number (
-                        archive -> archive_store_number );
-            transaction_list_remove_archive ( archive_number );
+            transaction_list_remove_archive ( archive->archive_number );
             tmp_list = tmp_list -> next;
             _gsb_data_archive_store_free ( archive );
         }
@@ -204,7 +181,7 @@ void gsb_data_archive_store_create_list ( void )
         }
         else
         {
-            /* there is no struct_store_archive for that transaction, we make a new one 
+            /* there is no struct_store_archive for that transaction, we make a new one
              * with the balance of the transaction as balance */
             gint archive_store_number;
 
@@ -228,11 +205,13 @@ void gsb_data_archive_store_create_list ( void )
  */
 static void _gsb_data_archive_store_free ( struct_store_archive *archive )
 {
-    if ( ! archive )
+    if ( !archive )
         return;
+
     g_free ( archive );
+
     if ( archive_store_buffer == archive )
-    archive_store_buffer = NULL;
+        archive_store_buffer = NULL;
 }
 
 /**
@@ -409,9 +388,9 @@ gpointer gsb_data_archive_store_get_structure ( gint archive_store_number )
 
 /**
  * find and return the last number of archive
- * 
+ *
  * \param none
- * 
+ *
  * \return last number of archive
  * */
 static gint gsb_data_archive_store_max_number ( void )
@@ -493,6 +472,11 @@ static gint gsb_data_archive_store_new ( void )
 }
 
 
+/**
+ *
+ *
+ *
+ */
 gsb_real gsb_data_archive_store_get_archives_balance ( gint account_number )
 {
     GSList *tmp_list;
@@ -514,6 +498,79 @@ gsb_real gsb_data_archive_store_get_archives_balance ( gint account_number )
 
     return balance;
 }
+
+
+/**
+ *
+ *
+ *
+ */
+gboolean gsb_data_archive_store_get_transactions_visibles ( gint archive_number,
+                        gint account_number )
+{
+    struct_store_archive *archive_store;
+
+    archive_store = gsb_data_archive_store_find_struct ( archive_number, account_number );
+
+    if ( archive_store )
+        return archive_store -> transactions_visibles;
+    else
+        return FALSE;
+}
+
+
+/**
+ *
+ *
+ *
+ */
+gboolean gsb_data_archive_store_set_transactions_visibles ( gint archive_number,
+                        gint account_number,
+                        gboolean transactions_visibles )
+{
+    struct_store_archive *archive_store;
+
+    archive_store = gsb_data_archive_store_find_struct ( archive_number, account_number );
+
+    if ( archive_store )
+    {
+        archive_store -> transactions_visibles = transactions_visibles;
+        return TRUE;
+    }
+    else
+        return FALSE;
+}
+
+
+/**
+ *
+ *
+ *
+ */
+gboolean gsb_data_archive_store_account_have_transactions_visibles ( gint account_number )
+{
+    GSList *tmp_list;
+
+    tmp_list = gsb_data_archive_store_get_archives_list ( );
+
+    while (tmp_list)
+    {
+        struct_store_archive *archive_store;
+
+        archive_store = tmp_list -> data;
+
+        if ( archive_store -> account_number == account_number
+         &&
+         archive_store -> transactions_visibles == TRUE )
+            return TRUE;
+
+        tmp_list = tmp_list -> next;
+    }
+
+    return FALSE;
+}
+
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
