@@ -31,6 +31,7 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_data_category.h"
@@ -48,7 +49,7 @@
 /*END_INCLUDE*/
 
 /**
- * \struct 
+ * \struct
  * Describe a category
  */
 typedef struct
@@ -69,7 +70,7 @@ typedef struct
 
 
 /**
- * \struct 
+ * \struct
  * Describe a sub-category
  */
 typedef struct
@@ -108,7 +109,6 @@ static gint gsb_data_sub_category_compare ( struct_sub_category * a, struct_sub_
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern gsb_real null_real;
 /*END_EXTERN*/
 
 
@@ -394,8 +394,8 @@ gint gsb_data_category_max_number ( void )
 /**
  * find and return the last number of the sub-categories
  *
- * \param 
- * 
+ * \param
+ *
  * \return last number of the sub-categories
  * */
 gint gsb_data_category_max_sub_category_number ( gint category_number )
@@ -453,7 +453,7 @@ gint gsb_data_category_new ( const gchar *name )
 /**
  * create a new category with a number, append it to the list
  * and return the number
- * 
+ *
  *
  * \param number the number we want to give to that category
  *
@@ -524,7 +524,7 @@ void _gsb_data_category_free ( struct_category *category )
     }
     if ( category -> category_name )
         g_free ( category -> category_name );
-    g_free ( category ); 
+    g_free ( category );
     if ( category_buffer == category )
 	category_buffer = NULL;
 }
@@ -863,10 +863,12 @@ gchar *gsb_data_category_get_name ( gint no_category,
 
         if ( sub_category )
         {
-            return_value = g_strconcat ( return_value,
+            gchar *tmp = return_value;
+            return_value = g_strconcat ( tmp,
                          " : ",
                          sub_category -> sub_category_name,
                          NULL );
+            g_free ( tmp );
         }
     }
     return return_value;
@@ -886,7 +888,7 @@ gboolean gsb_data_category_set_name ( gint no_category,
                         const gchar *name )
 {
     struct_category *category;
-    
+
     category = gsb_data_category_get_structure ( no_category );
 
     if ( !category )
@@ -970,7 +972,7 @@ gboolean gsb_data_category_set_sub_category_name ( gint no_category,
     if ( name )
     {
         GtkWidget *combofix;
-        
+
         sub_category -> sub_category_name = my_strdup ( name );
         combofix = gsb_form_widget_get_widget ( TRANSACTION_FORM_PARTY );
         if ( combofix )
@@ -1018,8 +1020,7 @@ GSList *gsb_data_category_get_name_list ( gboolean set_debit,
 	{
 	    if ( set_debit )
 	    {
-		debit_list = g_slist_append ( debit_list,
-					      category -> category_name);
+		debit_list = g_slist_append ( debit_list, g_strdup ( category -> category_name ) );
 		debit_list = gsb_data_category_append_sub_category_to_list ( debit_list,
 									     category -> sub_category_list);
 	    }
@@ -1028,8 +1029,7 @@ GSList *gsb_data_category_get_name_list ( gboolean set_debit,
 	{
 	    if ( set_credit )
 	    {
-		credit_list = g_slist_append ( credit_list,
-					       category -> category_name);
+		credit_list = g_slist_append ( credit_list, g_strdup ( category -> category_name ) );
 		credit_list = gsb_data_category_append_sub_category_to_list ( credit_list,
 									      category -> sub_category_list);
 	    }
@@ -1053,10 +1053,8 @@ GSList *gsb_data_category_get_name_list ( gboolean set_debit,
 	GSList *special_list = NULL;
 
 	if (set_split)
-	    special_list = g_slist_append ( special_list,
-					    _("Split of transaction"));
-	special_list = g_slist_append ( special_list,
-					_("Transfer"));
+	    special_list = g_slist_append ( special_list, g_strdup ( _("Split of transaction") ) );
+	special_list = g_slist_append ( special_list, g_strdup ( _("Transfer") ) );
 
 	/* append the accounts name with a tab at the beginning */
 
@@ -1081,6 +1079,34 @@ GSList *gsb_data_category_get_name_list ( gboolean set_debit,
 }
 
 
+/**
+ * free the memory used by gsb_data_category_get_name_list
+ *
+ * \param liste
+ *
+ * \return
+ */
+void gsb_data_categorie_free_name_list ( GSList *liste )
+{
+    gint nbre_list;
+    gint i;
+
+    nbre_list = g_slist_length ( liste );
+
+    for ( i = 0; i < nbre_list -1; i++ )
+    {
+        GSList *tmp_list;
+
+        tmp_list = liste->data;
+        liste = liste->next;
+        g_slist_foreach ( tmp_list, (GFunc) g_free, NULL );
+        g_slist_free ( tmp_list );
+    }
+
+    g_slist_free ( liste );
+}
+
+
 
 /**
  * append the sub-categories name with a tab at the beginning
@@ -1298,9 +1324,9 @@ gsb_real gsb_data_category_get_direct_balance ( gint no_category )
 /**
  * reset the counters of the categories and sub-categories
  *
- * \param 
+ * \param
  *
- * \return 
+ * \return
  * */
 void gsb_data_category_reset_counters ( void )
 {
@@ -1324,7 +1350,7 @@ void gsb_data_category_reset_counters ( void )
 	while ( sub_list_tmp )
 	{
 	    struct_sub_category *sub_category;
-	    
+
 	    sub_category = sub_list_tmp -> data;
 
 	    sub_category -> sub_category_nb_transactions = 0;
@@ -1334,7 +1360,7 @@ void gsb_data_category_reset_counters ( void )
 	}
 	list_tmp = list_tmp -> next;
     }
-    
+
     /* reset the empty category */
     empty_category -> category_balance = null_real;
     empty_category -> category_nb_transactions = 0;
@@ -1411,7 +1437,7 @@ void gsb_data_category_add_transaction_to_category ( gint transaction_number,
     {
 	gchar *tmpstr;
 	tmpstr = g_strdup_printf ( _("The transaction %d has a category n%d and sub-category n%d but they don't exist."),
-				   transaction_number, 
+				   transaction_number,
 				   category_id,
 				   sub_category_id );
 	warning_debug (tmpstr);
@@ -1508,7 +1534,7 @@ void gsb_data_category_remove_transaction_from_category ( gint transaction_numbe
  * Find if two sub categories are the same
  *
  * \param a		First sub-category to compare.
- * \param b		Second sub-category to compare.	
+ * \param b		Second sub-category to compare.
  *
  * \return		Same as a <=> b.
  */
@@ -1525,7 +1551,7 @@ gint gsb_data_sub_category_compare ( struct_sub_category * a, struct_sub_categor
 
 /**
  * \brief Debug check to verify if some sub categories are doubled.
- * 
+ *
  * This is a bug caused in old version of Grisbi and this check has to
  * be there since we need to access to the structures directly without
  * resorting to numeric ids.
@@ -1555,7 +1581,7 @@ gchar * gsb_debug_duplicate_categ_check ()
 	    if ( duplicate && duplicate > tmp_sous_categ )
 	    {
 	        gchar* tmpstr1 = output;
-		gchar* tmpstr2 = g_strdup_printf ( 
+		gchar* tmpstr2 = g_strdup_printf (
 				_("In <i>%s</i>, <i>%s</i> is a duplicate of <i>%s</i>.\n"),
 				categ -> category_name,
 				((struct_sub_category *) tmp_sous_categ -> data) -> sub_category_name,
@@ -1569,7 +1595,7 @@ gchar * gsb_debug_duplicate_categ_check ()
 	    }
 	    tmp_sous_categ = tmp_sous_categ -> next;
 	}
-	
+
 	tmp = tmp -> next;
     }
 
@@ -1578,14 +1604,14 @@ gchar * gsb_debug_duplicate_categ_check ()
 	output [ strlen ( output ) - 1 ] = '\0';
 	return output;
     }
-    
+
     return NULL;
 }
 
 
 
 /**
- * Fix any duplicate in sub categories.  
+ * Fix any duplicate in sub categories.
  *
  * \return	TRUE on success.  FALSE otherwise.
  */
@@ -1613,7 +1639,7 @@ gboolean gsb_debug_duplicate_categ_fix ()
 	    }
 	    tmp_sous_categ = tmp_sous_categ -> next;
 	}
-	
+
 	tmp = tmp -> next;
     }
 
@@ -1622,10 +1648,10 @@ gboolean gsb_debug_duplicate_categ_fix ()
 
 
 /**
- * 
- * 
  *
- * \param 
+ *
+ *
+ * \param
  *
  * \return
  * */
@@ -1668,6 +1694,13 @@ gint gsb_data_category_test_create_category ( gint no_category,
 }
 
 
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ * */
 gboolean gsb_data_category_test_create_sub_category ( gint no_category,
                         gint no_sub_category,
                         const gchar *name )
@@ -1703,6 +1736,35 @@ gboolean gsb_data_category_test_create_sub_category ( gint no_category,
     }
     return FALSE;
 }
+
+
+/**
+ * retourne le nombre de sous catgories
+ *
+ * \param   no_category
+ *
+ * \return  length of sub_category_list
+ * */
+gint gsb_data_category_get_sub_category_list_length ( gint no_category )
+{
+    struct_category *category;
+
+    category = gsb_data_category_get_structure ( no_category );
+
+    if ( !category )
+        return 0;
+
+    return g_slist_length ( category->sub_category_list );
+}
+
+
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ * */
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
