@@ -21,6 +21,7 @@ void gsb_data_category_add_transaction_to_category ( gint transaction_number,
 gboolean gsb_data_category_fill_transaction_by_string ( gint transaction_number,
                         const gchar *string,
                         gboolean is_transaction );
+void gsb_data_categorie_free_name_list ( GSList *liste );
 gsb_real gsb_data_category_get_balance ( gint no_category );
 GSList *gsb_data_category_get_categories_list ( void );
 gsb_real gsb_data_category_get_direct_balance ( gint no_category );
@@ -42,6 +43,7 @@ gint gsb_data_category_get_number_by_name ( const gchar *name,
 gpointer gsb_data_category_get_structure ( gint no_category );
 gsb_real gsb_data_category_get_sub_category_balance ( gint no_category,
 						      gint no_sub_category );
+gint gsb_data_category_get_sub_category_list_length ( gint no_category );
 GSList *gsb_data_category_get_sub_category_list ( gint no_category );
 gchar *gsb_data_category_get_sub_category_name ( gint no_category,
 						 gint no_sub_category,
