@@ -30,17 +30,22 @@
 #endif
 
 #include "include.h"
+#include <gdk/gdkkeysyms.h>
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_data_partial_balance.h"
 #include "dialog.h"
+#include "gsb_color.h"
 #include "gsb_currency_config.h"
 #include "gsb_currency.h"
 #include "gsb_data_account.h"
 #include "gsb_data_currency.h"
 #include "gsb_data_currency_link.h"
+#include "gsb_data_transaction.h"
 #include "navigation.h"
 #include "gsb_real.h"
+#include "utils_real.h"
 #include "utils_str.h"
 #include "utils.h"
 #include "structures.h"
@@ -82,8 +87,6 @@ static void gsb_partial_balance_selectionne_cptes ( GtkWidget *tree_view,
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern gsb_real null_real;
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 /* devise de base des soldes partiels de comptes ayant des devises différentes */
@@ -122,7 +125,7 @@ gint gsb_partial_balance_new ( const gchar *name )
 
     if ( name )
         partial_balance -> balance_name = my_strdup ( name );
-    else 
+    else
         partial_balance -> balance_name = NULL;
 
     partial_balance_list = g_slist_append ( partial_balance_list, partial_balance );
@@ -155,7 +158,7 @@ gint gsb_partial_balance_new_at_position ( const gchar *name, gint pos )
 
     if ( name )
         partial_balance -> balance_name = my_strdup ( name );
-    else 
+    else
         partial_balance -> balance_name = NULL;
 
     partial_balance_list = g_slist_insert ( partial_balance_list, partial_balance, pos - 1 );
@@ -167,10 +170,10 @@ gint gsb_partial_balance_new_at_position ( const gchar *name, gint pos )
 }
 
 
-/** 
+/**
  *
- * \param 
- * \param 
+ * \param
+ * \param
  *
  * */
 GtkListStore *gsb_partial_balance_create_model ( void )
@@ -183,10 +186,10 @@ GtkListStore *gsb_partial_balance_create_model ( void )
 }
 
 
-/** 
+/**
  *
- * \param 
- * \param 
+ * \param
+ * \param
  *
  * */
 void gsb_partial_balance_fill_model ( GtkListStore *list_store )
@@ -207,7 +210,7 @@ void gsb_partial_balance_fill_model ( GtkListStore *list_store )
 
         switch ( partial_balance -> kind )
         {
-        case -1:
+        case GSB_TYPE_BALANCE:
             kind_str = g_strdup ( _("Additional balance") );
             break;
 
@@ -282,8 +285,8 @@ dialog_return:
         name = gtk_entry_get_text ( GTK_ENTRY ( entry_name ) );
         liste_cptes = gtk_entry_get_text ( GTK_ENTRY ( entry_list ) );
 
-        if ( strlen ( name ) && strlen ( liste_cptes ) 
-         && 
+        if ( strlen ( name ) && strlen ( liste_cptes )
+         &&
          g_utf8_strchr  ( liste_cptes, -1, ';' ) )
         {
             position = gtk_spin_button_get_value_as_int ( GTK_SPIN_BUTTON ( spin_bouton ) );
@@ -398,7 +401,7 @@ dialog_return:
         name = gtk_entry_get_text ( GTK_ENTRY ( entry_name ) );
         liste_cptes = gtk_entry_get_text ( GTK_ENTRY ( entry_list ) );
 
-        if ( strlen ( name ) && strlen ( liste_cptes ) && 
+        if ( strlen ( name ) && strlen ( liste_cptes ) &&
          g_utf8_strchr  ( liste_cptes, -1, ';' ) )
         {
             gsb_data_partial_balance_set_name ( partial_balance_number, name );
@@ -571,6 +574,7 @@ void gsb_partial_balance_selectionne_cptes ( GtkWidget *tree_view,
             valid = gtk_tree_model_iter_next ( model, &iter );
         }
     }
+    g_strfreev ( tab );
 }
 
 
@@ -629,7 +633,7 @@ gboolean gsb_partial_balance_button_press ( GtkWidget *tree_view,
 
 
 /**
- * 
+ *
  *
 **/
 void gsb_partial_balance_colorise_toggled ( GtkCellRendererToggle *cell,
@@ -650,9 +654,9 @@ void gsb_partial_balance_colorise_toggled ( GtkCellRendererToggle *cell,
     treepath = gtk_tree_path_new_from_string ( path_str );
     gtk_tree_model_get_iter ( GTK_TREE_MODEL (model), &iter, treepath );
 
-    gtk_tree_model_get ( GTK_TREE_MODEL ( model ), &iter, 
+    gtk_tree_model_get ( GTK_TREE_MODEL ( model ), &iter,
                         4, &partial_number,
-                        5, &toggle, 
+                        5, &toggle,
                         -1);
     toggle ^= 1;
     gtk_list_store_set (GTK_LIST_STORE ( model ), &iter, 5, toggle, -1);
@@ -687,7 +691,7 @@ gboolean gsb_data_partial_balance_init_variables ( void )
 
             partial_balance = tmp_list -> data;
             tmp_list = tmp_list -> next;
-            _gsb_data_partial_balance_free ( partial_balance ); 
+            _gsb_data_partial_balance_free ( partial_balance );
         }
         g_slist_free ( partial_balance_list );
     }
@@ -774,18 +778,18 @@ gint gsb_data_partial_balance_get_number ( gpointer balance_ptr )
 
 
 /**
- * This internal function is called to free the memory used by an 
+ * This internal function is called to free the memory used by an
  * struct_partial_balance structure
  */
 static void _gsb_data_partial_balance_free ( struct_partial_balance *partial_balance)
 {
     if ( ! partial_balance )
         return;
-    if ( partial_balance -> balance_name 
+    if ( partial_balance -> balance_name
      &&
      strlen ( partial_balance -> balance_name ) )
         g_free ( partial_balance -> balance_name );
-    if ( partial_balance -> liste_cptes 
+    if ( partial_balance -> liste_cptes
      &&
      strlen ( partial_balance -> liste_cptes ) )
         g_free ( partial_balance -> liste_cptes );
@@ -897,7 +901,7 @@ gboolean gsb_data_partial_balance_set_name ( gint partial_balance_number,
 }
 
 
-/** 
+/**
  * get the kind of the partial_balance
  * \param partial_balance_number no of the partial_balance
  *
@@ -916,7 +920,7 @@ kind_account gsb_data_partial_balance_get_kind ( gint partial_balance_number )
 }
 
 
-/** 
+/**
  * set the kind of the partial_balance
  * \param partial_balance_number no of the partial_balance
  * \param kind type to set
@@ -939,7 +943,7 @@ gboolean gsb_data_partial_balance_set_kind ( gint partial_balance_number,
 }
 
 
-/** 
+/**
  * get the currency of the partial_balance
  *
  * \param partial_balance_number no of the partial_balance
@@ -959,7 +963,7 @@ gint gsb_data_partial_balance_get_currency ( gint partial_balance_number )
 }
 
 
-/** 
+/**
  * set the currency of the partial_balance
  *
  * \param partial_balance_number no of the partial_balance
@@ -983,12 +987,12 @@ gboolean gsb_data_partial_balance_set_currency ( gint partial_balance_number,
 }
 
 
-/** 
- * 
+/**
+ *
  *
  * \param partial_balance_number no of the partial_balance
  *
- * \return 
+ * \return
  * */
 gboolean gsb_data_partial_balance_get_colorise ( gint partial_balance_number )
 {
@@ -1003,7 +1007,7 @@ gboolean gsb_data_partial_balance_get_colorise ( gint partial_balance_number )
 }
 
 
-/** 
+/**
  * \param partial_balance_number no of the partial_balance
  * \param colorise
  *
@@ -1026,7 +1030,7 @@ gboolean gsb_data_partial_balance_set_colorise ( gint partial_balance_number,
 
 
 /**
- * 
+ *
  *
  * */
 gchar *gsb_data_partial_balance_get_marked_balance ( gint partial_balance_number )
@@ -1042,7 +1046,7 @@ gchar *gsb_data_partial_balance_get_marked_balance ( gint partial_balance_number
     if ( !partial_balance )
         return NULL;
 
-    if ( partial_balance -> liste_cptes == NULL || 
+    if ( partial_balance -> liste_cptes == NULL ||
      strlen ( partial_balance -> liste_cptes ) == 0 )
         return NULL;
 
@@ -1071,17 +1075,25 @@ gchar *gsb_data_partial_balance_get_marked_balance ( gint partial_balance_number
                     tmp_real = gsb_real_div ( tmp_real,
                                 gsb_data_currency_link_get_change_rate ( link_number ) );
             }
-            
+
         }
         solde = gsb_real_add ( solde, tmp_real );
     }
+    g_strfreev ( tab );
 
     if ( partial_balance -> colorise && solde.mantissa < 0 )
-        string = g_strdup_printf ( "<span color=\"red\">%s</span>",
-                        gsb_real_get_string_with_currency (
+    {
+        gchar *color;
+
+        color = gsb_color_get_couleur_to_string ( "couleur_solde_alarme_rouge_normal" );
+        string = g_strdup_printf ( "<span color=\"%s\">%s</span>",
+                        color,
+                        utils_real_get_string_with_currency (
                         solde, partial_balance -> currency, TRUE ) );
+        g_free ( color );
+    }
     else
-        string = gsb_real_get_string_with_currency (
+        string = utils_real_get_string_with_currency (
                         solde, partial_balance -> currency, TRUE );
 
     return string;
@@ -1089,7 +1101,7 @@ gchar *gsb_data_partial_balance_get_marked_balance ( gint partial_balance_number
 
 
 /**
- * 
+ *
  *
  * */
 gsb_real gsb_data_partial_balance_get_current_amount ( gint partial_balance_number )
@@ -1104,7 +1116,7 @@ gsb_real gsb_data_partial_balance_get_current_amount ( gint partial_balance_numb
     if ( !partial_balance )
         return null_real;
 
-    if ( partial_balance -> liste_cptes == NULL || 
+    if ( partial_balance -> liste_cptes == NULL ||
      strlen ( partial_balance -> liste_cptes ) == 0 )
         return null_real;
 
@@ -1136,13 +1148,14 @@ gsb_real gsb_data_partial_balance_get_current_amount ( gint partial_balance_numb
         }
         solde = gsb_real_add ( solde, tmp_real );
     }
+    g_strfreev ( tab );
 
     return solde;
 }
 
 
 /**
- * 
+ *
  *
  * */
 gchar *gsb_data_partial_balance_get_current_balance ( gint partial_balance_number )
@@ -1159,11 +1172,18 @@ gchar *gsb_data_partial_balance_get_current_balance ( gint partial_balance_numbe
     solde = gsb_data_partial_balance_get_current_amount ( partial_balance_number );
 
     if ( partial_balance -> colorise && solde.mantissa < 0 )
-        string = g_strdup_printf ( "<span color=\"red\">%s</span>",
-                        gsb_real_get_string_with_currency (
+    {
+        gchar *color;
+
+        color = gsb_color_get_couleur_to_string ( "couleur_solde_alarme_rouge_normal" );
+        string = g_strdup_printf ( "<span color=\"%s\">%s</span>",
+                        color,
+                        utils_real_get_string_with_currency (
                         solde, partial_balance -> currency, TRUE ) );
+        g_free ( color );
+    }
     else
-        string = gsb_real_get_string_with_currency (
+        string = utils_real_get_string_with_currency (
                         solde, partial_balance -> currency, TRUE );
 
     return string;
@@ -1171,7 +1191,7 @@ gchar *gsb_data_partial_balance_get_current_balance ( gint partial_balance_numbe
 
 
 /**
- * 
+ *
  *
  * */
 gboolean gsb_partial_balance_select_account ( GtkTreeSelection *selection,
@@ -1200,7 +1220,7 @@ gboolean gsb_partial_balance_select_account ( GtkTreeSelection *selection,
                 gtk_tree_model_get ( model, &iter, 1, &account_nb, -1);
                 if ( strlen ( gtk_entry_get_text ( GTK_ENTRY ( entry ) ) ) > 0 )
                 {
-                    gtk_entry_set_text ( GTK_ENTRY ( entry ), 
+                    gtk_entry_set_text ( GTK_ENTRY ( entry ),
                                 g_strconcat ( gtk_entry_get_text ( GTK_ENTRY ( entry ) ), ";",
                                 g_strdup_printf ( "%d", account_nb ), NULL ) );
                 }
@@ -1223,7 +1243,7 @@ gboolean gsb_partial_balance_select_account ( GtkTreeSelection *selection,
             gtk_tree_model_get ( model, &iter, 1, &account_nb, -1);
             if ( strlen ( gtk_entry_get_text ( GTK_ENTRY ( entry ) ) ) > 0 )
             {
-                gtk_entry_set_text ( GTK_ENTRY ( entry ), 
+                gtk_entry_set_text ( GTK_ENTRY ( entry ),
                             g_strconcat ( gtk_entry_get_text ( GTK_ENTRY ( entry ) ), ";",
                             g_strdup_printf ( "%d", account_nb ), NULL ) );
             }
@@ -1267,7 +1287,7 @@ gboolean gsb_data_partial_balance_init_from_liste_cptes ( gint partial_balance_n
     if ( !partial_balance )
         return FALSE;
 
-    if ( partial_balance -> liste_cptes == NULL || 
+    if ( partial_balance -> liste_cptes == NULL ||
      strlen ( partial_balance -> liste_cptes ) == 0 )
         return FALSE;
 
@@ -1304,6 +1324,9 @@ gboolean gsb_data_partial_balance_init_from_liste_cptes ( gint partial_balance_n
         {
             switch ( kind )
             {
+            case GSB_TYPE_BALANCE:
+                break;
+
             case GSB_TYPE_BANK:
             case GSB_TYPE_CASH:
                 if ( kind_nb >= GSB_TYPE_LIABILITIES )
@@ -1320,6 +1343,8 @@ gboolean gsb_data_partial_balance_init_from_liste_cptes ( gint partial_balance_n
             }
         }
     }
+    g_strfreev ( tab );
+
     if ( currency_mixte )
         gsb_data_partial_balance_set_currency ( partial_balance_number,
                         no_devise_solde_partiels );
@@ -1363,7 +1388,7 @@ gboolean gsb_data_partial_balance_drag_data_received ( GtkTreeDragDest * drag_de
 
         /* On récupère le model et le path d'origine */
         gtk_tree_get_row_drag_data (selection_data, &model, &orig_path);
-        
+
         if ( gtk_tree_model_get_iter ( model, &iter, orig_path ) )
             gtk_tree_model_get ( model, &iter, 4, &orig_partial_number, -1 );
 
@@ -1425,11 +1450,145 @@ gboolean gsb_data_partial_balance_move ( gint orig_partial_number, gint dest_pos
 }
 
 
+/**
+ * calcule le solde des comptes d'un solde partiel à une date donnée
+ *
+ * \param account_number    numéro du compte concerné
+ * \param date              date de calcul du solde
+ *
+ * \return GPtrArray        un tableau avec le solde de chaque compte concerné
+ * */
+GPtrArray *gsb_data_partial_balance_calculate_balances_at_date ( gint partial_balance_number,
+                        GDate *date )
+{
+    GSList *tmp_list;
+    GPtrArray *current_balances;
+    GPtrArray *current_balances_later;
+    GArray *floating_points;
+    GArray *account_numbers;
+    gchar **tab;
+    gint i;
+    gint nbre_comptes;
+    struct_partial_balance *partial_balance;
+
+    partial_balance = gsb_data_partial_balance_get_structure ( partial_balance_number );
+
+    if ( !partial_balance_number )
+        return NULL;
+
+    tab = g_strsplit ( partial_balance->liste_cptes, ";", 0 );
+
+    nbre_comptes = g_strv_length ( tab );
+    if ( nbre_comptes )
+    {
+        floating_points = g_array_new ( FALSE, TRUE, sizeof ( gint ) );
+        account_numbers = g_array_new ( FALSE, TRUE, sizeof ( gint ) );
+        current_balances = g_ptr_array_new ();
+        current_balances_later = g_ptr_array_new ();
+    }
+    else
+        return NULL;
+
+    for ( i = 0; tab[i]; i++ )
+    {
+        gint account_number;
+        gint floating_point;
+        gsb_real *balance;
+        gsb_real tmp_balance;
+
+        /* on remplit le tableau des numeros des comptes */
+        account_number = utils_str_atoi ( tab[i] );
+        g_array_append_val ( account_numbers, account_number );
+
+        /* on remplit le tableau des données des devises */
+        floating_point = gsb_data_account_get_currency_floating_point ( account_number );
+        g_array_append_val ( floating_points, floating_point );
+
+        /* on initialise le tableau des soldes de chaque compte */
+        balance = g_malloc0 ( sizeof ( gsb_real ) );
+        tmp_balance = gsb_data_account_get_init_balance ( account_number, floating_point );
+        balance->mantissa = tmp_balance.mantissa;
+        balance->exponent = tmp_balance.exponent;
+        g_ptr_array_add ( current_balances, balance );
+
+        /* on initialise le tableau des soldes en erreur de chaque compte */
+        balance = g_malloc0 ( sizeof ( gsb_real ) );
+        balance->mantissa = null_real.mantissa;
+        balance->exponent = null_real.exponent;
+        g_ptr_array_add ( current_balances_later, balance );
+    }
+
+    tmp_list = gsb_data_transaction_get_complete_transactions_list ();
+
+    while (tmp_list)
+    {
+        gint transaction_number;
+
+        transaction_number = gsb_data_transaction_get_transaction_number ( tmp_list->data );
+
+        for ( i = 0; i < nbre_comptes; i++ )
+        {
+            gint account_number;
+            gboolean trouve = FALSE;
+
+            account_number = g_array_index ( account_numbers, gint, i );
+
+            if ( gsb_data_transaction_get_account_number ( transaction_number ) == account_number )
+            {
+                if ( g_date_compare ( gsb_data_transaction_get_value_date_or_date ( transaction_number ),
+                 date ) <= 0 )
+                {
+                    if ( gsb_data_transaction_get_mother_transaction_number ( transaction_number ) == 0 )
+                    {
+                        trouve = TRUE;
+                    }
+                }
+            }
+            if ( trouve )
+            {
+                gint floating_point;
+                gsb_real adjusted_amout;
+                gsb_real tmp_balance;
+                gsb_real *balance;
+                gsb_real current_balance;
+
+                floating_point = g_array_index ( floating_points, gint, i );
+                balance = (gsb_real *) g_ptr_array_index ( current_balances, i );
+                current_balance.mantissa = balance->mantissa;
+                current_balance.exponent = balance->exponent;
+
+                adjusted_amout = gsb_data_transaction_get_adjusted_amount ( transaction_number, floating_point );
+                tmp_balance = gsb_real_add ( current_balance, adjusted_amout );
+
+                if ( tmp_balance.mantissa != error_real.mantissa )
+                {
+                    balance->mantissa = tmp_balance.mantissa;
+                    balance->exponent = tmp_balance.exponent;
+                }
+                else
+                {
+                    gsb_real *balance_later;
+
+                    balance_later = (gsb_real *) g_ptr_array_index ( current_balances_later, i );
+                    balance_later->mantissa = G_MININT64;
+                    balance_later->exponent = 0;
+                }
+            }
+        }
+        tmp_list = tmp_list->next;
+    }
+    g_array_free ( account_numbers, TRUE );
+    g_array_free ( floating_points, TRUE );
+
+    return current_balances;
+}
+
+
 /*********************************************************************************************/
 /*              Interface                                                                    */
 /*********************************************************************************************/
 /**
- * 
+ *
  *
  * */
 GtkWidget *gsb_partial_balance_create_list_accounts ( GtkWidget *entry )
@@ -1509,7 +1668,7 @@ GtkWidget *gsb_partial_balance_create_list_accounts ( GtkWidget *entry )
 
 
 /**
- * 
+ *
  *
  * */
 GtkWidget *gsb_partial_balance_create_dialog ( gint action, gint spin_value )
@@ -1521,14 +1680,14 @@ GtkWidget *gsb_partial_balance_create_dialog ( gint action, gint spin_value )
 
     if ( action == 1 )
         dialog = gtk_dialog_new_with_buttons ( _("Add a partial balance"),
-                            GTK_WINDOW ( window ),
+                            GTK_WINDOW ( run.window ),
                             GTK_DIALOG_MODAL,
                             GTK_STOCK_CANCEL, 0,
                             GTK_STOCK_OK, 1,
                             NULL );
     else
         dialog = gtk_dialog_new_with_buttons ( _("Modify a partial balance"),
-                            GTK_WINDOW ( window ),
+                            GTK_WINDOW ( run.window ),
                             GTK_DIALOG_MODAL,
                             GTK_STOCK_CANCEL, 0,
                             GTK_STOCK_OK, 1,
@@ -1594,7 +1753,7 @@ GtkWidget *gsb_partial_balance_create_dialog ( gint action, gint spin_value )
     gtk_table_attach ( GTK_TABLE ( table ), bouton, 0, 2, 5, 6,
                         GTK_SHRINK | GTK_FILL, 0, 0, 0 );
     g_object_set_data ( G_OBJECT ( dialog ), "colorise_bouton", bouton );
-    
+
     g_object_set_data ( G_OBJECT ( dialog ), "entry_name", entry_name );
     g_object_set_data ( G_OBJECT ( dialog ), "entry_list", entry_list );
     g_object_set_data ( G_OBJECT ( dialog ), "account_list", account_list );
@@ -1604,7 +1763,7 @@ GtkWidget *gsb_partial_balance_create_dialog ( gint action, gint spin_value )
 
 
 /**
- * 
+ *
  *
  * */
 gint gsb_partial_balance_request_currency ( GtkWidget *parent )
@@ -1643,6 +1802,72 @@ gint gsb_partial_balance_request_currency ( GtkWidget *parent )
 
     return currency_nb;
 }
+
+/**
+ * calcule le solde d'un solde partiel à une date donnée
+ *
+ * \param partial_balance_number    numéro du solde partiel concerné
+ * \param date                      date de calcul du solde
+ *
+ * \return gsb_real         le solde du solde partiel
+ * */
+gsb_real gsb_data_partial_balance_get_balance_at_date ( gint partial_balance_number,
+                        GDate *date )
+{
+    struct_partial_balance *partial_balance;
+    gsb_real solde = null_real;
+    gchar **tab;
+    gint i;
+
+    partial_balance = gsb_data_partial_balance_get_structure ( partial_balance_number );
+
+    if ( !partial_balance )
+        return null_real;
+
+    if ( partial_balance -> liste_cptes == NULL ||
+     strlen ( partial_balance -> liste_cptes ) == 0 )
+        return null_real;
+
+    tab = g_strsplit ( partial_balance -> liste_cptes, ";", 0 );
+    for ( i = 0; tab[i]; i++ )
+    {
+        gsb_real tmp_real;
+        gint account_number;
+        gint account_currency;
+        gint link_number;
+
+        account_number = utils_str_atoi ( tab[i] );
+        account_currency = gsb_data_account_get_currency ( account_number );
+        tmp_real = gsb_data_account_get_balance_at_date ( account_number, date );
+
+        if ( tmp_real.mantissa != 0 && partial_balance -> currency != account_currency )
+        {
+            if ( ( link_number = gsb_data_currency_link_search ( account_currency,
+                        partial_balance -> currency ) ) )
+            {
+                if ( gsb_data_currency_link_get_first_currency ( link_number) == account_currency )
+                    tmp_real = gsb_real_mul ( tmp_real,
+                                gsb_data_currency_link_get_change_rate ( link_number ) );
+                else
+                    tmp_real = gsb_real_div ( tmp_real,
+                                gsb_data_currency_link_get_change_rate ( link_number ) );
+            }
+        }
+        solde = gsb_real_add ( solde, tmp_real );
+    }
+    g_strfreev ( tab );
+
+    return solde;
+}
+
+
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ * */
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
