@@ -32,6 +32,7 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_data_payee.h"
@@ -51,8 +52,8 @@
 
 
 /**
- * \struct 
- * Describe a payee 
+ * \struct
+ * Describe a payee
  */
 typedef struct
 {
@@ -76,7 +77,6 @@ static void gsb_data_payee_reset_counters ( void );
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern gsb_real null_real;
 /*END_EXTERN*/
 
 /** contains the g_slist of struct_payee */
@@ -147,7 +147,7 @@ gpointer gsb_data_payee_get_structure ( gint no_payee )
 	return payee_buffer;
 
     tmp = payee_list;
-    
+
     while ( tmp )
     {
 	struct_payee *payee;
@@ -200,10 +200,10 @@ GSList *gsb_data_payee_get_payees_list ( void )
 gint gsb_data_payee_get_no_payee ( gpointer payee_ptr )
 {
     struct_payee *payee;
-    
+
     if ( !payee_ptr )
 	return 0;
-    
+
     payee = payee_ptr;
     payee_buffer = payee;
     return payee -> payee_number;
@@ -220,7 +220,7 @@ gint gsb_data_payee_max_number ( void )
     gint number_tmp = 0;
 
     tmp = payee_list;
-    
+
     while ( tmp )
     {
 	struct_payee *payee;
@@ -257,11 +257,11 @@ gint gsb_data_payee_new ( const gchar *name )
 
         payee -> payee_name = my_strdup ( name );
         combofix = gsb_form_widget_get_widget ( TRANSACTION_FORM_PARTY );
-    
+
         if ( combofix && name )
             gtk_combofix_append_text ( GTK_COMBOFIX ( combofix ), name );
     }
-    else 
+    else
         payee -> payee_name = NULL;
 
     payee_list = g_slist_append ( payee_list, payee );
@@ -271,8 +271,8 @@ gint gsb_data_payee_new ( const gchar *name )
 
 
 /**
- * This internal function is called to free the memory used by a struct_payee structure 
- */ 
+ * This internal function is called to free the memory used by a struct_payee structure
+ */
 static void _gsb_data_payee_free ( struct_payee* payee)
 {
     if ( ! payee )
@@ -362,11 +362,11 @@ gint gsb_data_payee_get_number_by_name ( const gchar *name,
     list_tmp = g_slist_find_custom ( payee_list,
                         name,
                         (GCompareFunc) gsb_data_payee_get_pointer_from_name_in_glist );
-    
+
     if ( list_tmp )
     {
         struct_payee *payee;
-        
+
         payee = list_tmp -> data;
         payee_number = payee -> payee_number;
     }
@@ -452,7 +452,7 @@ gboolean gsb_data_payee_set_name ( gint no_payee,
             gtk_combofix_remove_text ( GTK_COMBOFIX ( combofix ), payee -> payee_name );
 	    g_free ( payee -> payee_name );
     }
-    
+
     /* and copy the new one or set NULL */
     payee -> payee_name = my_strdup ( name );
 
@@ -492,6 +492,29 @@ GSList *gsb_data_payee_get_name_list ( void )
     return return_list;
 }
 
+/**
+ * compare the name of the payee
+ *
+ * \param payee_ptr_a a pointer a pointer to the struct of the payee a
+ * \param payee_ptr_b a pointer a pointer to the struct of the payee b
+ *
+ * \return a > b or NULL if problem
+ * */
+gboolean gsb_data_payee_compare_payees_by_name (gpointer payee_ptr_a,
+                                                gpointer payee_ptr_b)
+{
+    struct_payee *payee_a, *payee_b;
+    gchar *name_a, *name_b;
+    if ( !payee_ptr_a || !payee_ptr_b )
+	return 0;
+
+    payee_a = payee_ptr_a;
+    payee_b = payee_ptr_b;
+    name_a = payee_a -> payee_name;
+    name_b = payee_b -> payee_name;
+    return g_utf8_collate ( name_a, name_b );
+}
+
 /**
  * return a g_slist of names of all the payees and
  * the name of the reports which have to be with the payees
@@ -530,32 +553,42 @@ GSList *gsb_data_payee_get_name_and_report_list ( void )
 
 	if ( gsb_data_report_get_append_in_payee (report_number))
 	{
+        gchar *tmp_str;
+
+        tmp_str = my_strdup ( gsb_data_report_get_report_name ( report_number ) );
 	    if ( tmp_list )
-		tmp_list = g_slist_append ( tmp_list,
-					    g_strconcat ( "\t",
-							  my_strdup (gsb_data_report_get_report_name(report_number)),
-							  NULL ));
+            tmp_list = g_slist_append ( tmp_list, g_strconcat ( "\t", tmp_str, NULL ) );
 	    else
 	    {
-		tmp_list = g_slist_append ( tmp_list,
-					    g_strdup(_("Report")));
-		tmp_list = g_slist_append ( tmp_list,
-					    g_strconcat ( "\t",
-							  my_strdup (gsb_data_report_get_report_name(report_number)),
-							  NULL ));
+            tmp_list = g_slist_append ( tmp_list, g_strdup ( _("Report") ) );
+            tmp_list = g_slist_append ( tmp_list, g_strconcat ( "\t", tmp_str, NULL ) );
 	    }
+        g_free ( tmp_str );
 	}
 	pointer = pointer -> next;
     }
 
     if (tmp_list)
-	return_list = g_slist_append ( return_list,
-				       tmp_list );
+        return_list = g_slist_append ( return_list, tmp_list );
 
     return return_list;
 }
 
 
+void gsb_data_payee_free_name_and_report_list ( GSList *liste )
+{
+    if ( g_slist_length ( liste ) == 2 )
+    {
+        GSList *tmp_list;
+
+        tmp_list = g_slist_nth_data ( liste, 1 );
+        g_slist_foreach ( tmp_list, (GFunc) g_free, NULL );
+        g_slist_free ( tmp_list );
+    }
+    g_slist_free ( liste->data );
+    g_slist_free ( liste );
+}
+
 /**
  * return the description of the payee
  *
@@ -598,7 +631,7 @@ gboolean gsb_data_payee_set_description ( gint no_payee,
     /* we free the last name */
     if ( payee -> payee_description )
 	g_free (payee -> payee_description);
-    
+
     /* and copy the new one */
     if (description)
 	payee -> payee_description = my_strdup (description);
@@ -655,9 +688,9 @@ gsb_real gsb_data_payee_get_balance ( gint no_payee )
 /**
  * reset the counters of the payees
  *
- * \param 
+ * \param
  *
- * \return 
+ * \return
  * */
 void gsb_data_payee_reset_counters ( void )
 {
@@ -675,7 +708,7 @@ void gsb_data_payee_reset_counters ( void )
 
 	list_tmp = list_tmp -> next;
     }
-    
+
     /* reset the blank payee counters */
 
     empty_payee -> payee_balance = null_real;
@@ -704,7 +737,7 @@ void gsb_data_payee_update_counters ( void )
     {
 	gint transaction_number_tmp;
 	transaction_number_tmp = gsb_data_transaction_get_transaction_number (list_tmp_transactions -> data);
-	
+
 	gsb_data_payee_add_transaction_to_payee ( transaction_number_tmp );
 
 	list_tmp_transactions = list_tmp_transactions -> next;
@@ -735,7 +768,7 @@ void gsb_data_payee_add_transaction_to_payee ( gint transaction_number )
     {
 	gchar *tmpstr;
 	tmpstr = g_strdup_printf ( _("The transaction %d has a payee n%d but it doesn't exist."),
-				   transaction_number, 
+				   transaction_number,
 				   gsb_data_transaction_get_party_number (transaction_number));
 	warning_debug (tmpstr);
 	g_free (tmpstr);
@@ -745,7 +778,7 @@ void gsb_data_payee_add_transaction_to_payee ( gint transaction_number )
     payee -> payee_nb_transactions ++;
     if ( ! gsb_data_transaction_get_split_of_transaction ( transaction_number ) )
         payee -> payee_balance = gsb_real_add ( payee -> payee_balance,
-					    gsb_data_transaction_get_adjusted_amount_for_currency 
+					    gsb_data_transaction_get_adjusted_amount_for_currency
                         ( transaction_number, payee_tree_currency (), -1));
 }
 
@@ -770,7 +803,7 @@ void gsb_data_payee_remove_transaction_from_payee ( gint transaction_number )
     if (!payee
             &&
             !gsb_data_transaction_get_split_of_transaction (transaction_number)
-            && 
+            &&
             gsb_data_transaction_get_contra_transaction_number (transaction_number) == 0)
         payee = empty_payee;
 
@@ -878,7 +911,7 @@ gboolean gsb_data_payee_set_search_string ( gint no_payee, const gchar *search_s
     /* we free the last name */
     if ( payee -> payee_search_string )
         g_free (payee -> payee_search_string);
-    
+
     /* and copy the new one */
     if (search_string)
         payee -> payee_search_string = my_strdup (search_string);
@@ -887,3 +920,118 @@ gboolean gsb_data_payee_set_search_string ( gint no_payee, const gchar *search_s
 
     return TRUE;
 }
+
+
+/**
+ * renvoie le nombre de tiers non utilis (fonction  revoir )
+ *
+ * \param
+ *
+ * \return nb_unused
+ */
+gint gsb_data_payee_get_unused_payees ( void )
+{
+    GSList *tmp_list;
+    GSList *used = NULL;
+    gint nb_unused = 0;
+
+    /* on tient compte de toutes les oprations : mthode courte*/
+    if ( etat.add_archive_in_total_balance )
+    {
+        /* it scans the list of sheduled transactions. fix bug 538 */
+        tmp_list = gsb_data_scheduled_get_scheduled_list ();
+        while (tmp_list)
+        {
+            gint payee_number;
+
+            payee_number = gsb_data_scheduled_get_party_number (
+                                gsb_data_scheduled_get_scheduled_number (
+                                tmp_list -> data ) );
+            if ( !g_slist_find (used, GINT_TO_POINTER ( payee_number ) ) )
+            {
+                used = g_slist_append ( used, GINT_TO_POINTER ( payee_number ) );
+            }
+            tmp_list = tmp_list -> next;
+        }
+
+        /* now check each payee to know if it is used */
+        tmp_list = gsb_data_payee_get_payees_list ();
+        while (tmp_list)
+        {
+            struct_payee *payee = tmp_list->data;
+
+            tmp_list = tmp_list->next;
+
+            if ( payee->payee_nb_transactions == 0
+             &&
+             (!used
+              ||
+              !g_slist_find ( used, GINT_TO_POINTER ( payee->payee_number ) ) ) )
+            {
+                /* payee not used */
+                nb_unused++;
+            }
+        }
+
+        return nb_unused;
+    }
+
+    /* mthode longue */
+    /* first we create a list of used payees */
+    tmp_list = gsb_data_transaction_get_complete_transactions_list ();
+    while (tmp_list)
+    {
+        gint payee_number;
+
+        payee_number = gsb_data_transaction_get_party_number (
+                    gsb_data_transaction_get_transaction_number (tmp_list -> data));
+        if (!g_slist_find (used, GINT_TO_POINTER (payee_number)))
+        {
+            used = g_slist_append ( used, GINT_TO_POINTER (payee_number));
+        }
+        tmp_list = tmp_list -> next;
+    }
+
+    /* it also scans the list of sheduled transactions. fix bug 538 */
+    tmp_list = gsb_data_scheduled_get_scheduled_list ();
+    while (tmp_list)
+    {
+        gint payee_number;
+
+        payee_number = gsb_data_scheduled_get_party_number (
+                        gsb_data_scheduled_get_scheduled_number (
+                        tmp_list -> data));
+        if (!g_slist_find (used, GINT_TO_POINTER (payee_number)))
+        {
+            used = g_slist_append ( used, GINT_TO_POINTER (payee_number));
+        }
+        tmp_list = tmp_list -> next;
+    }
+
+    /* now check each payee to know if it is used */
+    tmp_list = gsb_data_payee_get_payees_list ();
+    while (tmp_list)
+    {
+        struct_payee *payee = tmp_list->data;
+
+        tmp_list = tmp_list->next;
+        if ( !used || !g_slist_find (used, GINT_TO_POINTER (payee->payee_number)))
+        {
+            /* payee not used */
+            nb_unused++;
+        }
+    }
+    return nb_unused;
+}
+
+
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ */
+/* Local Variables: */
+/* c-basic-offset: 4 */
+/* End: */
