@@ -31,14 +31,16 @@
 #endif
 
 #include "include.h"
+#include <string.h>
 
 /*START_INCLUDE*/
 #include "gsb_data_reconcile.h"
 #include "dialog.h"
 #include "gsb_data_transaction.h"
+#include "gsb_transactions_list.h"
+#include "gsb_real.h"
 #include "utils_dates.h"
 #include "utils_str.h"
-#include "gsb_real.h"
 /*END_INCLUDE*/
 
 /** \struct
@@ -67,7 +69,6 @@ static gpointer gsb_data_reconcile_get_structure ( gint reconcile_number );
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern gsb_real null_real;
 /*END_EXTERN*/
 
 
@@ -179,9 +180,9 @@ GList *gsb_data_reconcile_get_reconcile_list ( void )
 
 /**
  * find and return the last number of reconcile
- * 
+ *
  * \param none
- * 
+ *
  * \return last number of reconcile
  * */
 gint gsb_data_reconcile_max_number ( void )
@@ -270,10 +271,9 @@ gboolean gsb_data_reconcile_remove ( gint reconcile_number )
     reconcile = gsb_data_reconcile_get_structure ( reconcile_number );
 
     if (!reconcile)
-	return FALSE;
+        return FALSE;
 
-    reconcile_list = g_list_remove ( reconcile_list,
-				      reconcile );
+    reconcile_list = g_list_remove ( reconcile_list, reconcile );
     _gsb_data_reconcile_free ( reconcile );
 
     /* remove that reconcile of the transactions */
@@ -281,15 +281,16 @@ gboolean gsb_data_reconcile_remove ( gint reconcile_number )
 
     while (list_tmp)
     {
-	gint transaction_number = gsb_data_transaction_get_transaction_number (list_tmp -> data);
+        gint transaction_number;
 
-	if ( gsb_data_transaction_get_reconcile_number (transaction_number) == reconcile_number )
-	{
-	    gsb_data_transaction_set_reconcile_number ( transaction_number, 0 );
-	    gsb_data_transaction_set_marked_transaction ( transaction_number,
-							  OPERATION_POINTEE );
-	}
-	list_tmp = list_tmp -> next;
+        transaction_number = gsb_data_transaction_get_transaction_number ( list_tmp -> data );
+        if ( gsb_data_transaction_get_reconcile_number (transaction_number) == reconcile_number )
+        {
+            gsb_data_transaction_set_reconcile_number ( transaction_number, 0 );
+            gsb_data_transaction_set_marked_transaction ( transaction_number, OPERATION_POINTEE );
+            gsb_transactions_list_update_transaction ( transaction_number );
+        }
+        list_tmp = list_tmp -> next;
     }
 
     return TRUE;
@@ -725,10 +726,10 @@ GList *gsb_data_reconcile_get_sort_reconcile_list ( gint account_number )
 
         if (reconcile -> account_number == account_number)
         {
-            rec_list = g_list_insert_sorted ( rec_list, reconcile, 
+            rec_list = g_list_insert_sorted ( rec_list, reconcile,
                                              (GCompareFunc) gsb_data_reconcile_cmp_int );
         }
-	   
+
         tmp_list = tmp_list -> next;
     }
 
@@ -736,7 +737,7 @@ GList *gsb_data_reconcile_get_sort_reconcile_list ( gint account_number )
     while (tmp_list)
     {
         reconcile = tmp_list -> data;
-        
+
         new_list = g_list_append ( new_list, GINT_TO_POINTER (
                                     reconcile -> reconcile_number) );
         tmp_list = tmp_list -> next;
