@@ -31,6 +31,7 @@
 #include "gsb_dirs.h"
 #include "structures.h"
 
+static gchar *help_dir;
 static gchar *locale_dir;
 static gchar *pixmaps_dir;
 static gchar *categories_dir;
@@ -52,6 +53,7 @@ void gsb_dirs_init ( void )
         dir = g_win32_get_package_installation_directory_of_module ( NULL );
 
         categories_dir = g_build_filename ( dir, "share/grisbi/categories", NULL );
+        help_dir = g_build_filename ( dir, "share/doc/grisbi", NULL );
         locale_dir = g_strconcat ( dir, "/share/locale", NULL );
         pixmaps_dir = g_strconcat ( dir, "/share/pixmaps/grisbi", NULL );
         ui_dir = g_strconcat ( dir, "/share/grisbi/ui", NULL );
@@ -64,7 +66,7 @@ void gsb_dirs_init ( void )
     }
 #else
 #ifdef OS_OSX
-	
+
         user_config_dir = g_build_filename ( g_get_home_dir (),
                         "Library/Application Support/Grisbi/config", NULL );
         user_data_dir = g_build_filename ( g_get_home_dir (),
@@ -72,12 +74,13 @@ void gsb_dirs_init ( void )
         user_default_dir = g_strdup ( g_get_home_dir() );
 
 #ifdef GTKOSXAPPLICATION
-       	
+
     if ( gtkosx_application_get_bundle_id ( ) )
     {
         gchar *res_path = gtkosx_application_get_resource_path ();
-        
+
         categories_dir = g_build_filename ( res_path, "share/grisbi/categories", NULL );
+        help_dir = g_build_filename ( res_path, "share/doc/grisbi", NULL );
         locale_dir = g_strconcat (res_path, "/share/locale", NULL );
         pixmaps_dir = g_strconcat (res_path, "/share/pixmaps/grisbi", NULL );
         ui_dir = g_strconcat (res_path, "/share/grisbi/ui", NULL );
@@ -86,15 +89,17 @@ void gsb_dirs_init ( void )
     }
     else {
         categories_dir = g_build_filename ( DATA_PATH, "categories", NULL );
+        help_dir = g_strdup ( HELP_PATH );
         locale_dir = g_strdup ( LOCALEDIR );
         pixmaps_dir = g_strdup ( PIXMAPS_DIR );
-        ui_dir = g_strdup ( UI_DIR );    
+        ui_dir = g_strdup ( UI_DIR );
     }
 
-#endif /* GTKOSXAPPLICATION */ 
+#endif /* GTKOSXAPPLICATION */
 #else
     {
         categories_dir = g_build_filename ( DATA_PATH, "categories", NULL );
+        help_dir = g_strdup ( HELP_PATH );
         locale_dir = g_strdup ( LOCALEDIR );
         pixmaps_dir = g_strdup ( PIXMAPS_DIR );
         ui_dir = g_strdup ( UI_DIR );
@@ -104,7 +109,7 @@ void gsb_dirs_init ( void )
         user_default_dir = g_strdup ( g_get_home_dir() );
     }
 #endif /* OS_OSX */
-#endif
+#endif /* G_OS_WIN32 */
 
     accelerator_filename = g_build_filename ( user_config_dir, "grisbi-accels", NULL );
 }
@@ -113,6 +118,7 @@ void gsb_dirs_init ( void )
 void gsb_dirs_shutdown ( void )
 {
     g_free ( categories_dir );
+    g_free ( help_dir );
     g_free ( locale_dir );
     g_free ( pixmaps_dir );
     g_free ( ui_dir );
@@ -131,6 +137,12 @@ const gchar *gsb_dirs_get_categories_dir ( void )
 }
 
 
+const gchar *gsb_dirs_get_help_dir ( void )
+{
+    return help_dir;
+}
+
+
 const gchar *gsb_dirs_get_locale_dir ( void )
 {
     return locale_dir;
