@@ -23,10 +23,10 @@
 #endif
 
 #include "include.h"
-
+#include <errno.h>
+#include <glib/gi18n.h>
 #include <zlib.h>
 
-
 /*START_INCLUDE*/
 #include "gsb_file_util.h"
 #include "dialog.h"
@@ -85,7 +85,7 @@ gboolean gsb_file_util_test_overwrite ( const gchar *filename )
 	    g_free ( tmpstr );
 	    return FALSE;
 	}
-	
+
 	tmpstr = g_strdup_printf (_("Do you want to overwrite file \"%s\"?"), filename);
 	response = question_yes_no_hint (_("File already exists"),
 				       tmpstr,
@@ -332,7 +332,7 @@ gboolean gsb_file_util_modify_lock ( gboolean create_lock )
         {
             gchar* tmp_str;
 
-            tmp_str = g_strdup_printf ( _("Cannot write lock file :'%s': %s"),
+            tmp_str = g_strdup_printf ( _("Cannot write lock file: '%s': %s"),
                                 nom_fichier_comptes,
                                 g_strerror ( errno ) );
             dialogue_error ( tmp_str );
@@ -359,7 +359,7 @@ gboolean gsb_file_util_modify_lock ( gboolean create_lock )
         {
             gchar* tmp_str;
 
-            tmp_str = g_strdup_printf (_("Cannot erase lock file :'%s': %s"),
+            tmp_str = g_strdup_printf (_("Cannot erase lock file: '%s': %s"),
                                 nom_fichier_comptes,
                                 g_strerror ( errno ) );
             dialogue_error ( tmp_str );
