@@ -30,21 +30,23 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_form_config.h"
-#include "utils.h"
 #include "dialog.h"
 #include "gsb_account.h"
 #include "gsb_automem.h"
 #include "gsb_data_account.h"
 #include "gsb_data_form.h"
+#include "gsb_file.h"
 #include "gsb_form.h"
 #include "gsb_form_widget.h"
 #include "navigation.h"
-#include "utils_str.h"
-#include "traitement_variables.h"
 #include "structures.h"
+#include "traitement_variables.h"
+#include "utils.h"
+#include "utils_str.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -80,7 +82,6 @@ static gboolean gsb_form_config_update_form_config ( gint account_number );
 /*START_EXTERN*/
 extern GtkWidget *form_transaction_part;
 extern gint saved_allocation_size;
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 
@@ -152,7 +153,8 @@ void gsb_form_config_make_configuration_box ( GtkWidget *vbox_parent )
     gtk_box_pack_start ( GTK_BOX (paddingbox), hbox, FALSE, FALSE, 0 );
 
     /* the accounts option_menu */
-    accounts_combobox = gsb_account_create_combo_list ((GtkSignalFunc) gsb_form_config_change_account_choice, NULL, FALSE );
+    accounts_combobox = gsb_account_create_combo_list ( G_CALLBACK ( gsb_form_config_change_account_choice ),
+                        NULL, FALSE );
 
     /*create the scolled window for tree_view */
     sw = gtk_scrolled_window_new ( NULL, NULL);
@@ -237,7 +239,7 @@ GtkWidget *gsb_form_config_create_tree_view ( GtkListStore *store )
      * the config box increase too */
 
     tree_view = gtk_tree_view_new_with_model ( GTK_TREE_MODEL ( store ));
-    
+
     gtk_tree_selection_set_mode ( GTK_TREE_SELECTION ( gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view))),
 				  GTK_SELECTION_NONE );
 
@@ -482,7 +484,7 @@ gboolean gsb_form_config_update_form_config ( gint account_number )
     gint row;
     gint column;
     gint current_element_number;
-    
+
     /* fill the store */
     gsb_form_config_fill_store (account_number);
 
@@ -602,7 +604,7 @@ gboolean gsb_form_config_toggle_element_button ( GtkWidget *toggle_button )
 		    if ( no_second_element == -1 )
 		    {
 			/* 			il n'y a qu'un elt */
-			
+
 			gsb_data_form_set_value ( account_number,
 						  j,
 						  i,
@@ -728,8 +730,7 @@ gboolean gsb_form_config_toggle_element_button ( GtkWidget *toggle_button )
     gsb_form_config_fill_store (account_number);
     gsb_form_create_widgets ();
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
     return FALSE;
 }
 
@@ -747,7 +748,7 @@ gboolean gsb_form_config_fill_store ( gint account_number )
     GtkListStore *store;
 
     store = GTK_LIST_STORE ( gtk_tree_view_get_model ( GTK_TREE_VIEW ( form_config_tree_view )));
-						
+
     gtk_list_store_clear ( store );
 
     for ( row=0 ; row < gsb_data_form_get_nb_rows (account_number) ; row++ )
@@ -802,7 +803,7 @@ gboolean gsb_form_config_realized ( GtkWidget *tree_view,
 										column ) * width / 100 );
     }
 
-    gdk_window_set_cursor ( tree_view -> window, 
+    gdk_window_set_cursor ( tree_view -> window,
 			    gdk_cursor_new ( GDK_FLEUR ) );
 
     return FALSE;
@@ -846,8 +847,7 @@ gboolean gsb_form_config_change_column_size ( GtkWidget *tree_view,
 	    }
     }
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     /* update the form if needed */
 	saved_allocation_size = 0;
@@ -881,8 +881,7 @@ gboolean gsb_form_config_add_line ( void )
     gsb_form_config_fill_store (account_number);
     gsb_form_create_widgets ();
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
     return FALSE;
 }
 
@@ -957,8 +956,7 @@ gboolean gsb_form_config_remove_line ( void )
     gsb_form_config_fill_store (account_number);
     gsb_form_create_widgets ();
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
     return FALSE;
 }
 
@@ -996,8 +994,7 @@ gboolean gsb_form_config_add_column ( void )
 
     /* show the result */
     gsb_form_config_realized ( form_config_tree_view, NULL );
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
     return FALSE;
 }
 
@@ -1014,7 +1011,7 @@ gboolean gsb_form_config_remove_column ( void )
     gint row;
     gint account_number;
     gint nb_columns;
-    
+
     account_number = gsb_account_get_combo_account_number ( accounts_combobox );
     nb_columns = gsb_data_form_get_nb_columns (account_number);
 
@@ -1078,8 +1075,7 @@ gboolean gsb_form_config_remove_column ( void )
 
     /* fill the list */
     gsb_form_config_realized ( form_config_tree_view, NULL );
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
     return FALSE;
 }
 
@@ -1190,7 +1186,7 @@ gboolean gsb_form_config_drag_begin ( GtkWidget *tree_view,
 
     return FALSE;
 }
-					
+
 
 /**
  * called when we end a drag,
@@ -1263,8 +1259,7 @@ gboolean gsb_form_config_drag_end ( GtkWidget *tree_view,
     gsb_form_config_fill_store (account_number);
     gsb_form_fill_from_account (account_number);
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
     return (FALSE);
 }
 
