@@ -32,6 +32,7 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_form_transaction.h"
@@ -61,7 +62,6 @@
 
 /*START_EXTERN*/
 extern GtkWidget *form_button_recover_split;
-extern gsb_real null_real;
 /*END_EXTERN*/
 
 
@@ -149,13 +149,17 @@ gboolean gsb_form_transaction_complete_form_by_payee ( const gchar *payee_name )
          &&
          element -> element_number != TRANSACTION_FORM_VALUE_DATE
          &&
+         element -> element_number != TRANSACTION_FORM_CREDIT
+         &&
+         element -> element_number != TRANSACTION_FORM_DEBIT
+         &&
          element -> element_number != TRANSACTION_FORM_EXERCICE
          &&
          element -> element_number != TRANSACTION_FORM_PARTY
          &&
          element -> element_number != TRANSACTION_FORM_MODE
-         && 
-         element -> element_number != TRANSACTION_FORM_TYPE 
+         &&
+         element -> element_number != TRANSACTION_FORM_TYPE
          &&
          element -> element_number != TRANSACTION_FORM_DEVISE )
     {
@@ -174,6 +178,15 @@ gboolean gsb_form_transaction_complete_form_by_payee ( const gchar *payee_name )
             gtk_widget_show ( form_button_recover_split );
         }
     }
+    else if ( ( element -> element_number == TRANSACTION_FORM_CREDIT && !conf.automatic_erase_credit_debit )
+         ||
+         ( element -> element_number == TRANSACTION_FORM_DEBIT && !conf.automatic_erase_credit_debit ) )
+    {
+        gsb_form_fill_element ( element -> element_number,
+                        account_number,
+                        transaction_number,
+                        TRUE );
+    }
     else if ( element -> element_number == TRANSACTION_FORM_TYPE )
     {
         GtkWidget *widget;
@@ -192,7 +205,7 @@ gboolean gsb_form_transaction_complete_form_by_payee ( const gchar *payee_name )
                                    GSB_PAYMENT_DEBIT,
                                    account_number, 0, FALSE );
         else
-            gsb_payment_method_create_combo_list ( widget, GSB_PAYMENT_CREDIT, 
+            gsb_payment_method_create_combo_list ( widget, GSB_PAYMENT_CREDIT,
                         account_number, 0, FALSE );
 
         if ( GTK_WIDGET_VISIBLE (widget))
@@ -240,7 +253,7 @@ gboolean gsb_form_transaction_complete_form_by_payee ( const gchar *payee_name )
  * \param account_number the account we want to find first the party
  * keep it
  *
- * \return the number of the transaction found, or 0 
+ * \return the number of the transaction found, or 0
  * */
 gint gsb_form_transactions_look_for_last_party ( gint no_party,
                         gint no_new_transaction,
@@ -286,7 +299,7 @@ gint gsb_form_transactions_look_for_last_party ( gint no_party,
 
 /**
  * Clone the children of a split transaction to add the to the new split
- * 
+ *
  * \param new_transaction_number	the number of the new mother of the cloned transaction
  * \param no_last_split		the no of last split mother
  *
@@ -334,11 +347,11 @@ gboolean gsb_form_transaction_recover_splits_of_transaction ( gint new_transacti
 
 
 /**
- * return a list of numbers of parties if the party in the form is a 
+ * return a list of numbers of parties if the party in the form is a
  * report
- * 
+ *
  * \param none
- * 
+ *
  * \return a g_slist, with -1 if it's a normal party or a list of parties if it's a report
  * */
 GSList *gsb_form_transaction_get_parties_list_from_report ( void )
@@ -368,7 +381,7 @@ GSList *gsb_form_transaction_get_parties_list_from_report ( void )
             return parties_list;
         }
 
-        if ( strncmp ( string, _("Report : "), 7 ) )
+        if ( strncmp ( string, _("Report: "), 7 ) )
             /* the party is not a report, set -1 and go away */
             parties_list = g_slist_append ( parties_list, GINT_TO_POINTER ( -1 ) );
         else
@@ -380,39 +393,30 @@ GSList *gsb_form_transaction_get_parties_list_from_report ( void )
             tab_char = g_strsplit ( string, " : ", 2 );
 
             report_number = gsb_data_report_get_report_by_name (tab_char[1]);
-
             if (report_number)
             {
-            GSList *list_transactions;
-            GSList *list_tmp;
+                GSList *list_payees;
+                GSList *list_tmp;
 
-            list_transactions = recupere_opes_etat (report_number);
+                list_payees = gsb_data_report_get_payee_numbers ( report_number );
+                list_tmp = list_payees;
+                while ( list_tmp )
+                {
+                    parties_list = g_slist_append ( parties_list, list_tmp->data );
 
-            list_tmp = list_transactions;
+                    list_tmp = list_tmp->next;
+                }
 
-            while ( list_tmp )
-            {
-                gint transaction_number;
-
-                transaction_number = gsb_data_transaction_get_transaction_number (list_tmp -> data);
-
-                if ( !g_slist_find ( parties_list,
-                         GINT_TO_POINTER (gsb_data_transaction_get_party_number (transaction_number))))
-                parties_list = g_slist_append ( parties_list,
-                                GINT_TO_POINTER ( gsb_data_transaction_get_party_number (transaction_number)));
-                list_tmp = list_tmp -> next;
-            }
-            g_slist_free ( list_transactions );
             }
             else
-            /* the report was not found, set -1 */
-            parties_list = g_slist_append ( parties_list, GINT_TO_POINTER ( -1 ) );
-            g_strfreev ( tab_char );
+                /* the report was not found, set -1 */
+                parties_list = g_slist_append ( parties_list, GINT_TO_POINTER ( -1 ) );
+                g_strfreev ( tab_char );
         }
     }
     else
-	/* no party so not a report */
-	parties_list = g_slist_append ( parties_list, GINT_TO_POINTER ( - 1) );
+        /* no party so not a report */
+        parties_list = g_slist_append ( parties_list, GINT_TO_POINTER ( - 1) );
 
     return parties_list;
 }
@@ -424,11 +428,11 @@ GSList *gsb_form_transaction_get_parties_list_from_report ( void )
  * - create the contra-transaction
  * - delete the last contra-transaction if it's a modification
  * - append the contra-transaction to the tree view or update the tree_view
- * 
+ *
  * \param transaction_number	the new transaction or the modifed transaction
  * \param new_transaction 	TRUE if it's a new transaction
  * \param account_transfer 	the number of the account we want to create the contra-transaction
- * 
+ *
  * \return the number of the contra-transaction
  * */
 gint gsb_form_transaction_validate_transfer ( gint transaction_number,
@@ -437,6 +441,7 @@ gint gsb_form_transaction_validate_transfer ( gint transaction_number,
 {
     GDate *contra_value_date = NULL;
     const gchar *contra_transaction_content = NULL;
+    gint contra_payment_number = 0;
     gint contra_transaction_number;
     gint contra_mother_number = 0;
     gint contra_marked_transaction = 0;
@@ -467,6 +472,11 @@ gint gsb_form_transaction_validate_transfer ( gint transaction_number,
             contra_mother_number = gsb_data_transaction_get_mother_transaction_number (
                             contra_transaction_number );
 
+            /* on récupère le moyen de payement de l'opération fille qui ne doit pas changer */
+            if ( contra_mother_number > 0 )
+                contra_payment_number = gsb_data_transaction_get_method_of_payment_number (
+                        contra_transaction_number );
+
             /* Copying/deleting remove the marked information, so we get it here */
             contra_marked_transaction = gsb_data_transaction_get_marked_transaction (
                             contra_transaction_number );
@@ -480,14 +490,12 @@ gint gsb_form_transaction_validate_transfer ( gint transaction_number,
             if ( value_date )
                 contra_value_date = gsb_date_copy ( value_date );
 
-
             /* check if we change the account target */
             if ( gsb_data_transaction_get_contra_transaction_account (
                             transaction_number) != account_transfer )
             {
                 /* it was a transfer and the user changed the target account so we delete
                  * the last contra transaction contra_transaction_transfer has just been set */
-
                 gsb_data_transaction_set_contra_transaction_number (
                                 contra_transaction_number, 0);
                 gsb_transactions_list_delete_transaction (contra_transaction_number, FALSE);
@@ -504,7 +512,6 @@ gint gsb_form_transaction_validate_transfer ( gint transaction_number,
     /* so, now, it's either a new transfer and new_transaction is TRUE,
      * either a transfer without changing the target account and in that case, contra_transaction_number is
      * already set */
-
     if ( new_transaction )
         contra_transaction_number = gsb_data_transaction_new_transaction ( account_transfer );
 
@@ -518,6 +525,16 @@ gint gsb_form_transaction_validate_transfer ( gint transaction_number,
     gsb_data_transaction_set_mother_transaction_number ( contra_transaction_number,
 							 contra_mother_number );
 
+    /* si la contre opération est une fille et pas rapprochée on change la date */
+    if ( contra_mother_number > 0 && contra_marked_transaction != OPERATION_RAPPROCHEE )
+    {
+        const GDate *date;
+
+        date = gsb_data_transaction_get_date ( transaction_number );
+        gsb_data_transaction_set_date ( contra_mother_number, date );
+        gsb_transactions_list_update_transaction ( contra_mother_number );
+    }
+
     /* If this is not a new transaction it restores the marked statement */
     gsb_data_transaction_set_marked_transaction ( contra_transaction_number,
                         contra_marked_transaction );
@@ -538,15 +555,21 @@ gint gsb_form_transaction_validate_transfer ( gint transaction_number,
     /* we have to check the change */
     gsb_currency_check_for_change ( contra_transaction_number );
 
-    /* set the contra-method of payment,
+    /* set the contra-method of payment if the contra-transaction was not a child of split,
      * there is no place into the transaction structure for that, so it was not taken with the form,
      * we need to get it now from the form */
-    contra_payment_button = gsb_form_widget_get_widget (TRANSACTION_FORM_CONTRA);
-    if (contra_payment_button
-	&&
-	GTK_WIDGET_VISIBLE (contra_payment_button))
-	gsb_data_transaction_set_method_of_payment_number ( contra_transaction_number,
-							    gsb_payment_method_get_selected_number (contra_payment_button));
+    if ( contra_mother_number == 0 )
+    {
+        contra_payment_button = gsb_form_widget_get_widget ( TRANSACTION_FORM_CONTRA );
+        if ( contra_payment_button
+         &&
+         GTK_WIDGET_VISIBLE ( contra_payment_button ) )
+        gsb_data_transaction_set_method_of_payment_number ( contra_transaction_number,
+                        gsb_payment_method_get_selected_number ( contra_payment_button ) );
+    }
+    else
+        gsb_data_transaction_set_method_of_payment_number ( contra_transaction_number,
+                        contra_payment_number );
 
     /* set the content of the contra-method of paiement if it is not a new transaction */
     if ( !new_transaction )
@@ -561,9 +584,9 @@ gint gsb_form_transaction_validate_transfer ( gint transaction_number,
 
     /* show the contra_transaction */
     if ( new_transaction )
-	gsb_transactions_list_append_new_transaction (contra_transaction_number, TRUE);
+        gsb_transactions_list_append_new_transaction (contra_transaction_number, TRUE);
     else
-	gsb_transactions_list_update_transaction (contra_transaction_number);
+        gsb_transactions_list_update_transaction (contra_transaction_number);
 
     return contra_transaction_number;
 }
@@ -602,20 +625,20 @@ gboolean gsb_form_transaction_change_clicked ( GtkWidget *button,
                         gsb_form_widget_get_widget ( TRANSACTION_FORM_DEVISE ) );
         link_number = gsb_data_currency_link_search ( account_currency_number,
                         currency_number );
-        if ( link_number 
-         && 
+        if ( link_number
+         &&
          gsb_data_currency_link_get_first_currency ( link_number )
          == account_currency_number )
             gsb_currency_exchange_dialog ( account_currency_number, currency_number,
                         1,
                         gsb_data_currency_link_get_change_rate ( link_number ),
-                        null_real, 
+                        null_real,
                         TRUE );
         else
             gsb_currency_exchange_dialog ( account_currency_number, currency_number,
                         0,
                         gsb_data_currency_link_get_change_rate ( link_number ),
-                        null_real, 
+                        null_real,
                         TRUE );
     }
     else
@@ -624,7 +647,7 @@ gboolean gsb_form_transaction_change_clicked ( GtkWidget *button,
         gsb_currency_exchange_dialog ( account_currency_number, currency_number,
                         gsb_data_transaction_get_change_between ( transaction_number ),
                         gsb_data_transaction_get_exchange_rate ( transaction_number ),
-                        gsb_data_transaction_get_exchange_fees ( transaction_number ), 
+                        gsb_data_transaction_get_exchange_fees ( transaction_number ),
                         TRUE );
     }
 
