@@ -32,22 +32,25 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_form_widget.h"
 #include "gsb_calendar_entry.h"
+#include "gsb_color.h"
 #include "gsb_currency.h"
 #include "gsb_data_account.h"
 #include "gsb_data_budget.h"
 #include "gsb_data_category.h"
 #include "gsb_data_form.h"
 #include "gsb_data_payee.h"
+#include "gsb_data_report.h"
 #include "gsb_form.h"
 #include "gsb_form_transaction.h"
 #include "gsb_fyear.h"
+#include "gsb_locale.h"
 #include "gsb_payment_method.h"
 #include "gtk_combofix.h"
-#include "traitement_variables.h"
 #include "gsb_data_payment.h"
 #include "structures.h"
 #include "erreur.h"
@@ -60,7 +63,6 @@ static gboolean gsb_form_widget_can_focus ( gint element_number );
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern GdkColor calendar_entry_color;
 extern GtkWidget *form_button_cancel;
 extern GtkWidget *form_button_valid;
 /*END_EXTERN*/
@@ -75,6 +77,12 @@ static gint old_debit_payment_number = 0;
 static gchar *old_credit_payment_content = NULL;
 static gchar *old_debit_payment_content = NULL;
 
+/* empty entry in form color */
+#define EMPTY_ENTRY_COLOR_RED   50000
+#define EMPTY_ENTRY_COLOR_GREEN 50000
+#define EMPTY_ENTRY_COLOR_BLUE  50000
+
+
 /**
  * return the list wich contains the widgets of the form
  *
@@ -92,13 +100,14 @@ GSList *gsb_form_widget_get_list ( void )
  * free the content of the list of the widget's form
  * so free the content of the form
  *
- * \param 
+ * \param
  *
  * \return FALSE
  * */
 gboolean gsb_form_widget_free_list ( void )
 {
     GSList *tmp_list;
+    GtkWidget *widget_signals;
 
     devel_debug (NULL);
 
@@ -114,12 +123,41 @@ gboolean gsb_form_widget_free_list ( void )
 
         if (! element )
             continue;
-	
+
         /* just to make sure... */
-        if ( element -> element_widget ) 
+        if ( element -> element_widget )
         {
             if (GTK_IS_WIDGET (element -> element_widget))
             {
+                widget_signals = NULL;
+                if ( GTK_IS_ENTRY ( element -> element_widget ) )
+                {
+                    widget_signals = element -> element_widget;
+                }
+                else if ( GTK_IS_COMBOFIX ( element -> element_widget ) )
+                {
+                    widget_signals = GTK_COMBOFIX ( element -> element_widget ) -> entry;
+                }
+
+                if ( widget_signals )
+                {
+                    g_signal_handlers_disconnect_by_func ( G_OBJECT ( widget_signals ),
+                        G_CALLBACK ( gsb_form_entry_get_focus ),
+                        GINT_TO_POINTER ( element -> element_number ));
+                    g_signal_handlers_disconnect_by_func ( G_OBJECT ( widget_signals ),
+                        G_CALLBACK ( gsb_form_entry_lose_focus ),
+                        GINT_TO_POINTER ( element -> element_number ));
+                    g_signal_handlers_disconnect_by_func ( G_OBJECT ( widget_signals ),
+                        G_CALLBACK ( gsb_form_button_press_event ),
+                        GINT_TO_POINTER ( element -> element_number ));
+                    g_signal_handlers_disconnect_by_func ( G_OBJECT ( widget_signals ),
+                        G_CALLBACK ( gsb_form_key_press_event ),
+                        GINT_TO_POINTER ( element -> element_number ));
+                    g_signal_handlers_disconnect_by_func ( G_OBJECT ( widget_signals ),
+                        G_CALLBACK ( gsb_form_combo_selection_changed ),
+                        GINT_TO_POINTER ( element -> element_number ));
+                }
+
                 /* if there is something in the combofix we destroy, the popup will
                  * be showed because destroying the gtk_entry will erase it directly,
                  * so the simpliest way to avoid that is to erase now the entry, but with
@@ -135,7 +173,7 @@ gboolean gsb_form_widget_free_list ( void )
                 element -> element_widget = NULL;
             }
         }
-        else 
+        else
         {
             alert_debug ("element_widget is NULL\n");
         }
@@ -162,6 +200,7 @@ GtkWidget *gsb_form_widget_create ( gint element_number,
                         gint account_number )
 {
     GtkWidget *widget;
+    GSList *tmp_list;
 
     if (!element_number)
 	return NULL;
@@ -208,8 +247,10 @@ GtkWidget *gsb_form_widget_create ( gint element_number,
 	    break;
 
 	case TRANSACTION_FORM_PARTY:
-	    widget = gtk_combofix_new (
-                        gsb_data_payee_get_name_and_report_list ( ) );
+        tmp_list = gsb_data_payee_get_name_and_report_list ( );
+	    widget = gtk_combofix_new ( tmp_list );
+        gsb_data_payee_free_name_and_report_list ( tmp_list );
+
 	    gtk_combofix_set_force_text ( GTK_COMBOFIX (widget),
 					  etat.combofix_force_payee );
 	    gtk_combofix_set_max_items ( GTK_COMBOFIX (widget),
@@ -223,8 +264,9 @@ GtkWidget *gsb_form_widget_create ( gint element_number,
 	    break;
 
 	case TRANSACTION_FORM_CATEGORY:
-	    widget = gtk_combofix_new (
-                         gsb_data_category_get_name_list ( TRUE, TRUE, TRUE, TRUE ) );
+        tmp_list = gsb_data_category_get_name_list ( TRUE, TRUE, TRUE, TRUE );
+	    widget = gtk_combofix_new ( tmp_list );
+        gsb_data_categorie_free_name_list ( tmp_list );
 	    gtk_combofix_set_force_text ( GTK_COMBOFIX (widget),
 					  etat.combofix_force_category );
 	    gtk_combofix_set_max_items ( GTK_COMBOFIX (widget),
@@ -368,7 +410,7 @@ GtkWidget *gsb_form_widget_create ( gint element_number,
     else {
     	alert_debug ( "Widget should not be NULL" );
     }
-    
+
     return widget;
 }
 
@@ -505,7 +547,7 @@ gint gsb_form_widget_next_element ( gint account_number,
     gint return_value_number = 0;
     gint form_column_number;
     gint form_row_number;
-    
+
     if ( !gsb_data_form_look_for_value ( account_number,
 					 element_number,
 					 &row,
@@ -515,7 +557,7 @@ gint gsb_form_widget_next_element ( gint account_number,
     form_column_number = gsb_data_form_get_nb_columns (account_number);
     form_row_number = gsb_data_form_get_nb_rows (account_number);
 
-    while ( !gsb_form_widget_can_focus (return_value_number)) 
+    while ( !gsb_form_widget_can_focus (return_value_number))
     {
 	switch ( direction )
 	{
@@ -524,7 +566,7 @@ gint gsb_form_widget_next_element ( gint account_number,
 		{
 		    /* we are at the upper left, go on the bottom right */
 		    column = form_column_number;
-		    row = form_row_number -1; 
+		    row = form_row_number -1;
 		}
 
 		if ( --column == -1 )
@@ -550,7 +592,7 @@ gint gsb_form_widget_next_element ( gint account_number,
 			continue;
 		    }
 		    column = -1;
-		    row = 0; 
+		    row = 0;
 		}
 
 		if ( ++column == form_column_number )
@@ -600,7 +642,7 @@ gint gsb_form_widget_next_element ( gint account_number,
  * check if the given element can receive focus
  *
  * \param element_number
- * 
+ *
  * \return TRUE : can receive focus, or FALSE
  * */
 gboolean gsb_form_widget_can_focus ( gint element_number )
@@ -692,7 +734,7 @@ gboolean gsb_form_widget_check_empty ( GtkWidget *entry )
  * \param entry must be an entry
  * \param empty TRUE or FALSE
  *
- * \return 
+ * \return
  * */
 void gsb_form_widget_set_empty ( GtkWidget *entry,
                     gboolean empty )
@@ -700,9 +742,9 @@ void gsb_form_widget_set_empty ( GtkWidget *entry,
     GdkColor gray, black;
 
     gray.pixel = 0;
-    gray.red = EMPTY_ENTRY_COLOR_RED; 
+    gray.red = EMPTY_ENTRY_COLOR_RED;
     gray.green = EMPTY_ENTRY_COLOR_GREEN;
-    gray.blue = EMPTY_ENTRY_COLOR_BLUE; 
+    gray.blue = EMPTY_ENTRY_COLOR_BLUE;
 
     black.pixel = 0;
     black.red = 0;
@@ -716,18 +758,18 @@ void gsb_form_widget_set_empty ( GtkWidget *entry,
 
     if ( ! empty )
     {
-	gtk_widget_modify_text ( entry, 
+	gtk_widget_modify_text ( entry,
 				 GTK_STATE_NORMAL,
 				 &black );
     }
     else
     {
-	gtk_widget_modify_text ( entry, 
+	gtk_widget_modify_text ( entry,
 				 GTK_STATE_NORMAL,
 				 &gray );
     }
 
-	gtk_widget_modify_base ( entry, 
+	gtk_widget_modify_base ( entry,
 				 GTK_STATE_NORMAL,
 				 NULL );
 
@@ -736,7 +778,7 @@ void gsb_form_widget_set_empty ( GtkWidget *entry,
 
 
 /**
- * called when an debit or credit entry get the focus, 
+ * called when an debit or credit entry get the focus,
  * if the entry is free, set it normal and erase the help content
  *
  * \param entry
@@ -748,7 +790,6 @@ gboolean gsb_form_widget_entry_get_focus ( GtkWidget *entry,
                         GdkEventFocus *ev,
                         gint *ptr_origin )
 {
-    GtkWidget *fyear_button;
     GtkWidget *widget;
     GtkWidget *tmp_widget;
     gint element_number;
@@ -773,15 +814,6 @@ gboolean gsb_form_widget_entry_get_focus ( GtkWidget *entry,
 
     switch ( element_number )
     {
-    case TRANSACTION_FORM_DATE:
-    case TRANSACTION_FORM_VALUE_DATE:
-        /* set the financial year on automatic by default */
-        fyear_button = gsb_form_widget_get_widget (TRANSACTION_FORM_EXERCICE);
-        if ( fyear_button
-         &&
-         gsb_data_account_get_current_transaction_number (account_number) == -1 )
-            gsb_fyear_set_combobox_history ( fyear_button, 0 );
-        break;
     case TRANSACTION_FORM_DEBIT :
         /* on met old_debit = NULl car avec g_free plantage */
         if ( old_debit && strlen ( old_debit ) > 0 )
@@ -882,7 +914,7 @@ gboolean gsb_form_widget_entry_get_focus ( GtkWidget *entry,
         gsb_form_check_auto_separator (entry);
         break;
     }
-    
+
     /* sensitive the valid and cancel buttons */
     gtk_widget_set_sensitive (GTK_WIDGET (form_button_valid), TRUE);
     gtk_widget_set_sensitive (GTK_WIDGET (form_button_cancel), TRUE);
@@ -954,7 +986,7 @@ gboolean gsb_form_widget_amount_entry_changed ( GtkWidget *entry,
     {
 	    /* the entry is not valid, make it red */
 		gtk_widget_modify_base ( entry, GTK_STATE_NORMAL,
-                        &calendar_entry_color );
+                        gsb_color_get_couleur ( "entry_error_color" ) );
     }
 
     return FALSE;
@@ -982,9 +1014,9 @@ gboolean gsb_form_widget_get_valide_amout_entry ( const gchar *string )
      ( g_utf8_strchr ( ptr, -1, '*' ) && g_utf8_strchr ( ptr, -1, '-' ) ) )
         return FALSE;
 
-    mon_decimal_point = gsb_real_get_decimal_point ( );
+    mon_decimal_point = gsb_locale_get_mon_decimal_point ( );
     decimal_point = g_utf8_get_char_validated ( mon_decimal_point, -1 );
-    mon_thousands_sep = gsb_real_get_thousands_sep ( );
+    mon_thousands_sep = gsb_locale_get_mon_thousands_sep ( );
     if ( mon_thousands_sep )
         thousands_sep = g_utf8_get_char_validated ( mon_thousands_sep, -1 );
 
@@ -1095,8 +1127,8 @@ gboolean gsb_form_combo_selection_changed ( GtkTreeSelection *tree_selection,
         {
         case TRANSACTION_FORM_CATEGORY:
             widget = gsb_form_widget_get_widget ( TRANSACTION_FORM_DEVISE );
-            if ( widget != NULL 
-             && 
+            if ( widget != NULL
+             &&
              GTK_WIDGET_VISIBLE (
              gsb_form_widget_get_widget ( TRANSACTION_FORM_DEVISE) ) )
             {
@@ -1208,8 +1240,8 @@ gboolean gsb_form_widget_amount_entry_validate ( gint element_number )
         return TRUE;
     }
 
-    mon_decimal_point = gsb_real_get_decimal_point ( );
-    if ( g_strrstr ( text, gsb_real_get_decimal_point ( ) ) == NULL )
+    mon_decimal_point = gsb_locale_get_mon_decimal_point ( );
+    if ( g_strrstr ( text, gsb_locale_get_mon_decimal_point ( ) ) == NULL )
         tmp_str = g_strconcat ( text, mon_decimal_point, NULL );
     else
         tmp_str= g_strdup ( text );
@@ -1224,7 +1256,7 @@ gboolean gsb_form_widget_amount_entry_validate ( gint element_number )
     else
     {
         /* the entry is not valid, make it red */
-        gtk_widget_modify_base ( entry, GTK_STATE_NORMAL, &calendar_entry_color );
+        gtk_widget_modify_base ( entry, GTK_STATE_NORMAL, gsb_color_get_couleur ( "entry_error_color" ) );
         return_value = FALSE;
     }
 
@@ -1235,6 +1267,30 @@ gboolean gsb_form_widget_amount_entry_validate ( gint element_number )
 }
 
 
+/**
+ * update the payee combofix in the form with the current current report
+ *
+ * \param report_number
+ * \param sens              FALSE remove report TRUE add report
+ *
+ * \return FALSE
+ * */
+gboolean gsb_form_widget_update_payee_combofix ( gint report_number,
+                        gint sens )
+{
+    if ( sens )
+        gtk_combofix_append_report (  GTK_COMBOFIX ( gsb_form_widget_get_widget
+                        (TRANSACTION_FORM_PARTY)),
+                        gsb_data_report_get_report_name ( report_number ) );
+    else
+        gtk_combofix_remove_report ( GTK_COMBOFIX ( gsb_form_widget_get_widget
+                        (TRANSACTION_FORM_PARTY)),
+                        gsb_data_report_get_report_name ( report_number ) );
+
+    return FALSE;
+}
+
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
