@@ -1,9 +1,9 @@
 /* ************************************************************************** */
 /*                                                                            */
-/*     Copyright (C)	2000-2008 Cédric Auger (cedric@grisbi.org)	          */
-/*			2003-2008 Benjamin Drieu (bdrieu@april.org)	                      */
-/*                      2009-2010 Pierre Biava (grisbi@pierre.biava.name)     */
-/* 			http://www.grisbi.org				                              */
+/*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
+/*          2003-2008 Benjamin Drieu (bdrieu@april.org)                       */
+/*                      2009-2013 Pierre Biava (grisbi@pierre.biava.name)     */
+/*          http://www.grisbi.org                                             */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -32,29 +32,36 @@
 #endif
 
 #include "include.h"
+#include <string.h>
+#include <ctype.h>
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_reconcile.h"
 #include "dialog.h"
-#include "utils_dates.h"
+#include "fenetre_principale.h"
+#include "gsb_color.h"
 #include "gsb_calendar_entry.h"
 #include "gsb_data_account.h"
 #include "gsb_data_reconcile.h"
 #include "gsb_data_transaction.h"
+#include "gsb_file.h"
 #include "gsb_form.h"
 #include "gsb_form_widget.h"
-#include "navigation.h"
-#include "fenetre_principale.h"
 #include "gsb_real.h"
 #include "gsb_reconcile_list.h"
 #include "gsb_scheduler_list.h"
 #include "gsb_transactions_list.h"
-#include "utils_editables.h"
+#include "menu.h"
+#include "navigation.h"
+#include "structures.h"
 #include "traitement_variables.h"
-#include "utils_str.h"
 #include "transaction_list.h"
 #include "transaction_list_sort.h"
-#include "structures.h"
+#include "utils_dates.h"
+#include "utils_real.h"
+#include "utils_str.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -66,15 +73,12 @@ static gboolean gsb_reconcile_entry_lose_focus ( GtkWidget *entry,
 static gboolean gsb_reconcile_finish_reconciliation ( GtkWidget *button,
 					    gpointer null );
 static void gsb_reconcile_sensitive ( gboolean sensitive );
+static gchar *gsb_reconcile_build_label ( int reconcile_number );
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern GdkColor calendar_entry_color;
 extern GtkWidget *label_last_statement;
-extern gint mise_a_jour_liste_comptes_accueil;
-extern GtkWidget * navigation_tree_view;
 extern GtkWidget * reconcile_panel;
-extern GtkUIManager * ui_manager;
 /*END_EXTERN*/
 
 
@@ -117,13 +121,13 @@ GtkWidget *gsb_reconcile_create_box ( void )
     gtk_container_set_border_width ( GTK_CONTAINER ( vbox ), 3 );
     gtk_container_add ( GTK_CONTAINER ( frame ), vbox );
 
-    /* the title of the frame */ 
+    /* the title of the frame */
     label = gtk_label_new ( NULL );
     gtk_label_set_justify ( GTK_LABEL (label), GTK_JUSTIFY_LEFT );
     gtk_misc_set_alignment ( GTK_MISC (label), 0.0, 0.0 );
     gtk_frame_set_label_widget ( GTK_FRAME(frame), label);
 
-    /* number of reconcile */ 
+    /* number of reconcile */
     hbox = gtk_hbox_new ( FALSE, 5 );
     gtk_box_pack_start ( GTK_BOX ( vbox ), hbox, FALSE, FALSE, 0);
 
@@ -204,7 +208,7 @@ GtkWidget *gsb_reconcile_create_box ( void )
     gtk_box_pack_start ( GTK_BOX ( vbox ), separator, FALSE, FALSE, 0);
 
 
-    /* 2nd table under that, with the balances labels */ 
+    /* 2nd table under that, with the balances labels */
     table = gtk_table_new ( 5, 2, FALSE );
     gtk_table_set_row_spacings ( GTK_TABLE ( table ), 5 );
     gtk_box_pack_start ( GTK_BOX ( vbox ), table, FALSE, FALSE, 0);
@@ -276,12 +280,99 @@ GtkWidget *gsb_reconcile_create_box ( void )
     separator = gtk_hseparator_new();
     gtk_box_pack_end ( GTK_BOX ( vbox ), separator, FALSE, FALSE, 0);
 
-    gtk_widget_show_all ( frame ); 
+    gtk_widget_show_all ( frame );
 
     return ( frame );
 }
 
 
+/**
+ * Build the new label for the reconciliation, given the old one.
+ * The expected format is NAME+NUMBER, so this function returns
+ * a newly allocated string whose format is NAME+(NUMBER+1). It
+ * preserves leading '0' for the NUMBER string.
+ *
+ * If this is the first label building (first reconciliation for
+ * this account), then the function returns a standard string
+ * of the account name (lower case) + '-1'.
+ *
+ * \param reconcile_number
+ *
+ * \return the new string label
+ */
+gchar *gsb_reconcile_build_label ( int reconcile_number )
+{
+    gchar *tmp;
+    gchar *old_label;
+    gchar *new_label;
+    gchar format[6] = "%s%0d";
+    int __reconcile_number;
+    int __size;
+    int __expand;
+
+    /* old_label = NAME + NUMBER */
+    old_label = g_strdup ( gsb_data_reconcile_get_name ( reconcile_number ) );
+
+    /* return account NAME + '1' */
+    if ( !old_label )
+    {
+        tmp = gsb_data_account_get_name ( gsb_gui_navigation_get_current_account () );
+        new_label = g_strconcat ( tmp, "-1", NULL );
+        tmp = new_label;
+        while ( *tmp != '\0' )
+        {
+            if ( *tmp == ' ' )
+                *tmp = '-';
+            else
+                *tmp = tolower ( *tmp );
+            tmp ++;
+        }
+        return new_label;
+    }
+
+    /* we try to find some digits at the end of the name,
+     * if found, get the biggest number until we find a non digit character */
+    __expand = 1;
+    tmp = old_label + ( strlen ( old_label ) - 1 ) * sizeof ( gchar );
+
+    while ( tmp >= old_label )
+    {
+        if ( !isdigit ( tmp[0] ) )
+            break;
+
+        if ( *tmp != '9' )
+            __expand = 0;
+        tmp--;
+    }
+
+    tmp ++; /* step forward to the first digit */
+
+    __reconcile_number = utils_str_atoi ( tmp ) + 1;
+
+    /* if stage 99 -> 100 for example,
+     * then we have to allocate one more byte */
+    __size = strlen ( tmp ) + __expand;
+    /* format string for the output (according NUMBER string length) */
+    format[3] = 48 + __size;
+
+    /* close the NAME string */
+    *tmp = 0;
+    /* NAME + NUMBER + '\0' */
+    __size += strlen ( old_label ) * sizeof ( gchar ) + 1;
+    new_label = g_malloc0 ( __size * sizeof ( gchar ) );
+    sprintf ( new_label, format, old_label, __reconcile_number );
+
+    /* replace ' ' by '0' in number */
+    tmp = new_label + strlen ( old_label ) * sizeof ( gchar );
+    while ( *tmp == ' ' )
+        *tmp++ = '0';
+
+    g_free ( old_label );
+
+    return new_label;
+}
+
+
 /**
  * start the reconciliation, called by a click on the
  * reconcile button
@@ -297,106 +388,32 @@ gboolean gsb_reconcile_run_reconciliation ( GtkWidget *button,
     GDate *date;
     gint account_number;
     gint reconcile_number;
-    gchar *last_name;
+    gchar *label;
     gchar *string;
-	gchar* tmpstr;
+    gchar* tmpstr;
 
     account_number = gsb_gui_navigation_get_current_account ();
-
     reconcile_number = gsb_data_reconcile_get_account_last_number (account_number);
 
-    /* get the last reconcile number and try to increase the number in the name */
+    label = gsb_reconcile_build_label ( reconcile_number );
+    gtk_entry_set_text ( GTK_ENTRY ( reconcile_number_entry ), label );
+    g_free ( label );
 
-    last_name = my_strdup (gsb_data_reconcile_get_name (reconcile_number));
-
-    if (last_name)
+    /* reset records in run structure if user has changed of account */
+    if (run.reconcile_account_number != account_number)
     {
-	gchar *tmp_pointer;
-	gchar *end_pointer;
-
-	/* we try to find some digits at the end of the name,
-	 * if found, get the biggest number untill we find a non digit character */
-	end_pointer = last_name + (strlen ( last_name ) - 1) * sizeof (gchar);
-	tmp_pointer = end_pointer;
-
-	while ( isdigit ( tmp_pointer[0] ) && tmp_pointer >= last_name )
-	    tmp_pointer--;
-
-	if ( tmp_pointer != end_pointer )
-	{
-	    /* ok we have some digits at the end of the name */
-	    gchar *zero_string;
-	    gint digit_size;
-	    gint new_digit_size;
-	    gchar *new_string;
-	    gchar *digit_string;
-		gchar* oldstr;
-
-	    /* tmp_pointer is on the first non digit from the end of the last_name,
-	     * so go to the first digit */
-	    tmp_pointer++;
-
-	    digit_string = my_strdup ( tmp_pointer );
-	    tmp_pointer[0] = 0;
-
-	    /* increase the number */
-	    digit_size = strlen ( digit_string );
-	    oldstr =  digit_string;
-	    digit_string = utils_str_itoa ( utils_str_atoi ( digit_string ) + 1 );
-	    g_free ( oldstr );
-	    new_digit_size = strlen ( digit_string );
-
-	    /* if new_digit_size is < of digit_size, it's because some 0 diseappear
-	     * while the atoi and utils_str_itoa, so we set again that 0
-	     * ie if we had 0007, we want 0008 and no 8 */
-	    if ( new_digit_size < digit_size )
-	    {
-		gint i;
-
-		zero_string = g_malloc ((digit_size-new_digit_size+1)*sizeof (gchar));
-
-		for ( i=0 ; i<digit_size-new_digit_size ; i++ )
-		    zero_string[i]='0';
-
-		zero_string[digit_size-new_digit_size] = 0;
-	    }
-	    else
-		zero_string = g_strdup ("");
-
-	    /* create the new string */
-	    new_string = g_strconcat ( last_name,
-				       zero_string,
-				       digit_string,
-				       NULL );
-	    g_free (last_name);
-	    g_free (zero_string);
-	    g_free (digit_string);
-	    last_name = new_string;
-	}
-	gtk_entry_set_text ( GTK_ENTRY ( reconcile_number_entry ),
-			     last_name );
-	g_free (last_name);
-    }
-    else
-    {
-        tmpstr = utils_str_itoa ( gsb_data_reconcile_max_number ( ) + 1 );
-        gtk_entry_set_text ( GTK_ENTRY ( reconcile_number_entry ), tmpstr );
-    }
-
-    /* reset records in etat if user has changed of account */
-    if (etat.reconcile_account_number != account_number)
-    {
-        if (etat.reconcile_final_balance) g_free (etat.reconcile_final_balance);
-        if (etat.reconcile_new_date) g_date_free (etat.reconcile_new_date);
-        etat.reconcile_final_balance = NULL;
-        etat.reconcile_new_date = NULL;
-        etat.reconcile_account_number = -1;
+        g_free (run.reconcile_final_balance);
+        if (run.reconcile_new_date)
+            g_date_free (run.reconcile_new_date);
+        run.reconcile_final_balance = NULL;
+        run.reconcile_new_date = NULL;
+        run.reconcile_account_number = -1;
     }
 
     /* set last input date/amount if available */
-    if (etat.reconcile_new_date)
+    if (run.reconcile_new_date)
     {
-        date = etat.reconcile_new_date;
+        date = run.reconcile_new_date;
     }
     else
     {
@@ -426,7 +443,7 @@ gboolean gsb_reconcile_run_reconciliation ( GtkWidget *button,
                 g_date_free (today);
 
             /* it's not the first reconciliation, set the old balance and unsensitive the old balance entry */
-            tmpstr = gsb_real_get_string (gsb_data_reconcile_get_final_balance (reconcile_number));
+            tmpstr = utils_real_get_string (gsb_data_reconcile_get_final_balance (reconcile_number));
             gtk_entry_set_text ( GTK_ENTRY ( reconcile_initial_balance_entry ), tmpstr);
             g_free ( tmpstr );
             gtk_widget_set_sensitive ( GTK_WIDGET ( reconcile_initial_balance_entry ),
@@ -440,7 +457,7 @@ gboolean gsb_reconcile_run_reconciliation ( GtkWidget *button,
 
             /* it's the first reconciliation, set the initial balance and make sensitive the old balance to change
              * it if necessary */
-            tmpstr = gsb_real_get_string ( gsb_data_account_get_init_balance (account_number, -1));
+            tmpstr = utils_real_get_string ( gsb_data_account_get_init_balance (account_number, -1));
             gtk_entry_set_text ( GTK_ENTRY ( reconcile_initial_balance_entry ), tmpstr);
             g_free ( tmpstr );
             gtk_widget_set_sensitive ( GTK_WIDGET ( reconcile_initial_balance_entry ), TRUE );
@@ -454,10 +471,9 @@ gboolean gsb_reconcile_run_reconciliation ( GtkWidget *button,
     g_date_free (date);
 
     /* set last input amount if available and if the account is the good one */
-    gtk_entry_set_text ( GTK_ENTRY ( reconcile_final_balance_entry ), 
-            (etat.reconcile_final_balance) ? etat.reconcile_final_balance : "");
-    if (etat.reconcile_final_balance)
-        g_free(etat.reconcile_final_balance);
+    gtk_entry_set_text ( GTK_ENTRY ( reconcile_final_balance_entry ),
+            (run.reconcile_final_balance) ? run.reconcile_final_balance : "");
+    g_free(run.reconcile_final_balance);
 
     /* set the title */
     tmpstr = g_markup_printf_escaped ( _(" <b>%s reconciliation</b> "),
@@ -467,7 +483,7 @@ gboolean gsb_reconcile_run_reconciliation ( GtkWidget *button,
     g_free ( tmpstr );
 
     /* we go to the reconciliation mode */
-    etat.equilibrage = 1;
+    run.equilibrage = 1;
 
     /* set all the balances for reconciliation */
     gsb_reconcile_update_amounts (NULL, NULL);
@@ -522,16 +538,17 @@ gboolean gsb_reconcile_finish_reconciliation ( GtkWidget *button,
 {
     GSList *list_tmp_transactions;
     GDate *date;
+    const GDate *initial_date;
     gint account_number;
     gint reconcile_number;
     gsb_real real;
-	gchar* tmpstr;
+	gchar *tmp_str;
 
     account_number = gsb_gui_navigation_get_current_account ();
 
-    if ( gsb_real_sub ( gsb_real_add ( gsb_real_get_from_string (gtk_entry_get_text ( GTK_ENTRY ( reconcile_initial_balance_entry ))),
+    if ( gsb_real_sub ( gsb_real_add ( utils_real_get_from_string (gtk_entry_get_text ( GTK_ENTRY ( reconcile_initial_balance_entry ))),
 				       gsb_data_account_calculate_waiting_marked_balance (account_number)),
-			gsb_real_get_from_string (gtk_entry_get_text ( GTK_ENTRY ( reconcile_final_balance_entry )))).mantissa != 0 )
+			utils_real_get_from_string (gtk_entry_get_text ( GTK_ENTRY ( reconcile_final_balance_entry )))).mantissa != 0 )
     {
 	dialogue_warning_hint ( _("There is a variance in balances, check that both final balance and initial balance minus marked transactions are equal."),
 				_("Reconciliation can't be completed.") );
@@ -542,8 +559,11 @@ gboolean gsb_reconcile_finish_reconciliation ( GtkWidget *button,
     reconcile_number = gsb_data_reconcile_get_number_by_name (gtk_entry_get_text ( GTK_ENTRY ( reconcile_number_entry )));
     if (reconcile_number)
     {
-	dialogue_warning_hint ( _("There is already a reconcile with that name, you must use another name or let it free.\nIf the reconcile name is ending by a number,\nit will be automatically incremented."),
-				_("Reconciliation can't be completed.") );
+	dialogue_warning_hint ( _("There is already a reconciliation with that "
+                        "name, you must use another name or let it free.\nIf the "
+                        "reconcile name is ending by a number,\n"
+                        "it will be automatically incremented."),
+                        _("Reconciliation can't be completed.") );
 	return FALSE;
     }
 
@@ -552,14 +572,35 @@ gboolean gsb_reconcile_finish_reconciliation ( GtkWidget *button,
     date = gsb_calendar_entry_get_date (reconcile_new_date_entry);
     if (!date)
     {
-	gchar* tmpstr = g_strdup_printf ( _("Invalid date: '%s'"),
+    tmp_str = g_strdup_printf ( _("Invalid date: '%s'"),
 						  gtk_entry_get_text ( GTK_ENTRY ( reconcile_new_date_entry )));
-	dialogue_warning_hint ( tmpstr,
+	dialogue_warning_hint ( tmp_str,
 				_("Reconciliation can't be completed.") );
-	g_free ( tmpstr );
+	g_free ( tmp_str );
 	return FALSE;
     }
 
+    /* teste la validité de la date de fin */
+    reconcile_number = gsb_data_reconcile_get_account_last_number ( account_number );
+    if ( reconcile_number )
+    {
+        initial_date = gsb_data_reconcile_get_final_date ( reconcile_number );
+        if ( g_date_compare ( initial_date, date ) >= 0 )
+        {
+            tmp_str = g_strdup_printf ( _("Invalid date: '%s'"), gsb_format_gdate ( date ) );
+            dialogue_warning_hint ( tmp_str, _("Reconciliation can't be completed.") );
+            g_free ( tmp_str );
+
+            return FALSE;
+        }
+    }
+    else
+    {
+        tmp_str = g_strdup ( _("You can set the initial date of the reconciliation in the preferences.") );
+        dialogue_warning ( tmp_str );
+        g_free ( tmp_str );
+    }
+
     if (!strlen (gtk_entry_get_text ( GTK_ENTRY ( reconcile_number_entry ))))
     {
 	dialogue_warning_hint ( _("You need to set a name to the reconciliation ; at least, set a number,\nit will be automatically incremented later"),
@@ -575,10 +616,10 @@ gboolean gsb_reconcile_finish_reconciliation ( GtkWidget *button,
 	gsb_reconcile_list_button_clicked (reconcile_sort_list_button, NULL);
     }
 
-    tmpstr = g_strdup_printf ( _("Last statement: %s"), gsb_format_gdate (date));
+    tmp_str = g_strdup_printf ( _("Last statement: %s"), gsb_format_gdate (date));
     gtk_label_set_text ( GTK_LABEL ( label_last_statement ),
-			 tmpstr);
-    g_free ( tmpstr );
+			 tmp_str);
+    g_free ( tmp_str );
 
     /* create the new reconcile structure */
     reconcile_number = gsb_data_reconcile_new (gtk_entry_get_text (GTK_ENTRY (reconcile_number_entry)));
@@ -592,11 +633,11 @@ gboolean gsb_reconcile_finish_reconciliation ( GtkWidget *button,
     gsb_data_reconcile_set_init_date ( reconcile_number, date );
     g_free (date);
 
-    real = gsb_real_get_from_string ( gtk_entry_get_text (
+    real = utils_real_get_from_string ( gtk_entry_get_text (
                         GTK_ENTRY ( reconcile_initial_balance_entry ) ) );
     gsb_data_reconcile_set_init_balance ( reconcile_number, real );
 
-    real = gsb_real_get_from_string ( gtk_entry_get_text (
+    real = utils_real_get_from_string ( gtk_entry_get_text (
                         GTK_ENTRY ( reconcile_final_balance_entry ) ) );
     gsb_data_reconcile_set_final_balance ( reconcile_number,
 					   real );
@@ -627,20 +668,23 @@ gboolean gsb_reconcile_finish_reconciliation ( GtkWidget *button,
     /* update the P and T to R in the list */
     transaction_list_update_element (ELEMENT_MARK);
 
-    mise_a_jour_liste_comptes_accueil = 1;
+    /* update the reconcile number if necessary */
+    transaction_list_update_element ( ELEMENT_RECONCILE_NB );
+
+    run.mise_a_jour_liste_comptes_accueil = TRUE;
 
     /* go back to the normal transactions list */
     gsb_reconcile_cancel (NULL, NULL);
 
-    /* reset records in etat: to do after gsb_reconcile_cancel */
-    if (etat.reconcile_final_balance) g_free (etat.reconcile_final_balance);
-    if (etat.reconcile_new_date) g_date_free (etat.reconcile_new_date);
-    etat.reconcile_final_balance = NULL;
-    etat.reconcile_new_date = NULL;
-    etat.reconcile_account_number = -1;
+    /* reset records in run: to do after gsb_reconcile_cancel */
+    g_free (run.reconcile_final_balance);
+    if (run.reconcile_new_date)
+        g_date_free (run.reconcile_new_date);
+    run.reconcile_final_balance = NULL;
+    run.reconcile_new_date = NULL;
+    run.reconcile_account_number = -1;
 
-    if ( etat.modification_fichier == 0 )
-        modification_fichier ( TRUE );
+    gsb_file_set_modified ( TRUE );
 
     if ( reconcile_save_last_scheduled_convert )
     {
@@ -664,25 +708,28 @@ gboolean gsb_reconcile_finish_reconciliation ( GtkWidget *button,
  * */
 void gsb_reconcile_sensitive ( gboolean sensitive )
 {
-    gtk_widget_set_sensitive ( navigation_tree_view, sensitive );
+    GtkUIManager *ui_manager;
+
+    ui_manager = gsb_menu_get_ui_manager ( );
+    gtk_widget_set_sensitive ( gsb_gui_navigation_get_tree_view ( ), sensitive );
     gsb_gui_sensitive_headings (sensitive);
     /* add by pbiava 02/11/2009 */
-    gtk_widget_set_sensitive ( gtk_ui_manager_get_widget ( ui_manager, 
+    gtk_widget_set_sensitive ( gtk_ui_manager_get_widget ( ui_manager,
                               "/menubar/ViewMenu/ShowReconciled/" ),
 			       sensitive );
-    gtk_widget_set_sensitive ( gtk_ui_manager_get_widget ( ui_manager, 
+    gtk_widget_set_sensitive ( gtk_ui_manager_get_widget ( ui_manager,
                               "/menubar/ViewMenu/ShowArchived/" ),
 			       sensitive );
-    gtk_widget_set_sensitive ( gtk_ui_manager_get_widget (ui_manager, 
+    gtk_widget_set_sensitive ( gtk_ui_manager_get_widget (ui_manager,
 							  "/menubar/ViewMenu/ShowClosed/" ),
 			       sensitive );
-    gtk_widget_set_sensitive ( gtk_ui_manager_get_widget (ui_manager, 
+    gtk_widget_set_sensitive ( gtk_ui_manager_get_widget (ui_manager,
 							  "/menubar/EditMenu/ConvertToScheduled/" ),
 			       sensitive );
-    gtk_widget_set_sensitive ( gtk_ui_manager_get_widget (ui_manager, 
+    gtk_widget_set_sensitive ( gtk_ui_manager_get_widget (ui_manager,
 							  "/menubar/EditMenu/NewAccount/" ),
 			       sensitive );
-    gtk_widget_set_sensitive ( gtk_ui_manager_get_widget (ui_manager, 
+    gtk_widget_set_sensitive ( gtk_ui_manager_get_widget (ui_manager,
 							  "/menubar/EditMenu/RemoveAccount/" ),
 			       sensitive );
 }
@@ -700,12 +747,12 @@ void gsb_reconcile_sensitive ( gboolean sensitive )
 gboolean gsb_reconcile_cancel ( GtkWidget *button,
 				        gpointer null )
 {
-    etat.equilibrage = 0;
+    run.equilibrage = 0;
 
     /* save the final balance/new date for the next time the user will try to reconcile */
-    etat.reconcile_account_number = gsb_gui_navigation_get_current_account ();
-    etat.reconcile_final_balance = g_strdup ( gtk_entry_get_text ( GTK_ENTRY ( reconcile_final_balance_entry ) ) );
-    etat.reconcile_new_date = gsb_parse_date_string ( gtk_entry_get_text ( GTK_ENTRY ( reconcile_new_date_entry ) ) );
+    run.reconcile_account_number = gsb_gui_navigation_get_current_account ();
+    run.reconcile_final_balance = g_strdup ( gtk_entry_get_text ( GTK_ENTRY ( reconcile_final_balance_entry ) ) );
+    run.reconcile_new_date = gsb_parse_date_string ( gtk_entry_get_text ( GTK_ENTRY ( reconcile_new_date_entry ) ) );
 
     /* set the normal color to the date entry */
     gsb_calendar_entry_set_color ( reconcile_new_date_entry, TRUE);
@@ -779,21 +826,20 @@ gboolean gsb_reconcile_update_amounts ( GtkWidget *entry,
         else
         {
             /* the entry is not valid, make it red */
-            gtk_widget_modify_base ( entry, GTK_STATE_NORMAL,
-                            &calendar_entry_color );
+            gtk_widget_modify_base ( entry, GTK_STATE_NORMAL, gsb_color_get_couleur ( "entry_error_color" ) );
             return FALSE;
         }
     }
 
     currency_number = gsb_data_account_get_currency ( account_number );
-    amount = gsb_utils_edit_calculate_entry ( reconcile_final_balance_entry );
-    final_balance = gsb_real_get_string_with_currency ( amount, currency_number, FALSE );
+    amount = utils_real_get_calculate_entry ( reconcile_final_balance_entry );
+    final_balance = utils_real_get_string_with_currency ( amount, currency_number, FALSE );
     gtk_label_set_text ( GTK_LABEL ( reconcile_final_balance_label ), final_balance );
 
     /* set the marked balance amount,
-     * this is what we mark as P while reconciling, so it's the total marked balance 
+     * this is what we mark as P while reconciling, so it's the total marked balance
      * - the initial marked balance */
-    tmp_string = gsb_real_get_string_with_currency (
+    tmp_string = utils_real_get_string_with_currency (
                         gsb_data_account_calculate_waiting_marked_balance ( account_number ),
                         currency_number,
                         FALSE );
@@ -802,11 +848,11 @@ gboolean gsb_reconcile_update_amounts ( GtkWidget *entry,
 
     /* calculate the variation balance and show it */
     amount = gsb_real_sub ( gsb_real_add (
-                        gsb_real_get_from_string ( initial_balance ),
+                        utils_real_get_from_string ( initial_balance ),
 					    gsb_data_account_calculate_waiting_marked_balance ( account_number ) ),
-			            gsb_real_get_from_string ( final_balance ) );
+			            utils_real_get_from_string ( final_balance ) );
 
-    tmpstr = gsb_real_get_string_with_currency ( amount, currency_number, FALSE );
+    tmpstr = utils_real_get_string_with_currency ( amount, currency_number, FALSE );
     gtk_label_set_text ( GTK_LABEL ( reconcile_variation_balance_label ), tmpstr);
     g_free ( tmpstr );
 
