@@ -26,6 +26,8 @@
 #endif
 
 #include "include.h"
+#include <gdk-pixbuf/gdk-pixdata.h>
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "gsb_select_icon.h"
@@ -34,12 +36,13 @@
 #include "structures.h"
 #include "utils.h"
 #include "erreur.h"
+#include "gsb_dirs.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
 static gboolean gsb_select_icon_add_path ( void );
 static GtkWidget * gsb_select_icon_create_entry_text ( gchar * name_icon );
-static void gsb_select_icon_create_file_chooser ( GtkWidget * button, 
+static void gsb_select_icon_create_file_chooser ( GtkWidget * button,
                                            gpointer user_data );
 static GtkWidget * gsb_select_icon_create_icon_view ( gchar * name_icon );
 static void gsb_select_icon_entry_text_changed ( GtkComboBoxEntry *entry,
@@ -52,7 +55,6 @@ static gchar * gsb_select_icon_troncate_name_icon ( gchar *name_icon, gint trunc
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 static GtkWidget * dialog;
@@ -78,7 +80,7 @@ typedef struct
 static struct_account_icon *icon_buffer;
 
 
-enum { 
+enum {
         PIXBUF_COLUMN,
         TEXT_COLUMN,
         DATA_COLUMN
@@ -156,9 +158,12 @@ gchar * gsb_select_icon_create_window ( gchar *name_icon )
 
     new_icon = g_strdup ( name_icon );
 
+    if ( path_icon && strlen ( path_icon ) > 0 )
+        g_free ( path_icon );
+
     path_icon = g_path_get_dirname ( name_icon );
     dialog = gtk_dialog_new_with_buttons ( _("Browse icons"),
-                            GTK_WINDOW ( window ),
+                            GTK_WINDOW ( run.window ),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_STOCK_CANCEL,
                             GTK_RESPONSE_REJECT,
@@ -185,7 +190,7 @@ gchar * gsb_select_icon_create_window ( gchar *name_icon )
     /* création du bouton de sélection des répertoires */
     chooser_button = gtk_button_new_with_label ( _("Browse") );
     gtk_box_pack_start ( GTK_BOX ( hbox ), chooser_button, FALSE, FALSE, 0 );
-    
+
     /* création de la vue pour les icônes */
     scroll = gtk_scrolled_window_new ( NULL, NULL);
     gtk_scrolled_window_set_policy ( GTK_SCROLLED_WINDOW ( scroll ),
@@ -196,19 +201,19 @@ gchar * gsb_select_icon_create_window ( gchar *name_icon )
     gtk_container_add ( GTK_CONTAINER ( scroll ), icon_view );
 
     /* gestion des signaux */
-    g_signal_connect ( G_OBJECT ( icon_view ), 
-                        "selection-changed", 
-                        G_CALLBACK( gsb_select_icon_selection_changed ), 
+    g_signal_connect ( G_OBJECT ( icon_view ),
+                        "selection-changed",
+                        G_CALLBACK( gsb_select_icon_selection_changed ),
                         NULL );
 
-    g_signal_connect ( G_OBJECT ( chooser_button ), 
-                        "clicked", 
-                        G_CALLBACK(gsb_select_icon_create_file_chooser), 
+    g_signal_connect ( G_OBJECT ( chooser_button ),
+                        "clicked",
+                        G_CALLBACK(gsb_select_icon_create_file_chooser),
                         NULL );
 
-    g_signal_connect ( G_OBJECT( entry_text ), 
-                        "changed", 
-                        G_CALLBACK( gsb_select_icon_entry_text_changed ), 
+    g_signal_connect ( G_OBJECT( entry_text ),
+                        "changed",
+                        G_CALLBACK( gsb_select_icon_entry_text_changed ),
                         NULL );
 
     gtk_widget_show_all ( dialog );
@@ -254,14 +259,14 @@ GtkWidget * gsb_select_icon_create_entry_text ( gchar * name_icon )
         devel_debug ( "combo n'existe pas" );
         store = gtk_list_store_new ( 2, G_TYPE_STRING, G_TYPE_INT );
         gtk_list_store_append (store, &iter);
-        if ( g_strcmp0 ( GRISBI_PIXMAPS_DIR, path_icon ) != 0 )
+        if ( g_strcmp0 ( gsb_dirs_get_pixmaps_dir ( ), path_icon ) != 0 )
         {
-            gtk_list_store_set (store, &iter, 0, GRISBI_PIXMAPS_DIR, -1);
+            gtk_list_store_set (store, &iter, 0, gsb_dirs_get_pixmaps_dir ( ), -1);
             gtk_list_store_prepend (store, &iter);
         }
         gtk_list_store_set (store, &iter, 0, path_icon, -1);
     }
-    
+
     combo = gtk_combo_box_entry_new_with_model ( GTK_TREE_MODEL ( store ), 0 );
     gtk_entry_set_text ( GTK_ENTRY (GTK_BIN (combo)->child), name_icon );
 
@@ -270,12 +275,12 @@ GtkWidget * gsb_select_icon_create_entry_text ( gchar * name_icon )
 
 
 /**
- * Crée le GtkIconView 
+ * Crée le GtkIconView
  *
  * \param nom de l'icône
  *
  * \return le GtkIconView rempli avec l'icône sélectionnée au premier plan
- * 
+ *
  * */
 GtkWidget * gsb_select_icon_create_icon_view ( gchar * name_icon )
 {
@@ -285,7 +290,7 @@ GtkWidget * gsb_select_icon_create_icon_view ( gchar * name_icon )
     icon_view = gtk_icon_view_new ();
     gtk_icon_view_set_margin ( GTK_ICON_VIEW ( icon_view ), 0 );
     gtk_icon_view_set_spacing (GTK_ICON_VIEW ( icon_view ), 0 );
-    gtk_icon_view_set_selection_mode (GTK_ICON_VIEW ( icon_view ), 
+    gtk_icon_view_set_selection_mode (GTK_ICON_VIEW ( icon_view ),
                             GTK_SELECTION_SINGLE );
     gtk_icon_view_set_pixbuf_column (GTK_ICON_VIEW ( icon_view ), PIXBUF_COLUMN);
     gtk_icon_view_set_text_column (GTK_ICON_VIEW ( icon_view ), TEXT_COLUMN);
@@ -319,9 +324,8 @@ GtkTreePath * gsb_select_icon_fill_icon_view (  gchar * name_icon )
     GError *error = NULL;
     GtkTreePath *tree_path = NULL;
 
-
     devel_debug ( path_icon );
-    
+
     dir = g_dir_open ( path_icon, 0, &error );
     if ( dir )
     {
@@ -331,7 +335,7 @@ GtkTreePath * gsb_select_icon_fill_icon_view (  gchar * name_icon )
         GSList *liste = NULL;
         gint i = 0;
         const gchar *name = NULL;
-        
+
         while ( (name = g_dir_read_name ( dir ) ) )
         {
             liste = g_slist_append ( liste, g_strdup ( name ) );
@@ -344,28 +348,32 @@ GtkTreePath * gsb_select_icon_fill_icon_view (  gchar * name_icon )
                             liste -> data, NULL );
             if ( g_strcmp0 ( tmpstr, name_icon ) == 0 )
             {
-                gchar *tmpstr = utils_str_itoa ( i );
+                gchar *tmpstr;
+
+                tmpstr = utils_str_itoa ( i-1 );
                 tree_path = gtk_tree_path_new_from_string ( tmpstr );
                 g_free ( tmpstr );
             }
+
             pixbuf = gdk_pixbuf_new_from_file_at_size ( tmpstr, 32, 32, NULL);
             if ( pixbuf )
             {
                 gchar *tmpstr;
-                
+
                 gtk_list_store_append ( store, &iter );
                 tmpstr = gsb_select_icon_troncate_name_icon ( liste -> data, 10 );
-                gtk_list_store_set (store, &iter, PIXBUF_COLUMN, pixbuf, 
+                gtk_list_store_set (store, &iter, PIXBUF_COLUMN, pixbuf,
                             TEXT_COLUMN, tmpstr, -1);
                 g_free ( tmpstr );
                 g_object_unref (pixbuf);
             }
-            
+
             g_free ( tmpstr );
             liste = liste -> next;
             i++;
         }
         gtk_icon_view_set_model (GTK_ICON_VIEW ( icon_view ), GTK_TREE_MODEL (store));
+        g_object_unref ( G_OBJECT ( store ) );
         g_dir_close ( dir );
     }
     else
@@ -387,14 +395,14 @@ GtkTreePath * gsb_select_icon_fill_icon_view (  gchar * name_icon )
  * \param bouton appelant
  *
  * \return void
- * 
+ *
  * */
-void gsb_select_icon_create_file_chooser ( GtkWidget * button, 
+void gsb_select_icon_create_file_chooser ( GtkWidget * button,
                                            gpointer user_data )
 {
     GtkWidget *chooser;
     GtkFileFilter *filter;
-    
+
     chooser = gtk_file_chooser_dialog_new ( _("Select icon directory"),
                         GTK_WINDOW (dialog),
                         GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
@@ -412,14 +420,14 @@ void gsb_select_icon_create_file_chooser ( GtkWidget * button,
     if (gtk_dialog_run (GTK_DIALOG ( chooser ) ) == GTK_RESPONSE_ACCEPT )
     {
         GtkTreePath *path;
-        
+
         path_icon = gtk_file_chooser_get_filename ( GTK_FILE_CHOOSER ( chooser ) );
         devel_debug ( path_icon );
         path = gsb_select_icon_fill_icon_view ( NULL );
         gtk_icon_view_scroll_to_path (GTK_ICON_VIEW ( icon_view ),
                             path, TRUE, 0.5, 0 );
         gsb_select_icon_add_path ( );
-        gtk_entry_set_text ( GTK_ENTRY (GTK_BIN (entry_text)->child ), 
+        gtk_entry_set_text ( GTK_ENTRY (GTK_BIN (entry_text)->child ),
                                  path_icon );
         gtk_widget_set_sensitive (bouton_OK, FALSE );
     }
@@ -435,7 +443,7 @@ void gsb_select_icon_create_file_chooser ( GtkWidget * button,
  * \param le GtkComboBoxEntry appellant
  *
  * \return void
- * 
+ *
  * */
 void gsb_select_icon_entry_text_changed ( GtkComboBoxEntry *entry,
                                           gpointer user_data )
@@ -466,8 +474,8 @@ void gsb_select_icon_entry_text_changed ( GtkComboBoxEntry *entry,
  *
  * \param le GtkIconView appellant
  *
- * \return 
- * 
+ * \return
+ *
  * */
 void gsb_select_icon_selection_changed ( GtkIconView *icon_view,
                                          gpointer user_data )
@@ -495,7 +503,7 @@ void gsb_select_icon_selection_changed ( GtkIconView *icon_view,
     {
         new_icon = g_strconcat ( path_icon, G_DIR_SEPARATOR_S,
                                  name_icon, NULL );
-        gtk_entry_set_text ( GTK_ENTRY (GTK_BIN (entry_text)->child ), 
+        gtk_entry_set_text ( GTK_ENTRY (GTK_BIN (entry_text)->child ),
                                  new_icon );
         gtk_widget_set_sensitive (bouton_OK, TRUE );
     }
@@ -516,15 +524,15 @@ gchar * gsb_select_icon_troncate_name_icon ( gchar *name_icon, gint trunc )
 
     if ( size > 10 )
     {
-        gchar *tmpstr;
+        gchar *tmpstr, *tmpstr2;
         gchar *end;
         gchar *ptr = NULL;
         gint i = 1, n = 0;
-        
+
         n = size / trunc;
         if ( (size % trunc ) == 0 )
         n--;
-        
+
         tmpstr = g_malloc ( size + n + 1 );
         /* devel_debug_int ( n );
         devel_debug ( name_icon ); */
@@ -536,15 +544,16 @@ gchar * gsb_select_icon_troncate_name_icon ( gchar *name_icon, gint trunc )
             if ( i < n )
                 ptr = g_utf8_offset_to_pointer ( name_icon, ( i + 1 ) * 10 );
             if ( ptr )
-                tmpstr = g_strconcat ( tmpstr, "\n", 
+                tmpstr2 = g_strconcat ( tmpstr, "\n",
                                        g_strndup (end, ptr - end ), NULL);
             else
-                tmpstr = g_strconcat ( tmpstr, "\n", end, NULL);
+                tmpstr2 = g_strconcat ( tmpstr, "\n", end, NULL);
             ptr = NULL;
             i++;
         } while ( i <= n );
-        
-        return tmpstr;
+
+        g_free ( tmpstr );
+        return tmpstr2;
     }
     else
         return g_strdup ( name_icon );
@@ -571,7 +580,7 @@ gboolean gsb_select_icon_add_path ( void )
     while (result)
     {
         gchar * rep;
-        
+
         gtk_tree_model_get ( GTK_TREE_MODEL ( store ), &iter, 0, &rep, -1 );
         if ( strcmp ( path_icon, rep ) == 0)
         {
@@ -656,8 +665,8 @@ GdkPixbuf *gsb_select_icon_get_default_logo_pixbuf ( void )
     GdkPixbuf *pixbuf = NULL;
     GError *error = NULL;
 
-    pixbuf = gdk_pixbuf_new_from_file ( g_build_filename 
-                        (GRISBI_PIXMAPS_DIR, "grisbi-logo.png", NULL), &error );
+    pixbuf = gdk_pixbuf_new_from_file ( g_build_filename
+                        (gsb_dirs_get_pixmaps_dir ( ), "grisbi-logo.png", NULL), &error );
 
     if ( ! pixbuf )
     {
@@ -668,7 +677,11 @@ GdkPixbuf *gsb_select_icon_get_default_logo_pixbuf ( void )
     if ( gdk_pixbuf_get_width (pixbuf) > LOGO_WIDTH ||
 	     gdk_pixbuf_get_height (pixbuf) > LOGO_HEIGHT )
     {
-        return gsb_select_icon_resize_logo_pixbuf ( pixbuf );
+        GdkPixbuf *tmp_pixbuf;
+
+        tmp_pixbuf = gsb_select_icon_resize_logo_pixbuf ( pixbuf );
+        g_object_unref ( G_OBJECT ( pixbuf ) );
+        return tmp_pixbuf;
 	}
     else
         return pixbuf;
@@ -692,7 +705,10 @@ void gsb_select_icon_set_logo_pixbuf ( GdkPixbuf *pixbuf )
         pixbuf_logo = gsb_select_icon_resize_logo_pixbuf ( pixbuf );
 	}
     else
+    {
         pixbuf_logo = pixbuf ;
+        g_object_ref ( G_OBJECT ( pixbuf_logo ) );
+    }
 }
 
 
@@ -719,9 +735,6 @@ GdkPixbuf *gsb_select_icon_resize_logo_pixbuf ( GdkPixbuf *pixbuf )
         ratio_height ++;
     ratio = ( ratio_width > ratio_height ) ? ratio_width : ratio_height;
 
-    tmp = gdk_pixbuf_new ( GDK_COLORSPACE_RGB, TRUE, 8,
-               gdk_pixbuf_get_width ( pixbuf )/ratio,
-               gdk_pixbuf_get_height ( pixbuf )/ratio );
     tmp = gdk_pixbuf_scale_simple ( pixbuf,
                         gdk_pixbuf_get_width ( pixbuf )/ratio,
                         gdk_pixbuf_get_height ( pixbuf )/ratio,
@@ -744,10 +757,10 @@ GSList *gsb_select_icon_list_accounts_icon ( void )
 
 
 /**
- * find and return the number of the account which the struct account_icon is the param 
- * 
+ * find and return the number of the account which the struct account_icon is the param
+ *
  * \param the struct of the account_icon
- * 
+ *
  * \return the number of account, -1 if pb
  * */
 gint gsb_select_icon_get_no_account_by_ptr ( gpointer account_icon_ptr )
@@ -901,7 +914,7 @@ gboolean gsb_select_icon_new_account_icon_from_file ( gint account_number,
         g_free ( icon );
 
         return FALSE;
-    }        
+    }
 }
 
 
@@ -985,7 +998,7 @@ gboolean gsb_select_icon_remove_account_pixbuf ( gint account_number )
 
         if ( icon -> account_number == account_number )
         {
-            
+
             if ( icon -> pixbuf )
             {
                 g_object_unref ( icon -> pixbuf );
