@@ -27,14 +27,14 @@
 #endif
 
 #include "include.h"
-
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "help.h"
+#include "gsb_select_icon.h"
+#include "structures.h"
 #include "utils.h"
 #include "utils_dates.h"
-#include "gsb_plugins.h"
-#include "gsb_select_icon.h"
 #include "utils_str.h"
 /*END_INCLUDE*/
 
@@ -44,7 +44,6 @@ static void launch_url (GtkAboutDialog *about, const gchar * link, gpointer data
 
 
 /*START_EXTERN*/
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 
@@ -76,6 +75,35 @@ void launch_mailto (GtkAboutDialog *about, const gchar * link, gpointer data)
 }
 
 
+gchar * extra_support ( void )
+{
+    gchar *ret;
+
+    ret = g_strconcat (
+        _("GnuCash support: "),
+#ifdef HAVE_XML2
+        _("yes"), "\n",
+#else
+        _("no"), "\n",
+#endif
+        _("OFX support: "),
+#ifdef HAVE_OFX
+        _("yes"), "\n",
+#else
+        _("no"), "\n",
+#endif
+        _("OpenSSL support: "),
+#ifdef HAVE_SSL
+        _("yes"), "\n",
+#else
+        _("no"), "\n",
+#endif
+        NULL);
+
+    return ret;
+}
+
+
 /**
  * Create and run an About dialog.
  *
@@ -97,7 +125,9 @@ _("Programming"),
 "Francois Terrot (<grisbi@terrot.net>)",
 "Pierre Biava (<pierre.biava@nerim.net>)",
 "Mickaël Remars (<grisbi@remars.com>)",
-"William Ollivier (<guneeyoufix@gmail.com>)"
+"William Ollivier (<guneeyoufix@gmail.com>)",
+"Rémi Cardona (remi@gentoo.org)",
+"Ludovic Rousseau (ludovic.rousseau@gmail.com)"
 "\n",
 
 _("Packaging"),
@@ -129,18 +159,24 @@ NULL };
 "Fabio Erculiani (<fabio.erculiani@tiscali.it>): ", _("Italian"), CSUFFIX,
 "Flavio Henrique Somensi (<flavio@opens.com.br>): ", _("Brazilian Portuguese"), CSUFFIX,
 "Giorgio Mandolfo (<giorgio@pollycoke.org>): ", _("Italian"), CSUFFIX,
-"Martin Stromberger (<Fabiolla@aon.at>): ", _("German"), CSUFFIX,
+"Martin Stromberger (<ma.stromberger@gmx.at>): ", _("German"), CSUFFIX,
 "Ryszard Jeziorski (<rjeziorski@eagleW): ", _("Polish"), CSUFFIX,
 "Achilleas Kaskamanidis (<alterna55@users.sourceforge.net>): ", _("Greek"), CSUFFIX,
 NULL);
 
   const gchar *documenters [] = {
 "Alain Portal (<aportal@univ-monpt2.fr>)",
+"Benjamin Drieu (bdrieu[at]april.org)",
 "Daniel Cartron (<doc@grisbi.org>)",
+"Jean-Luc Duflot (jl.duflot[at]laposte.net)",
+"Loic Breilloux (loic.breilloux[at]libertysurf.fr)",
 NULL};
 
   const gchar *artists [] = {
 "Andre Pascual (<andre@linuxgraphic.org>)",
+"Jakub 'jimmac' Steiner (jimmac[at]ximian.com)",
+"Jean-Baptiste Renard (renardjb[at]free.fr)",
+"Tuomas 'tigert' Kuosmanen (tigert[at]gimp.org)",
 NULL};
 
   const gchar *license = "This program is free software; you can redistribute "
@@ -159,10 +195,10 @@ NULL};
 
     /* Others info */
     gchar *comments;
-    gchar *plugins;
+    gchar *extra;
     gchar *version_to_string;
 
-    plugins = gsb_plugin_get_list ( );
+    extra = extra_support ( );
     version_to_string = get_gtk_run_version ( );
 
     if ( IS_DEVELOPMENT_VERSION == 1 )
@@ -170,10 +206,9 @@ NULL};
         gchar *compiled_time;
 
         compiled_time = gsb_date_get_compiled_time ( );
-
         comments = g_strconcat ( _("Personal finance manager for everyone\n"),
-                        plugins,
-                        "\nVersion de GTK : ",
+                        extra,
+                        "Version de GTK : ",
                         version_to_string,
                         "\n",
                         _("This instance of Grisbi was compiled on\n"),
@@ -188,8 +223,8 @@ NULL};
     }
     else
         comments = g_strconcat ( _("Personal finance manager for everyone\n"),
-                        plugins,
-                        "\nVersion de GTK : ",
+                        extra,
+                        "Version de GTK : ",
                         version_to_string,
                         NULL );
 
@@ -221,9 +256,9 @@ NULL};
     gtk_window_set_position ( GTK_WINDOW ( about ), GTK_WIN_POS_CENTER_ON_PARENT );
     gtk_window_set_resizable ( GTK_WINDOW ( about ), TRUE );
     gtk_window_set_modal ( GTK_WINDOW ( about ), TRUE );
-    gtk_window_set_transient_for ( GTK_WINDOW ( about ), GTK_WINDOW ( window ) );
+    gtk_window_set_transient_for ( GTK_WINDOW ( about ), GTK_WINDOW ( run.window ) );
 
-    g_free ( plugins );
+    g_free ( extra );
     g_free ( version_to_string );
     g_free ( comments );
 
