@@ -26,6 +26,7 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "import_csv.h"
@@ -42,7 +43,6 @@
 /*START_EXTERN*/
 extern GSList *liste_comptes_importes;
 extern GSList *liste_comptes_importes_error;
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 /*START_STATIC*/
@@ -252,7 +252,7 @@ GtkTreeModel * csv_import_create_model ( GtkTreeView * tree_preview, gchar * con
         types[i+1] = G_TYPE_STRING;
 
         cell = gtk_cell_renderer_text_new ();
-        col = gtk_tree_view_column_new_with_attributes ( 
+        col = gtk_tree_view_column_new_with_attributes (
                         NULL,
                         cell,
                         "text", i + 1,
@@ -308,7 +308,7 @@ void skip_line_toggled ( GtkCellRendererToggle * cell, gchar * path_str,
     gboolean toggle_item;
     gint * indices;
     GtkTreePath * path = gtk_tree_path_new_from_string (path_str);
-    GtkTreeModel * tree_model = gtk_tree_view_get_model ( tree_preview );;
+    GtkTreeModel * tree_model = gtk_tree_view_get_model ( tree_preview );
 
     /* Get toggled iter */
     gtk_tree_model_get_iter ( GTK_TREE_MODEL ( tree_model ), &iter, path );
@@ -627,7 +627,7 @@ gint * csv_import_guess_fields_config ( gchar * contents, gint size, gchar * sep
 	    if ( strlen ( value ) > 1 &&
 		 strlen ( csv_fields [ field ] . name ) > 1 )
         {
-            if ( strlen ( csv_fields [ field ] . alias ) > 1 
+            if ( strlen ( csv_fields [ field ] . alias ) > 1
              &&
              ( safe_contains ( csv_fields [ field ] . name, value ) ||
                safe_contains ( _( csv_fields [ field ] . name ), value ) ||
@@ -926,7 +926,7 @@ void csv_import_update_validity_check ( GtkWidget * assistant )
     if ( !( ( csv_find_field_config ( 11 ) && !csv_find_field_config ( 12 ) &&
            !csv_find_field_config ( 13 ) && !csv_find_field_config ( 14 ) )
      ||
-     ( !csv_find_field_config ( 11 ) &&  csv_find_field_config ( 12 ) && 
+     ( !csv_find_field_config ( 11 ) &&  csv_find_field_config ( 12 ) &&
        ( csv_find_field_config ( 13 ) || csv_find_field_config ( 14 ) ) &&
        !( csv_find_field_config ( 13 ) && csv_find_field_config ( 14 ) ) ) ) )
     {
@@ -1097,10 +1097,10 @@ gboolean import_enter_csv_preview_page ( GtkWidget * assistant )
         size = 0;
         bytes_written = 0;
 
-        dialogue_special ( GTK_MESSAGE_WARNING, make_hint (
-                            _("The conversion to utf8 went wrong."),
+        dialogue_warning_hint (
                             _("If the result does not suit you, try again by selecting the "
-                            "correct character set in the window for selecting files.") ) );
+                            "correct character set in the window for selecting files."),
+                            _("The conversion to utf8 went wrong.") );
 
         contents = g_convert_with_fallback ( tmp_str, -1, "UTF-8", "ISO-8859-1",
                         "?", &size, &bytes_written, &error );
