@@ -1,10 +1,15 @@
 #ifndef _META_CATEGORIES_H
 #define _META_CATEGORIES_H (1)
+
+#include <glib.h>
+
 /* START_INCLUDE_H */
+#include "metatree.h"
 /* END_INCLUDE_H */
 
 
 /* START_DECLARATION */
+MetatreeInterface *category_get_metatree_interface ( void );
 gint category_tree_currency ( );
 /* END_DECLARATION */
 #endif
