@@ -1,6 +1,7 @@
 #ifndef METATREE_H
 #define METATREE_H
 
+#include <gtk/gtk.h>
 
 /* START_INCLUDE_H */
 #include "gsb_real.h"
@@ -85,8 +86,9 @@ enum meta_tree_columns {
     META_TREE_FONT_COLUMN,
     META_TREE_XALIGN_COLUMN,
     META_TREE_DATE_COLUMN,
+    META_TREE_BACKGROUND_COLOR,
     META_TREE_NUM_COLUMNS,
-}; 
+};
 
 enum meta_tree_row_type {
     META_TREE_DIV,
@@ -98,23 +100,27 @@ enum meta_tree_row_type {
 
 #define META_TREE_COLUMN_TYPES G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, \
 				 G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, \
-				 G_TYPE_INT, G_TYPE_FLOAT, G_TYPE_POINTER
+				 G_TYPE_INT, G_TYPE_FLOAT, G_TYPE_POINTER, GDK_TYPE_COLOR
 
 
 /*START_DECLARATION*/
 void appui_sur_ajout_sub_division ( GtkTreeModel * model );
 gboolean division_activated ( GtkTreeView * treeview, GtkTreePath * path,
                         GtkTreeViewColumn * col, gpointer userdata );
-gboolean division_column_expanded  ( GtkTreeView * treeview, GtkTreeIter * iter, 
+gboolean division_column_expanded  ( GtkTreeView * treeview, GtkTreeIter * iter,
                         GtkTreePath * tree_path, gpointer user_data ) ;
+gboolean division_column_collapsed  ( GtkTreeView *treeview,
+                        GtkTreeIter *iter,
+                        GtkTreePath *tree_path,
+                        gpointer user_data );
 gboolean division_drag_data_received ( GtkTreeDragDest * drag_dest, GtkTreePath * dest_path,
                         GtkSelectionData * selection_data );
 gboolean division_row_drop_possible ( GtkTreeDragDest * drag_dest, GtkTreePath * dest_path,
                         GtkSelectionData * selection_data );
 void expand_arbre_division ( GtkWidget *bouton, gint depth );
-void fill_division_row ( GtkTreeModel * model, MetatreeInterface * iface, 
+void fill_division_row ( GtkTreeModel * model, MetatreeInterface * iface,
                         GtkTreeIter * iter, gint division );
-void fill_sub_division_row ( GtkTreeModel * model, MetatreeInterface * iface, 
+void fill_sub_division_row ( GtkTreeModel * model, MetatreeInterface * iface,
                         GtkTreeIter * iter,
                         gint division,
                         gint sub_division );
@@ -127,7 +133,7 @@ void metatree_register_widget_as_linked ( GtkTreeModel * model,
                         GtkWidget * widget,
                         gchar * link_type );
 void metatree_remove_transaction ( GtkTreeView * tree_view,
-                        MetatreeInterface * iface, 
+                        MetatreeInterface * iface,
                         gint transaction,
                         gboolean delete_transaction );
 gboolean metatree_selection_changed ( GtkTreeSelection * selection, GtkTreeModel * model );
@@ -137,9 +143,10 @@ void metatree_set_linked_widgets_sensitive ( GtkTreeModel * model,
 gboolean metatree_sort_column  ( GtkTreeModel * model,
                         GtkTreeIter * a, GtkTreeIter * b,
                         gpointer user_data );
+void metatree_transfer_identical_transactions ( GtkWidget *tree_view );
 gboolean supprimer_division ( GtkTreeView * tree_view );
-void update_transaction_in_tree ( MetatreeInterface * iface, 
-                        GtkTreeModel * model, 
+void update_transaction_in_tree ( MetatreeInterface * iface,
+                        GtkTreeModel * model,
                         gint transaction_number );
 /*END_DECLARATION*/
 
