@@ -26,6 +26,7 @@
 #include "include.h"
 
 #include <libofx/libofx.h>
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "ofx.h"
@@ -40,46 +41,49 @@
 
 /*START_STATIC*/
 static int ofx_proc_account_cb(struct OfxAccountData data, void * account_data);;
-static int ofx_proc_security_cb(struct OfxSecurityData data);
 static int ofx_proc_statement_cb(struct OfxStatementData data, void * statement_data);;
 static int ofx_proc_status_cb(struct OfxStatusData data, void * status_data);;
 static int ofx_proc_transaction_cb(struct OfxTransactionData data, void * security_data);;
-static GSList * recuperation_donnees_ofx ( GtkWidget * assistant, struct imported_file * imported );
 /*END_STATIC*/
 
 
-static struct import_format ofx_format =
-{
-    "OFX",
-    "Open Financial Exchange",
-    "ofx",
-    (import_function) recuperation_donnees_ofx,
-};
 
+/* It seems the following applies to everyone, otherwise OFX_* are not defined */
+/* #ifdef _WIN32 */
+/* On Windows, the Ofx Severity enumerate values are already used in wingdi.h, DELETE is used in winnt.h
+ * This is a work around to this issues :
+ *  INFO, WARN, ERROR, DELETE and REPLACE are used in standard libofx.h;
+ *  on windows they should be prefixed by OFX_
+ */
 
+#ifndef _MINGW
 
-#ifndef ENABLE_STATIC
-/** Module name. */
-G_MODULE_EXPORT const gchar plugin_name[] = "ofx";
+#ifndef OFX_INFO
+#define OFX_INFO    INFO
 #endif
 
+#ifndef OFX_WARN
+#define OFX_WARN    WARN
+#endif
 
+#ifndef OFX_ERROR
+#if defined(_MSC_VER) || defined(_MINGW)
+#undef ERROR
+#endif /* _MSC_VER */
+#define OFX_ERROR   ERROR
+#endif
 
-/** Initialization function. */
-G_MODULE_EXPORT extern void ofx_plugin_register ( void )
-{
-    devel_debug ("Initializating ofx plugin");
-    register_import_format ( &ofx_format );
-}
+#ifndef OFX_DELETE
+#define OFX_DELETE  DELETE
+#endif
 
+#ifndef OFX_REPLACE
+#define OFX_REPLACE REPLACE
+#endif
 
+#endif /* _MIN_GW */
 
-/** Main function of module. */
-G_MODULE_EXPORT extern gpointer ofx_plugin_run ( GtkWidget * assistant,
-				    struct imported_file * imported )
-{
-    return recuperation_donnees_ofx ( assistant, imported );
-}
+/* #endif _WIN32 */
 
 
 
@@ -93,14 +97,12 @@ gint  message_erreur_operation;
 gchar * ofx_filename;
 
 
-#ifdef OFX_0_7
 LibofxContextPtr ofx_context;
 int ofx_proc_status_cb(struct OfxStatusData data, void * status_data);
 /* void ofx_proc_security_cb ( LibofxContextPtr, LibofxProcSecurityCallback, void * ); */
 int ofx_proc_account_cb(struct OfxAccountData data, void * account_data);
 int ofx_proc_transaction_cb(struct OfxTransactionData data, void * security_data);
 int ofx_proc_statement_cb(struct OfxStatementData data, void * statement_data);
-#endif /* OFX_0_7 */
 
 
 /**
@@ -109,7 +111,7 @@ int ofx_proc_statement_cb(struct OfxStatementData data, void * statement_data);
  *
  *
  */
-GSList *recuperation_donnees_ofx ( GtkWidget * assistant, struct imported_file * imported )
+gboolean recuperation_donnees_ofx ( GtkWidget * assistant, struct imported_file * imported )
 {
     GSList *liste_tmp;
     gchar *argv[2] = { "", "" };
@@ -124,20 +126,14 @@ GSList *recuperation_donnees_ofx ( GtkWidget * assistant, struct imported_file *
     argv[1] = imported -> name;
     devel_print_str ( imported -> name );
 
-#ifdef OFX_0_7
     ofx_context = libofx_get_new_context();
     ofx_set_status_cb ( ofx_context, ofx_proc_status_cb, NULL );
     /*     ofx_set_security_cb ( ofx_context, sofx_proc_security_cb, NULL ); */
     ofx_set_account_cb ( ofx_context, ofx_proc_account_cb, NULL );
     ofx_set_transaction_cb ( ofx_context, ofx_proc_transaction_cb, NULL );
     ofx_set_statement_cb ( ofx_context, ofx_proc_statement_cb, NULL );
-#endif /* OFX_0_7 */
- 
-#ifdef OFX_0_7
+
     libofx_proc_file ( ofx_context, ofx_filename, AUTODETECT );
-#else /* OFX_0_7 */
-    ofx_proc_file ( 2, argv );	/* FIXME: handle < 0.7 */
-#endif /* OFX_0_7 */
 
     /*     le dernier compte n'a pas été ajouté à la liste */
     liste_comptes_importes_ofx = g_slist_append ( liste_comptes_importes_ofx,
@@ -155,7 +151,7 @@ GSList *recuperation_donnees_ofx ( GtkWidget * assistant, struct imported_file *
         gsb_import_register_account_error ( account );
         devel_print_str ( account -> nom_de_compte );
 
-        return ( FALSE );
+        return FALSE ;
     }
 
     liste_tmp = liste_comptes_importes_ofx;
@@ -174,18 +170,14 @@ GSList *recuperation_donnees_ofx ( GtkWidget * assistant, struct imported_file *
 	liste_tmp = liste_tmp -> next;
     }
 
-    return ( liste_tmp );
+    return TRUE;
 }
 /* *******************************************************************************/
 
 
 
 
-#ifdef OFX_0_7
 int ofx_proc_status_cb(struct OfxStatusData data, void * status_data)
-#else /* OFX_0_7 */
-int ofx_proc_status_cb(struct OfxStatusData data)
-#endif /* OFX_0_7 */
 {
 /*         printf ( "ofx_proc_status_cb:\n" ); */
 /*         printf ( "ofx_element_name_valid %d\n", data . ofx_element_name_valid); */
@@ -232,7 +224,7 @@ int ofx_proc_status_cb(struct OfxStatusData data)
 		    dialogue_error ( _("OFX processing returned an error message which is not valid."));
 		erreur_import_ofx = 1;
 		break;
-	}		
+	}
     }
 
 
@@ -245,24 +237,9 @@ int ofx_proc_status_cb(struct OfxStatusData data)
 
 
 
-/* *******************************************************************************/
-int ofx_proc_security_cb(struct OfxSecurityData data)
-{
-    dialog_message ( "ofx-security-not-implemented" );
-    return 0;
-}
 /* *******************************************************************************/
 
-
-
-
-/* *******************************************************************************/
-
-#ifdef OFX_0_7
 int ofx_proc_account_cb(struct OfxAccountData data, void * account_data)
-#else /* OFX_0_7 */
-int ofx_proc_account_cb(struct OfxAccountData data)
-#endif /* OFX_0_7 */
 {
 /*         printf ( "ofx_proc_account_cb\n" ); */
 /*         printf ( "account_id_valid %d\n", data.account_id_valid ); */
@@ -307,11 +284,7 @@ int ofx_proc_account_cb(struct OfxAccountData data)
 
 
 /* *******************************************************************************/
-#ifdef OFX_0_7
 int ofx_proc_transaction_cb(struct OfxTransactionData data, void * security_data)
-#else /* OFX_0_7 */
-int ofx_proc_transaction_cb(struct OfxTransactionData data)
-#endif /* OFX_0_7 */
 {
     struct struct_ope_importation *ope_import;
     GDate *date;
@@ -497,18 +470,14 @@ int ofx_proc_transaction_cb(struct OfxTransactionData data)
 									       ope_import );
 
 
-    return 0; 
+    return 0;
 }
 /* *******************************************************************************/
 
 
 
 /* *******************************************************************************/
-#ifdef OFX_0_7
 int ofx_proc_statement_cb(struct OfxStatementData data, void * statement_data)
-#else /* OFX_0_7 */
-int ofx_proc_statement_cb(struct OfxStatementData data)
-#endif /* OFX_0_7 */
 {
     GDate *date;
 
