@@ -30,9 +30,11 @@
 #endif
 
 #include "include.h"
+#include <gtk/gtk.h>
 
 /*START_INCLUDE*/
 #include "print_dialog_config.h"
+#include "structures.h"
 #include "erreur.h"
 /*END_INCLUDE*/
 
@@ -40,7 +42,6 @@
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern GtkWidget *window;
 /*END_EXTERN*/
 
 static GtkPrintSettings *settings = NULL;
@@ -51,7 +52,7 @@ static GtkPrintSettings *settings = NULL;
  * \param begin_callback	the function to call when the "begin" signal is emited
  * \param draw_callback		the function to call when the "draw" signal is emited
  * \param custom_tab_label	Tab title for an optional custom config tab
- * \param custom_tab_callback	Callback that creates an optional config tab 
+ * \param custom_tab_callback	Callback that creates an optional config tab
  * \param custom_apply_callback	Callback called when user validate config
  * \param data data for callback
  *
@@ -69,7 +70,7 @@ void print_dialog_config ( GCallback begin_callback,
     print = gtk_print_operation_new ();
 	gtk_print_operation_set_unit ( print, GTK_UNIT_POINTS );
 
-    if (settings != NULL) 
+    if (settings != NULL)
 	gtk_print_operation_set_print_settings (print, settings);
 
     /* Custom stuff */
@@ -85,7 +86,7 @@ void print_dialog_config ( GCallback begin_callback,
 
 
     res = gtk_print_operation_run (print, GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG,
-				   GTK_WINDOW (window), NULL);
+				   GTK_WINDOW ( run.window ), NULL);
 
     if (res == GTK_PRINT_OPERATION_RESULT_APPLY)
     {
