@@ -29,12 +29,15 @@
 #endif
 
 #include "include.h"
+#include <math.h>
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "print_transactions_list.h"
 #include "gsb_autofunc.h"
 #include "gsb_automem.h"
 #include "gsb_calendar_entry.h"
+#include "gsb_color.h"
 #include "gsb_data_print_config.h"
 #include "gsb_data_transaction.h"
 #include "utils.h"
@@ -75,10 +78,8 @@ static GtkWidget * print_transactions_list_layout_config ( GtkPrintOperation * o
 
 
 /*START_EXTERN*/
-extern GdkColor archive_background_color;
-extern GdkColor couleur_fond[2];
-extern gchar *titres_colonnes_liste_operations[CUSTOM_MODEL_N_VISIBLES_COLUMN];
-extern gint transaction_col_width[CUSTOM_MODEL_N_VISIBLES_COLUMN];
+extern gchar *titres_colonnes_liste_operations[CUSTOM_MODEL_VISIBLE_COLUMNS];
+extern gint transaction_col_width[CUSTOM_MODEL_VISIBLE_COLUMNS];
 /*END_EXTERN*/
 
 
@@ -180,11 +181,11 @@ GtkWidget * print_transactions_list_layout_config ( GtkPrintOperation * operatio
 			hbox,
 			FALSE, FALSE, 0);
 
-    label = gtk_label_new (_("Initial date : "));
+    label = gtk_label_new (_("Initial date: "));
     gtk_box_pack_start (GTK_BOX (hbox),
 			label,
 			FALSE, FALSE, 0);
-    
+
     init_date_entry = gsb_calendar_entry_new (FALSE);
     if (draw_initial_date)
 	gsb_calendar_entry_set_date (init_date_entry, draw_initial_date);
@@ -192,11 +193,11 @@ GtkWidget * print_transactions_list_layout_config ( GtkPrintOperation * operatio
 			init_date_entry,
 			FALSE, FALSE, 0);
 
-    label = gtk_label_new (_("Final date : "));
+    label = gtk_label_new (_("Final date: "));
     gtk_box_pack_start (GTK_BOX (hbox),
 			label,
 			FALSE, FALSE, 0);
-    
+
     final_date_entry = gsb_calendar_entry_new (FALSE);
     if (draw_final_date)
 	gsb_calendar_entry_set_date (final_date_entry, draw_final_date);
@@ -345,7 +346,7 @@ gboolean print_transactions_list_apply ( GtkPrintOperation * operation,
 
     font_button_transactions = g_object_get_data ( G_OBJECT ( operation ), "font_transaction_button" );
     font_button_title = g_object_get_data ( G_OBJECT( operation ), "font_title_button" );
-    
+
     gsb_data_print_config_set_font_transaction ( pango_font_description_from_string (
                         gtk_font_button_get_font_name ( font_button_transactions ) ) );
     gsb_data_print_config_set_font_title ( pango_font_description_from_string (
@@ -742,7 +743,7 @@ static gint print_transactions_list_draw_title ( GtkPrintContext *context,
  * draw the title of the columns
  *
  * \param line_position	the position to insert the titles
- * 
+ *
  * \return the new line_position to continue to fill the page
  * */
 static gint print_transactions_list_draw_columns_title ( GtkPrintContext *context,
@@ -801,30 +802,38 @@ static void print_transactions_list_draw_background ( CustomRecord *record,
 						      gint line_position )
 {
     if (!gsb_data_print_config_get_draw_background ())
-	return;
+        return;
 
     if (record -> what_is_line == IS_ARCHIVE)
     {
-	cairo_rectangle (cr, 0, line_position, page_width, size_row + 2*gsb_data_print_config_get_draw_lines ());
-	cairo_set_source_rgb (cr, (gdouble) archive_background_color.red/65535, (gdouble) archive_background_color.green/65535, (gdouble) archive_background_color.blue/65535);
+        GdkColor *color;
+
+        color = gsb_color_get_couleur ( "archive_background_color" );
+        cairo_rectangle ( cr, 0, line_position, page_width, size_row + 2*gsb_data_print_config_get_draw_lines ( ) );
+        cairo_set_source_rgb ( cr,
+                        (gdouble) color -> red/65535,
+                        (gdouble) color -> green/65535,
+                        (gdouble) color -> blue/65535 );
     }
     else
     {
-	if (color_bg)
-	{
-	    CustomList *custom_list = transaction_model_get_model ();
-	    cairo_rectangle (cr, 0, line_position, page_width, custom_list -> nb_rows_by_transaction * size_row + 2*gsb_data_print_config_get_draw_lines ());
-	    cairo_set_source_rgb (cr, (gdouble) couleur_fond[0].red/65535, (gdouble) couleur_fond[0].green/65535, (gdouble) couleur_fond[0].blue/65535);
-	}
-	else
-	{
-	    CustomList *custom_list = transaction_model_get_model ();
-	    cairo_rectangle (cr, 0, line_position, page_width, custom_list -> nb_rows_by_transaction * size_row + 2*gsb_data_print_config_get_draw_lines ());
-	    cairo_set_source_rgb (cr, (gdouble) couleur_fond[1].red/65535, (gdouble) couleur_fond[1].green/65535, (gdouble) couleur_fond[1].blue/65535);
-	}
+        CustomList *custom_list = transaction_model_get_model ( );
+        GdkColor *color;
+
+        if ( color_bg )
+            color = gsb_color_get_couleur_with_indice ( "couleur_fond", 0 );
+        else
+            color = gsb_color_get_couleur_with_indice ( "couleur_fond", 1 );
+
+        cairo_rectangle (cr, 0, line_position, page_width,
+                        custom_list -> nb_rows_by_transaction * size_row + 2*gsb_data_print_config_get_draw_lines ( ) );
+        cairo_set_source_rgb (cr,
+                        (gdouble) color -> red/65535,
+                        (gdouble) color -> green/65535,
+                        (gdouble) color -> blue/65535 );
     }
-    cairo_fill (cr);
-    cairo_set_source_rgb (cr, 0.0, 0.0, 0.0);
+    cairo_fill ( cr );
+    cairo_set_source_rgb ( cr, 0.0, 0.0, 0.0 );
 }
 
 /**
@@ -852,7 +861,7 @@ static gint print_transactions_list_draw_line ( gint line_position )
 }
 
 /**
- * draw a column line 
+ * draw a column line
  *
  * \param column_position	column position
  * \param line_position		line position
@@ -888,7 +897,7 @@ static gint print_transactions_list_draw_row ( GtkPrintContext *context,
 {
     gint column;
     gfloat alignment[] = {
-	PANGO_ALIGN_CENTER, PANGO_ALIGN_CENTER, PANGO_ALIGN_LEFT, 
+	PANGO_ALIGN_CENTER, PANGO_ALIGN_CENTER, PANGO_ALIGN_LEFT,
 	PANGO_ALIGN_CENTER, PANGO_ALIGN_RIGHT, PANGO_ALIGN_RIGHT, PANGO_ALIGN_RIGHT
     };
 
