@@ -32,6 +32,7 @@
 #endif
 
 #include "include.h"
+#include <glib/gi18n.h>
 
 /*START_INCLUDE*/
 #include "transaction_list_sort.h"
@@ -52,7 +53,7 @@ static gboolean transaction_list_sort_get_initial_sort ( void );
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern GtkTreeViewColumn *transactions_tree_view_columns[CUSTOM_MODEL_N_VISIBLES_COLUMN];
+extern GtkTreeViewColumn *transactions_tree_view_columns[CUSTOM_MODEL_VISIBLE_COLUMNS];
 /*END_EXTERN*/
 
 
@@ -68,7 +69,7 @@ extern GtkTreeViewColumn *transactions_tree_view_columns[CUSTOM_MODEL_N_VISIBLES
  *
  * to update all the tree view, use gsb_transactions_list_update_tree_view instead
  *
- * \param 
+ * \param
  *
  * \return
  * */
@@ -189,7 +190,7 @@ void transaction_list_sort_get_column ( gint *sort_col,
 
 
 /**
- * set if the sorting function is normal (by columns) or for reconcile
+ * set if the sorting function is normal (by columns) or for reconciliation
  *
  * \param use_reconcile_sort	TRUE to sort for reconciliation, FALSE for column sort
  *
@@ -215,11 +216,11 @@ void transaction_list_sort_set_reconcile_sort ( gboolean use_reconcile_sort )
 
 
 /**
- * get if the sorting function is normal (by columns) or for reconcile
+ * get if the sorting function is normal (by columns) or for reconciliation
  *
  * \param
  *
- * \return TRUE if the list is sorted for reconcile, FALSE if column sort
+ * \return TRUE if the list is sorted for reconciliation, FALSE if column sort
  * */
 gboolean transaction_list_sort_get_reconcile_sort ( void )
 {
