@@ -26,11 +26,12 @@
 #endif
 
 #include "include.h"
-
+#include <string.h>
+#include <ctype.h>
 
 /*START_INCLUDE*/
 #include "utils_editables.h"
-#include "gsb_real.h"
+#include "utils_real.h"
 #include "utils_str.h"
 /*END_INCLUDE*/
 
@@ -38,7 +39,6 @@
 /*END_STATIC*/
 
 /*START_EXTERN*/
-extern gsb_real null_real;
 /*END_EXTERN*/
 
 
@@ -73,7 +73,7 @@ GtkWidget *gsb_editable_text_view_new ( const gchar *value )
  *
  * \param the text_view
  *
- * \return a gchar which is the content of the text view 
+ * \return a gchar which is the content of the text view
  * */
 gchar *gsb_editable_text_view_get_content ( GtkWidget *text_view )
 {
@@ -84,7 +84,7 @@ gchar *gsb_editable_text_view_get_content ( GtkWidget *text_view )
 			  NULL);
     g_return_val_if_fail (GTK_IS_TEXT_VIEW (text_view),
 			  NULL);
-    
+
     buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_view));
     gtk_text_buffer_get_iter_at_offset ( buffer, &start, 0 );
     gtk_text_buffer_get_iter_at_offset ( buffer, &end, -1 );
@@ -136,87 +136,6 @@ void increment_decrement_champ ( GtkWidget *entry, gint increment )
 }
 
 
-/**
- * calcule le total du contenu de l'entrée donnée en argument 
- * accepte les + et les - 
- * 
- * \param entry entrée d'un montant 
- * 
- * \return gsb_real total de ce qui est dans l'entrée 
- */
-gsb_real gsb_utils_edit_calculate_entry ( GtkWidget *entry )
-{
-    gchar *string;
-    gchar *pointeur;
-    gsb_real total = null_real;
-	
-    string = my_strdup ( gtk_entry_get_text ( GTK_ENTRY ( entry ) ) );
-
-    if ( string && strlen ( string ) )
-        pointeur = string + strlen ( string );
-    else
-    {
-        g_free ( string );
-        return total;
-    }
-
-    if ( g_utf8_strchr ( string, -1, '-' ) || g_utf8_strchr ( string, -1, '+' ) )
-    {
-        while ( pointeur != string )
-        {
-            if ( pointeur[0] == '+'
-                 ||
-                 pointeur[0] == '-' )
-            {
-                total = gsb_real_add ( total,
-                            gsb_real_get_from_string ( pointeur ) );
-                pointeur[0] = 0;
-            }
-            
-            pointeur--;
-        }
-        total = gsb_real_add ( total,
-                        gsb_real_get_from_string ( pointeur ) );
-    }
-    else if ( g_utf8_strchr ( string, -1, '*' ) )
-    {
-        total.mantissa = 1;
-        total.exponent = 0;
-
-        while ( pointeur != string )
-        {
-            if ( pointeur[0] == '*' )
-            {
-                total = gsb_real_mul ( total,
-                            gsb_real_get_from_string ( pointeur + 1 ) );
-                pointeur[0] = 0;
-            }
-            
-            pointeur--;
-        }
-        total = gsb_real_mul ( total,
-                        gsb_real_get_from_string ( pointeur ) );
-    }
-    else if ( g_utf8_strchr ( string, -1, '/' ) )
-    {
-        gchar **tab;
-
-        tab = g_strsplit ( string, "/", 2 );
-
-        total = gsb_real_div ( gsb_real_get_from_string ( tab[0] ),
-                        gsb_real_get_from_string ( tab[1] ) );
-
-        g_strfreev ( tab );
-    }
-    else
-        total = gsb_real_get_from_string ( string );
-
-    g_free ( string );
-
-    return total;
-}
-
-
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
