@@ -28,6 +28,7 @@
 #include <shlobj.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <gtk/gtk.h>
 
 #include "win32utils.h"
 
@@ -185,7 +186,7 @@ HRESULT win32_get_folder_path(gchar* folder_path,const int csidl)        /* {{{
 gchar* win32_get_my_documents_folder_path()            /* {{{ */
 {
     SetLastError(win32_get_folder_path(my_documents_path,CSIDL_PERSONAL|CSIDL_FLAG_CREATE));
-    g_strlcat(my_documents_path,"\\",MAX_PATH+1);
+    // g_strlcat(my_documents_path,"\\",MAX_PATH+1);
     return my_documents_path;
 } /* }}}  */
 
@@ -282,14 +283,17 @@ gchar* win32_app_subdir_folder_path(gchar * app_subdir) /* {{{ */
 win_version    win32_get_windows_version(void)                        /* {{{ */
 {
     win_version current_version = WIN_UNKNOWN;
+	DWORD dwPlatormId;
+	DWORD dwMajorVers;
+	DWORD dwMinorVers;
 
     OSVERSIONINFO VersInfos;
     VersInfos.dwOSVersionInfoSize = sizeof(OSVERSIONINFO);
     GetVersionEx(&VersInfos);
 
-    DWORD dwPlatormId = VersInfos.dwPlatformId;
-    DWORD dwMajorVers = VersInfos.dwMajorVersion;
-    DWORD dwMinorVers = VersInfos.dwMinorVersion;
+    dwPlatormId = VersInfos.dwPlatformId;
+    dwMajorVers = VersInfos.dwMajorVersion;
+    dwMinorVers = VersInfos.dwMinorVersion;
 
     switch (dwPlatormId)
     {
@@ -369,6 +373,7 @@ BOOL win32_create_process(gchar* application_path,gchar* arg_line,gchar* utf8_wo
     STARTUPINFO si;
     PROCESS_INFORMATION pi;
     TCHAR arg[2*MAX_PATH];
+	HANDLE hStdError;
 
     gchar* syslocale_working_directory = NULL; 
       
@@ -387,7 +392,7 @@ BOOL win32_create_process(gchar* application_path,gchar* arg_line,gchar* utf8_wo
         TCHAR stderr_path[MAX_PATH];
         strcpy(stderr_path,application_path);
         strcat(stderr_path,".err");
-        HANDLE hStdError = CreateFile(stderr_path,     // file to create
+        hStdError = CreateFile(stderr_path,     // file to create
                    GENERIC_WRITE,          // open for writing
                    0,                      // do not share
                    NULL,                   // default security
@@ -544,7 +549,7 @@ BOOL win32_create_process(gchar* application_path,gchar* arg_line,gchar* utf8_wo
  * @caveats   
  *   \\server\dir is not supported in this version of the implementation 
  *   duplicate directory separator are not supported by this implementation
- *
+ * 
  */
 gchar* win32_long_name(gchar* short_name) /* {{{ */
 {
@@ -629,18 +634,19 @@ gchar* win32_full_path(gchar* syslocale_path) /* {{{ */
 
 #define _WIN32_CHAR_IS_DIR_SEPARATOR(c) ((c=='\\')||(c== '/'))
 /** \deprecated */
+#ifdef _USE_DEPRECTED_
 DWORD win32_get_long_path_name(LPCTSTR lpszShortPath, LPTSTR lpszLongPath, DWORD ccBuffer) /* {{{ */
 {
     int iFound = -1;
         
     iFound = strlen(lpszShortPath);
-    
+
     // UNC path form is not supported, return immediatly
     if ( (iFound >= 2) && (_WIN32_CHAR_IS_DIR_SEPARATOR(lpszShortPath[0])) && (_WIN32_CHAR_IS_DIR_SEPARATOR(lpszShortPath[1]) ))
     {
         return -1;
     }
-        
+    
     
     //// remove duplicate (or more) '\' from path by going back to the first of the serie
     //while ((iFound > 0) && (lpszShortPath[iFound-1] == '\')) { iFound--; }
@@ -692,26 +698,26 @@ DWORD win32_get_long_path_name(LPCTSTR lpszShortPath, LPTSTR lpszLongPath, DWORD
         }
     }
     // nothing to convert ( c:\ \ )
-    else 
+    else
     {
         strcpy((TCHAR*)lpszLongPath,(TCHAR*)lpszShortPath);
     }
     return strlen((TCHAR*)lpszLongPath);
 } /* }}} */
-
+#endif
 /**
  * Get Environment variable value using Windows method.
  *
  * \param env_var Environment varaible name
  * \return newly allocated buffer containing the variable value 
  *      the buffer as to be freed using g_free when no more needed.
- *
+ * 
  * \retval NULL an error occured. PLease win32_get_last_error to have more information
  */
 gchar* win32_get_environment_variable(gchar* env_var) /* {{{ */
 {
     int    nVarBufferSize = GetEnvironmentVariable((LPCTSTR)(char*)(env_var),NULL,0);
-
+    
     TCHAR* lpVarBuffer    = (TCHAR*)malloc( sizeof(TCHAR) * (nVarBufferSize + 1));
     
     gchar* ret_buffer     = NULL; 
@@ -791,6 +797,20 @@ void win32_set_current_directory(gchar* utf8_dir) /* {{{ */
     g_free(syslocale_dir);
 } /* }}}  */
 
+void win32_parse_gtkrc (const gchar * basename){
+	gchar * out;
+	gchar * gtkrc_file = g_strdelimit(g_strconcat(g_path_get_dirname ( grisbi_exe_path  ),"\\",basename,NULL),
+                        "\\",
+                        '/');
+	out = g_locale_to_utf8(gtkrc_file, -1, NULL, NULL, NULL);
+	g_free ( gtkrc_file);
+	gtkrc_file = g_filename_from_utf8(out, -1, NULL, NULL, NULL);
+	g_free (out);
+	gtk_rc_parse(gtkrc_file);
+	g_free ( gtkrc_file );
+}
+
+
 // -------------------------------------------------------------------------
 // End of WinUtils
 // -------------------------------------------------------------------------
